//Header file for Mario 3 Improvement - Contains locations of SMB3 levels in
//the NES ROM.  Used by the level loading and saving routines to
//determine where objects and levels are.
//Version: 0.95
//Date: July 21, 2000
//Copyright (C) 1999-2000 by LincolnSoft(TM).
//Thanks to MarioExpert for finding the offsets for the "lost levels", the
//Hammer Bros. levels, and the pipe levels.



#ifndef _LEVELS_H
#define _LEVELS_H

#include "m3idefs.h"	

#define MAX_LEVEL_SECTIONS	(65)


typedef struct {
int num_ptrs;
int offset;
} MAPSCREEN_POINTER_LOCS;

typedef struct {
int ptr_type;
char type_name[20];
int ptr_min;
int ptr_max;
} OBJECTSET_POINTER_TYPES;


typedef struct {
MAX255 game_world;           //game world
MAX255 level_in_world;       //level in world
MAX4GIG rom_level_offset;    //location in ROM where level is stored
MAX4GIG enemy_offset;        //offset of enemy data
MAX255 real_obj_set;         //the REAL object set of the level according to SMB3.
 
} Mario3Level;

#define NUM_SMB3_LEVELS 298

Mario3Level level_array[NUM_SMB3_LEVELS] = {

//****************************************************************************************//
//       World Map Screens                                                                //
//****************************************************************************************//
{0, 1, 0x185BA, 0, 0x10}, 	//World 1 Map
{0, 2, 0x1864B, 0, 0x10},  //World 2 Map
{0, 3, 0x1876C, 0, 0x10},	//World 3 Map
{0, 4, 0x1891D, 0, 0x10}, 	//World 4 Map
{0, 5, 0x18A3E, 0, 0x10}, 	//World 5 Map
{0, 6, 0x18B5F, 0, 0x10},	//World 6 Map
{0, 7, 0x18D10, 0, 0x10}, 	//World 7 Map
{0, 8, 0x18E31, 0, 0x10},	//World 8 Map
{0, 9, 0x19072, 0, 0x10},  //Warp Zone
//****************************************************************************************//
//       World 1                                                                          //
//****************************************************************************************//
{1, 1, 0x1FB9B, 0xC538, 0x1},	//World 1-1
{1, 2, 0x20F43, 0xC6BB, 0x3},	//World 1-2
{1, 3, 0x1EE22, 0xC2FF, 0x1},   //World 1-3
{1, 4, 0x2351A, 0xCC44, 0x4},	//World 1-4
{1, 5, 0x1AA5A, 0xC93C, 0xE}, 	//World 1-5
{1, 6, 0x233C1, 0xCC1E, 0x4},	//World 1-6
{1, 7, 0x2A976, 0xD33C, 0x2},	//World 1-Dungeon
{1, 8, 0x232D8, 0xCBF6, 0x4},   //World 1-Secret
{1, 9, 0x2EDD0, 0xD6FB, 0xA},	//World 1-Ship
{1, 10, 0x1FCAC, 0xC017, 0x1}, //World 1-1 Bonus Area*****
{1, 11, 0x1FA62, 0xC017, 0x1}, //World 1-2 Bonus Area*****

{1, 12, 0x27A43, 0xCFE3, 0xD}, //World 1-3 Bonus Area
{1, 13, 0x1FE61, 0xC595, 0x1}, //World 1-4 Ending
{1, 14, 0x2788D, 0xD03D, 0xD}, //World 1-5 Bonus

{1, 15, 0x1FD81, 0xC571, 0x1}, //World 1-5 Ending
{1, 16, 0x2AA43, 0xD362, 0x2}, //World 1-Dungeon Spike Room
{1, 17, 0x2339A, 0xCC19, 0xC}, //World 1-Secret Ending
{1, 18, 0x2FA1B, 0xD9F7, 0xA}, //World 1-Ship Boss Room
{1, 19, 0x21404, 0xC73C, 0x3}, //World 1-Hammer Bros 1
{1, 20, 0x2141E, 0xC73C, 0x3}, //World 1-Hammer Bros 2
{1, 21, 0x2A850, 0xD2C0, 0x2}, //World 1-End Castle
{1, 22, 0x2EC42, 0xD6AD, 0xA}, //World 1-Anchors Away
{1, 23, 0x2FC2E, 0xDA15, 0xA}, //World 1-Coin Ship
{1, 24, 0x2FCD1, 0xDA20, 0xA}, //World 1-Coin Ship Boss Room
//****************************************************************************************//
//       World 2                                                                          //
//****************************************************************************************//
{2, 1, 0x29478, 0xD19A, 0x9},  //World 2-1
{2, 2, 0x218B1, 0xC8A6, 0x3},  //World 2-2
{2, 3, 0x2992E, 0xD201, 0x9},  //World 2-3
{2, 4, 0x29C91, 0xD270, 0x9},  //World 2-4
{2, 5, 0x29753, 0xD1D2, 0x9},  //World 2-5
{2, 6, 0x29AD3, 0xD233, 0x9},  //World 2-Dungeon
{2, 7, 0x21626, 0xC854, 0x3},  //World 2-Quicksand
{2, 8, 0x20590, 0xC5CD, 0x3},  //World 2-Pyramid
{2, 9, 0x2EEC4, 0xD72D, 0xA},  //World 2-Ship
{2, 10, 0x29644, 0xC017, 0x9}, //World 2-1 Bonus Area
{2, 11, 0x29F31, 0xD2B6, 0x9}, //World 2-2 Ending
{2, 12, 0x29F41, 0xD2BB, 0x9}, //World 2-3 Ending
{2, 13, 0x298C0, 0xC017, 0x9}, //World 2-5 Bonus Area
{2, 14, 0x29C15, 0xD265, 0x9}, //World 2-Dungeon Spike Room
{2, 15, 0x28F3F, 0xD108, 0x9}, //World 2-Pyramid Outside Area
{2, 16, 0x2FA64, 0xD9FC, 0xA}, //World 2-Ship Boss Room
{2, 17, 0x20CCE, 0xC013, 0x3}, //World 2-Hidden Hammer Bros
{2, 18, 0x2920F, 0xD15E, 0x9}, //World 2-Hammer Bros 1
{2, 19, 0x2920F, 0xD153, 0x9}, //World 2-Hammer Bros 2
{2, 20, 0x1ADB2, 0xC154, 0xE}, //World 2-Pipe 1 End 1
{2, 21, 0x1AE01, 0xC154, 0xE}, //World 2-Pipe 1 End 2
{2, 22, 0x2A800, 0xD2C0, 0x2}, //World 2-End Castle
{2, 23, 0x2EC10, 0xD6AD, 0xA}, //World 2-Anchors Away
//****************************************************************************************//
//       World 3                                                                          //
//****************************************************************************************//
{3, 1, 0x25323, 0xCE36, 0x6},  //World 3-1
{3, 2, 0x227E9, 0xCA34, 0x4},  //World 3-2
{3, 3, 0x1FE82, 0xC59F, 0x1},  //World 3-3
{3, 4, 0x1B732, 0xC9C4, 0xE},  //World 3-4
{3, 5, 0x25073, 0xCDFC, 0x6},  //World 3-5
{3, 6, 0x22952, 0xCA74, 0x4},  //World 3-6
{3, 7, 0x1F8D5, 0xC47F, 0x1},  //World 3-7
{3, 8, 0x1AC72, 0xC965, 0xE},  //World 3-8
{3, 9, 0x1F121, 0xC3A0, 0x1},  //World 3-9
{3, 10, 0x2AB9A, 0xD3A4, 0x2}, //World 3-Dungeon #1
{3, 11, 0x2AA92, 0xD373, 0x2}, //World 3-Dungeon #2
{3, 12, 0x2F022, 0xD768, 0xA}, //World 3-Ship
{3, 13, 0x1FA4B, 0xC4C0, 0x1}, //World 3-1 Ending
{3, 14, 0x228E3, 0xCA69, 0x4}, //World 3-2 Ending
{3, 15, 0x1FFB3, 0xC5C8, 0x1}, //World 3-3 Ending
{3, 16, 0x1B2A4, 0xC991, 0xE}, //World 3-5 Bonus Area
{3, 17, 0x1EF13, 0xC32E, 0x1}, //World 3-5 Ending
{3, 18, 0x22A56, 0xCA97, 0x4}, //World 3-6 Ending
{3, 19, 0x26B68, 0xCE9A, 0xD}, //World 3-7 Bonus Area
{3, 20, 0x1FD4C, 0xC56C, 0x1}, //World 3-8 Ending
{3, 21, 0x1B2A4, 0xC994, 0xE}, //World 3-9 Bonus Area
{3, 22, 0x1F32B, 0xC3E4, 0x1}, //World 3-9 Ending
{3, 23, 0x2AC61, 0xD3D6, 0x2}, //World 3-Dungeon #1 Water Room
{3, 24, 0x2AB24, 0xD390, 0x2}, //World 3-Dungeon #2 Water Room
{3, 25, 0x2FAB9, 0xDA01, 0xA}, //World 3-Ship Boss Room
{3, 26, 0x1F400, 0xC651, 0x1}, //World 3-Hammer Bros 1
{3, 27, 0x1F420, 0xC651, 0x1}, //World 3-Hammer Bros 2
{3, 28, 0x1FE14, 0xC651, 0x1}, //World 3-Hammer Bros 3
{3, 29, 0x1FDF1, 0xC651, 0x1}, //World 3-Hammer Bros 4
{3, 30, 0x21400, 0xC651, 0x3}, //World 3-Hidden Hammer Bros
{3, 32, 0x1AF9A, 0xC159, 0xE}, //World 3-Pipe 1 End 1
{3, 31, 0x1AFF8, 0xC159, 0xE}, //World 3-Pipe 1 End 2
{3, 33, 0x1AE50, 0xC15E, 0xE}, //World 3-Pipe 2 End 1
{3, 34, 0x1AEAD, 0xC15E, 0xE}, //World 3-Pipe 2 End 2
{3, 35, 0x1AF0A, 0xC163, 0xE}, //World 3-Pipe 3 End 1
{3, 36, 0x1AF52, 0xC163, 0xE}, //World 3-Pipe 3 End 2
{3, 36, 0x2A810, 0xD2C0, 0x2}, //World 3-End Castle
{3, 36, 0x2EC29, 0xD6AD, 0xA}, //World 3-Anchors Away
//****************************************************************************************//
//       World 4                                                                          //
//****************************************************************************************//
{4, 1, 0x26BA1, 0xCEA8, 0xB},  //World 4-1
{4, 2, 0x27080, 0xCF25, 0xB},  //World 4-2
{4, 3, 0x216EE, 0xC874, 0x3},  //World 4-3
{4, 4, 0x272C6, 0xCFCA, 0xB},  //World 4-4
{4, 5, 0x27745, 0xCFFD, 0xB},  //World 4-5
{4, 6, 0x1EAF8, 0xC268, 0x1},  //World 4-6
{4, 7, 0x2B6BF, 0xD539, 0x2},  //World 4-Dungeon #1
{4, 8, 0x2B5D7, 0xD519, 0x2},  //World 4-Dungeon #2
{4, 9, 0x2F153, 0xD7A9, 0xA},  //World 4-Ship
{4, 10, 0x2796B, 0xD042, 0xB}, //World 4-1 Bonus Area
{4, 11, 0x1FDD1, 0xC571, 0x1}, //World 4-1 Ending
{4, 12, 0x1FDD1, 0xC571, 0x1}, //World 4-2 Ending
{4, 13, 0x27028, 0xCF1D, 0xB}, //World 4-3 Beginning
{4, 14, 0x1FDD1, 0xC571, 0x1}, //World 4-3 Ending
{4, 15, 0x1FA9C, 0xC017, 0x1}, //World 4-4 Bonus Area
{4, 16, 0x1FDD1, 0xC571, 0x1}, //World 4-4 Ending
{4, 17, 0x1EF49, 0xC336, 0x1}, //World 4-5 Bonus Area
{4, 18, 0x1FDD1, 0xC571, 0x1}, //World 4-5 Ending
{4, 19, 0x1E88E, 0xC1EB, 0x1}, //World 4-6 Small Side
{4, 20, 0x1B152, 0xC979, 0xE}, //World 4-Dungeon #1 Underground Room
{4, 21, 0x25292, 0xCE28, 0x8}, //World 4-Dungeon #2 Pipe Room
{4, 22, 0x1B38E, 0xC999, 0xE}, //World 4-Dungeon #2 Bonus Area
{4, 23, 0x2EC5B, 0xD6B2, 0xA}, //World 4-Ship Boss Room
{4, 24, 0x27F77, 0xD0FB, 0xB}, //World 4-Hammer Bros 1
{4, 25, 0x1ADB2, 0xC168, 0xE}, //World 4-Pipe 1 End 1
{4, 26, 0x1AE01, 0xC168, 0xE}, //World 4-Pipe 1 End 2
{4, 27, 0x1AF9A, 0xC16D, 0xE}, //World 4-Pipe 2 End 1
{4, 28, 0x1AFF8, 0xC16D, 0xE}, //World 4-Pipe 2 End 2
{4, 30, 0x2A820, 0xD2C0, 0x2}, //World 4-End Castle
{4, 31, 0x2F43E, 0xD6AD, 0xA}, //World 4-Anchors Away
//***************************************************************************************//
//       World 5                                                                          //
//****************************************************************************************//
{5, 1, 0x1F464, 0xC3F3, 0x1},  //World 5-1
{5, 2, 0x1A590, 0xC8CF, 0xE},  //World 5-2
{5, 3, 0x1EC57, 0xC2AF, 0x1},  //World 5-3
{5, 4, 0x27A65, 0xD04A, 0xD},  //World 5-4
{5, 5, 0x22F1B, 0xCB1B, 0x4},  //World 5-5
{5, 6, 0x2715A, 0xCF51, 0xD},  //World 5-6
{5, 7, 0x26ED1, 0xCEEE, 0xD},  //World 5-7
{5, 8, 0x26A78, 0xCE81, 0xD},  //World 5-8
{5, 9, 0x2721B, 0xCF8C, 0xD},  //World 5-9
{5, 10, 0x2AD3F, 0xD3E1, 0x2}, //World 5-Dungeon #1
{5, 11, 0x2B48E, 0xD4FD, 0x2}, //World 5-Tower (Part 1)
{5, 12, 0x2B537, 0xD511, 0x2}, //World 5-Tower (Part 2)
{5, 13, 0x2A8CB, 0xD2CA, 0x2}, //World 5-Dungeon #2
{5, 14, 0x2ECB0, 0xD6B7, 0xA}, //World 5-Ship
{5, 15, 0x1F666, 0xC425, 0x1}, //World 5-1 Bonus Area
{5, 16, 0x2549A, 0xCE5C, 0x8}, //World 5-2 Pipe Room
{5, 17, 0x1B3F1, 0xC9A1, 0xE}, //World 5-2 Bonus Area
{5, 18, 0x1FD81, 0xC571, 0x1}, //World 5-2 Ending
{5, 19, 0x1EC2F, 0xC017, 0x1}, //World 5-3 Beginning
{5, 20, 0x1FD81, 0xC571, 0x1}, //World 5-3 Ending
{5, 21, 0x26B51, 0xCE92, 0xD}, //World 5-4 Ending
{5, 22, 0x1B3F1, 0xC9A4, 0xE}, //World 5-5 Bonus Area
{5, 23, 0x26B51, 0xCE92, 0xD}, //World 5-6 Ending
{5, 24, 0x1E512, 0xC177, 0x1}, //World 5-7 Bonus Area
{5, 25, 0x26B51, 0xCE92, 0xD}, //World 5-8 Ending
{5, 26, 0x26B51, 0xCE92, 0xD}, //World 5-9 Ending
{5, 27, 0x2AEBC, 0xD40D, 0x2}, //World 5-Dungeon #1 Bonus Area
{5, 28, 0x27650, 0xCFF5, 0xD}, //World 5-Tower Outside Area (Part 1)
{5, 29, 0x275C7, 0xCFED, 0xD}, //World 5-Tower Outside Area (Part 2)
{5, 30, 0x27581, 0xCFE8, 0xD}, //World 5-Tower (Going Down)
{5, 31, 0x2A870, 0xD2C5, 0x2}, //World 5-Dungeon #2 Beginning/End
{5, 32, 0x2FB0E, 0xDA06, 0xA}, //World 5-Ship Boss Room
{5, 33, 0x20CCE, 0xC651, 0x3}, //World 5-Hammer Bros 1
{5, 34, 0x2143B, 0xC651, 0x3}, //World 5-Hammer Bros 2
{5, 35, 0x27FCC, 0xC651, 0xD}, //World 5-Hammer Bros 3
{5, 36, 0x279A4, 0xC651, 0xD}, //World 5-Hammer Bros 4
{5, 37, 0x2A830, 0xD2C0, 0x2}, //World 5-End Castle
{5, 38, 0x2F457, 0xD6AD, 0xA}, //World 5-Anchors Away
//****************************************************************************************//
//       World 6                                                                          //
//****************************************************************************************//
{6, 1, 0x23245, 0xCBD3, 0xC},  //World 6-1
{6, 2, 0x23165, 0xCB63, 0xC},  //World 6-2
{6, 3, 0x22A84, 0xCA9F, 0xC},  //World 6-3
{6, 4, 0x2363E, 0xCC7C, 0xC},  //World 6-4
{6, 5, 0x207F0, 0xC5FC, 0x3},  //World 6-5
{6, 6, 0x20CF5, 0xC65C, 0x3},  //World 6-6
{6, 7, 0x23B03, 0xCD28, 0xC},  //World 6-7
{6, 8, 0x1B8CD, 0xC9F6, 0xE},  //World 6-8
{6, 9, 0x209F0, 0xC61F, 0x3},  //World 6-9
{6, 10, 0x239AC, 0xCCF9, 0xC}, //World 6-10
{6, 11, 0x2B16A, 0xD4C1, 0x2}, //World 6-Dungeon #1
{6, 12, 0x22BA5, 0xCABC, 0xC}, //World 6-Dungeon #2
{6, 13, 0x2B04B, 0xD481, 0x2}, //World 6-Dungeon #3
{6, 14, 0x2F2CC, 0xD7F6, 0xA}, //World 6-Ship
{6, 15, 0x23F42, 0xC017, 0xC}, //World 6-1 Bonus Area
{6, 16, 0x2339A, 0xCC19, 0xC}, //World 6-2 Ending
{6, 17, 0x1B489, 0xC9AC, 0xE}, //World 6-3 Bonus Area
{6, 18, 0x27851, 0xD038, 0xD}, //World 6-4 Bonus Area
{6, 19, 0x22D03, 0xCAE4, 0xC}, //World 6-5 Outside Area
{6, 20, 0x2394A, 0xCCF1, 0xC}, //World 6-6 Outside Area
{6, 21, 0x23CC9, 0xCD36, 0xC}, //World 6-7 Ending
{6, 22, 0x23D07, 0xCD3E, 0xC}, //World 6-9 Outside Area
{6, 23, 0x1B489, 0xC9A9, 0xE}, //World 6-9 Bonus Area
{6, 24, 0x1B489, 0xC9AF, 0xE}, //World 6-10 Bonus Area
{6, 25, 0x2B218, 0xD4E4, 0x2}, //World 6-Dungeon #1 Spike Room
{6, 26, 0x22CB1, 0xCADF, 0xC}, //World 6-Dungeon #2 Boss Room
{6, 27, 0x2B13F, 0xD4B3, 0x2}, //World 6-Dungeon #3 Falling Room
{6, 28, 0x2FB63, 0xDA0B, 0xA}, //World 6-Ship Boss Room
{6, 29, 0x23F29, 0xC651, 0xC}, //World 6-Hammer Bros 1
{6, 30, 0x23F97, 0xC651, 0xC}, //World 6-Hammer Bros 2
{6, 31, 0x1ADB2, 0xC14A, 0xE}, //World 6-Pipe 1 End 1
{6, 32, 0x1AE01, 0xC14A, 0xE}, //World 6-Pipe 1 End 2
{6, 33, 0x1B056, 0xC14F, 0xE}, //World 6-Pipe 2 End 1
{6, 34, 0x1B092, 0xC14F, 0xE}, //World 6-Pipe 2 End 2
{6, 35, 0x2A840, 0xD2C0, 0x2}, //World 6-End Castle
{6, 36, 0x2F470, 0xD6AD, 0xA}, //World 6-Anchors Away
//****************************************************************************************//
//       World 7                                                                          //
//****************************************************************************************//
{7, 1, 0x24BB0, 0xCDA4, 0x8},  //World 7-1
{7, 2, 0x29007, 0xD115, 0x9},  //World 7-2
{7, 3, 0x2129D, 0xC704, 0x3},  //World 7-3
{7, 4, 0x24DDD, 0xCDD3, 0x6},  //World 7-4
{7, 5, 0x1E5E6, 0xC182, 0x1},  //World 7-5
{7, 6, 0x25619, 0xCE67, 0x8},  //World 7-6
{7, 7, 0x23D48, 0xCD46, 0x4},  //World 7-7
{7, 8, 0x1EF88, 0xC33E, 0x1},  //World 7-8
{7, 9, 0x29258, 0xD16B, 0x9},  //World 7-9
{7, 10, 0x27C3C, 0xD08D, 0x5}, //World 7-Piranha Plat #1
{7, 11, 0x2B2A7, 0xD4F5, 0x2}, //World 7-Dungeon #1
{7, 12, 0x2AF19, 0xD42C, 0x2}, //World 7-Dungeon #2
{7, 13, 0x27B39, 0xD079, 0x5}, //World 7-Piranha Plant #2
{7, 14, 0x2F4A2, 0xD825, 0xA}, //World 7-Ship
{7, 15, 0x1EA7A, 0xC25E, 0x1}, //World 7-1 Outside Area
{7, 16, 0x1FA4B, 0xC4C0, 0x1}, //World 7-2 Ending
{7, 17, 0x1F39B, 0xC3EE, 0x1}, //World 7-4 Outside Area
{7, 18, 0x1FD02, 0xC567, 0x1}, //World 7-5 Outside Area
{7, 19, 0x1F34B, 0xC3E9, 0x1}, //World 7-6 Outside Area
{7, 20, 0x1EAC1, 0xC263, 0x1}, //World 7-7 Beginning/End
{7, 21, 0x27F90, 0xD103, 0xD}, //World 7-8 Bonus Area #1
{7, 22, 0x1B5FE, 0xC9B4, 0xE}, //World 7-8 Bonus Area #2
{7, 23, 0x28FF7, 0xD110, 0x9}, //World 7-9 Ending
{7, 24, 0x27EEC, 0xD0F3, 0x5}, //World 7-Piranha Plant #1 Ending
{7, 25, 0x2B3E4, 0xC017, 0x2}, //World 7-Dungeon #1 Lonely Room
{7, 26, 0x1B5FE, 0xC9B7, 0xE}, //World 7-Dungeon #1 Bonus Area
{7, 27, 0x2AFF1, 0xD46D, 0x2}, //World 7-Dungeon #2 Boss Room
{7, 28, 0x27E61, 0xD0EB, 0x5}, //World 7-Piranha Plant #2 Ending
{7, 29, 0x2FBD3, 0xDA10, 0xA}, //World 7-Ship Boss Room
{7, 30, 0x1F441, 0xC651, 0x1}, //World 7-Hammer Bros 1
{7, 31, 0x1ADB2, 0xC127, 0xE}, //World 7-Pipe 1 End 1
{7, 32, 0x1AE01, 0xC127, 0xE}, //World 7-Pipe 1 End 2
{7, 33, 0x1B056, 0xC136, 0xE}, //World 7-Pipe 2 End 1
{7, 34, 0x1B092, 0xC136, 0xE}, //World 7-Pipe 2 End 2
{7, 35, 0x1AF0A, 0xC12C, 0xE}, //World 7-Pipe 3 End 1
{7, 36, 0x1AF52, 0xC12C, 0xE}, //World 7-Pipe 3 End 2
{7, 37, 0x1AE50, 0xC131, 0xE}, //World 7-Pipe 4 End 1
{7, 38, 0x1AEAD, 0xC131, 0xE}, //World 7-Pipe 4 End 2
{7, 39, 0x1AE50, 0xC122, 0xE}, //World 7-Pipe 5 End 1
{7, 40, 0x1AEAD, 0xC122, 0xE}, //World 7-Pipe 5 End 2
{7, 41, 0x1AE50, 0xC144, 0xE}, //World 7-Pipe 6 End 1
{7, 42, 0x1AEAD, 0xC144, 0xE}, //World 7-Pipe 6 End 2
{7, 43, 0x1AF9A, 0xC13B, 0xE}, //World 7-Pipe 7 End 1
{7, 44, 0x1AFF8, 0xC13B, 0xE}, //World 7-Pipe 7 End 2
{7, 45, 0x1ADB2, 0xC140, 0xE}, //World 7-Pipe 8 End 1
{7, 46, 0x1AE01, 0xC140, 0xE}, //World 7-Pipe 8 End 2
{7, 47, 0x2A860, 0xD2C0, 0x2}, //World 7-End Castle
{7, 48, 0x2F489, 0xD6AD, 0xA}, //World 7-Anchors Away
//****************************************************************************************//
//                   World 8                                                              //
//****************************************************************************************//
{8, 1, 0x1F7A0, 0xC435, 0x1},  //World 8-1
{8, 2, 0x1A814, 0xC910, 0xE},  //World 8-2
{8, 3, 0x2F8EC, 0xD980, 0xA},  //World 8-Tank #1
{8, 4, 0x2F6CA, 0xD8DD, 0xA},  //World 8-Battleship
{8, 5, 0x27D59, 0xD0C1, 0xB},  //World 8-Hand Trap #1
{8, 6, 0x27CF7, 0xD0A4, 0xB},  //World 8-Hand Trap #2
{8, 7, 0x27DA8, 0xD0D2, 0xB},  //World 8-Hand Trap #3
{8, 8, 0x2F630, 0xD878, 0xA},  //World 8-Crappy Ship
{8, 9, 0x2B893, 0xD562, 0x2},  //World 8-Dungeon
{8, 10, 0x2F7F7, 0xD92D, 0xA}, //World 8-Tank #2
{8, 11, 0x2BC46, 0xD5DE, 0x2}, //World 8-Bowsers Castle
{8, 12, 0x1B674, 0xC9BF, 0xE}, //World 8-1 Bonus Area
{8, 13, 0x1F6D3, 0xC016, 0x1}, //World 8-2 Bonus Area
{8, 14, 0x2FDB9, 0xDA3A, 0xA}, //World 8-Tank #1 Boss Room
{8, 15, 0x2FD57, 0xDA30, 0xA}, //World 8-Battleship Boss Room
{8, 16, 0x27E30, 0xD0E0, 0xB}, //World 8-Hand Trap #1 Ending
{8, 17, 0x27E30, 0xD0E0, 0xB}, //World 8-Hand Trap #2 Ending
{8, 18, 0x27E30, 0xD0E0, 0xB}, //World 8-Hand Trap #3 Ending
{8, 19, 0x2FD88, 0xDA35, 0xA}, //World 8-Crappy Ship Boss Room
{8, 20, 0x2BAC6, 0xD59A, 0x2}, //World 8-Dungeon (White Side)
{8, 21, 0x2FD26, 0xDA2B, 0xA}, //World 8-Tank #2 Boss Room
{8, 21, 0x1EAC1, 0xC04E, 0x1}, //World 8-Hidden Level
{8, 21, 0x1B0CE, 0xC104, 0xE}, //World 8-Pipe 1 End 1
{8, 21, 0x1B110, 0xC104, 0xE}, //World 8-Pipe 1 End 2
{8, 21, 0x1B0CE, 0xC113, 0xE}, //World 8-Pipe 2 End 1
{8, 21, 0x1B110, 0xC113, 0xE}, //World 8-Pipe 2 End 2
{8, 21, 0x1B0CE, 0xC118, 0xE}, //World 8-Pipe 3 End 1
{8, 21, 0x1B110, 0xC118, 0xE}, //World 8-Pipe 3 End 2
{8, 21, 0x1B0CE, 0xC109, 0xE}, //World 8-Pipe 4 End 1
{8, 21, 0x1B110, 0xC109, 0xE}, //World 8-Pipe 4 End 2
{8, 21, 0x1ADB2, 0xC11C, 0xE}, //World 8-Pipe 5 End 1
{8, 21, 0x1AE01, 0xC11C, 0xE}, //World 8-Pipe 5 End 2
{8, 21, 0x1B0CE, 0xC10E, 0xE}, //World 8-Pipe 6 End 1
{8, 21, 0x1B110, 0xC10E, 0xE}, //World 8-Pipe 6 End 2
{8, 22, 0x2BE60, 0xD61C, 0x2},  //World 8-Bowser's Castle (Bowser's Lair)



//****************************************************************************************//
//          Lost Levels                                                                       //
//****************************************************************************************//

{9, 1, 0x1E742, 0xC1B7, 0x1},  //Plains End
{9, 2, 0x1E765, 0xC1BC, 0x1},  //Plains 1
{9, 3, 0x1E9C5, 0xC232, 0x1},  //Plains 2
{9, 4, 0x1FDA1, 0xC590, 0x1},  //Plains 2 End

{9, 5, 0x2B76D, 0xD412, 0x2},  //Dungeon 1

{9, 6, 0x20712, 0x0000, 0x3},  //Hilly 1
{9, 7, 0x210F6, 0xC6ED, 0x3},  //Hilly 2
{9, 8, 0x2145B, 0xC017, 0x3},  //Hilly 3
{9, 9, 0x214B6, 0xC7B8, 0x3},  //Hilly 4

{9, 10, 0x22DE6, 0xCAE9, 0x4}, //Sky 1
{9, 11, 0x23055, 0xCB47, 0x4}, //Sky 2
{9, 12, 0x230DD, 0xCB55, 0x4}, //Sky 3

{9, 13, 0x24F31, 0xC017, 0x8}, //Pipe 1

{9, 14, 0x26CC2, 0xCECE, 0xD}, //Cloudy 1
{9, 15, 0x26B51, 0xCE92, 0xD}, //Cloudy 1 End
{9, 16, 0x26DC4, 0x0000, 0xD}, //Cloudy 3
{9, 17, 0x26E21, 0x0000, 0xC} //Ice

};

//****************************************************************************************//
//           The End!                                                                     //
//****************************************************************************************//

const unsigned int map_enemy_offset = 0x16070;
 
MAPSCREEN_POINTER_LOCS pointer_tables[9] = {
{21, 0x19438},  // World 1 map pointers
{47, 0x194BA},  // World 2 map pointers
{52, 0x195D8},  // World 3 map pointers
{34, 0x19714},  // World 4 map pointers
{42, 0x197E4},  // World 5 map pointers
{57, 0x198E4},  // World 6 map pointers
{46, 0x19A3E},  // World 7 map pointers
{41, 0x19B56},  // World 8 map pointers
{10, 0x19C50},  // Warp Zone pointers (no enemy set / level pointers)
};
 
OBJECTSET_POINTER_TYPES object_set_pointers[17] = {
{0x0000, "Unknown", 0x0000, 0x0000},
{0x4000, "Plains", 0x1E512, 0x2000F},
{0x10000, "Dungeon", 0x2A7F7, 0x2C00F},
{0x6000, "Hilly", 0x20587, 0x2200F},
{0x8000, "Sky", 0x227E0, 0x2400F},
{0xC000, "Piranha Plant", 0x26A6F, 0x2800F},
{0xA000, "Water", 0x24BA7, 0x2600F},
{0x0000, "Mushroom House", 0x0000, 0x0000},
{0xA000, "Pipe", 0x24BA7, 0x2600F},
{0xE000, "Desert", 0x28F3F, 0x2A00F},
{0x14000, "Ship", 0x2EC07, 0x3000F},
{0xC000, "Giant", 0x26A6F, 0x2800F},
{0x8000, "Ice", 0x227E0, 0x2400F},
{0xC000, "Cloudy", 0x26A6F, 0x2800F},
{0x0000, "Underground", 0x1A587, 0x1C00F},
{0x0000, "Spade House", 0x0000, 0x0000},
{0x0000, "Map Screen", 0x0000, 0x0000}
};
 

 
#endif
 