// Mario 3 Improvement Source Code - Level Editor for Super Mario Bros. 3 NES ROM
// This is the main source code module.
// Version: 0.95
// Date: July 22, 2000
// Copyright (C) 1999-2000 by LincolnSoft(TM).  All rights reserved.
// Written for DJGPP and Allegro.
#include <conio.h>
#include <dos.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <allegro3.h>
#include <fcntl.h>
#include <sys/stat.h>
#include <unistd.h>
#include <tdgui.h>
#include <dir.h>
#include "nessmb3.h"
#include "allstars.h"
#include "m3idefs.h"
#include "objects.h"


#define MAX_LEVEL_SIZE	(65544)	// The NES only has 64K of RAM so you couldn't load levels bigger than this anyway
				 //(I made it a little bit bigger so its divisible by both 3 and 4)
#define X_SCREEN_MAX(x_screen_loc) (x_screen_loc + 20)
#define Y_SCREEN_MAX(y_screen_loc) (y_screen_loc + 13)
#define PIXEL_CALC(x) (x * 16)
#define CENTER_X(x)  ((320 - (x)) / 2)
#define CENTER_Y(x)  ((240 - (x)) / 2)


const unsigned short int screen_split = 40;	//used when scrolling to inidicate where the status

					     //display starts
//function declarations
char *level_getter(int, int *);
char *exit_action_getter(int, int *);
char *level_getter_ex(int, int *);
char *action_getter(int, int *);
char *world_getter(int, int *);
char *world_getter_ex(int, int *);
char *object_getter(int, int *);
char *object_set_getter(int, int *);
char *object_set_getter_ex(int, int *);
char *music_getter(int, int *);
char *gfx_getter(int, int *);
char *palette_getter(int, int *);
char *scroll_getter(int, int *);
char *mushroom_house_type_getter(int, int *);
char *remove_filename(char *filename);
void change_vert_scroll(int i);
void change_horiz_scroll(int i);
int redraw_length_dialog(void *, int);
int d_drop_down_proc(int msg, DIALOG * d, int c);
int my_list_proc(int msg, DIALOG * d, int c);
int qsort_by_h_location(const void *e1, const void *e2);
int qsort_objects_by_h_location(const void *e1, const void *e2);
int user_choose_level();	//lets user choose different level to edit
void scroll_level_right();	//scroll right
void scroll_level_left();	//scroll left
void scroll_level_up();		//scroll up     
void scroll_level_down();	//scroll down
int load_level_new();
int load_level_from_offset();
int specify_offset_3();
int read_objects(int obs);
int do_options_dialog();
int do_pointer_dialog_2();
int do_music();
int do_gfx();
int do_palettes();
int do_scrolling();
int do_length();
int save_level();		//saves changes to level
int save_level_new();
int toggle_pointer_mode();
int toggle_pointer_numbers();
int toggle_3byte();
int toggle_4byte();
int toggle_enemies();
int do_about();
int do_help();
void page_flip();		//flips pages for scrolling
void erase_page();
void load_level();		//loads the level when the user chooses a different

					//level
void do_pointer_dialog();
void redraw_screen();		//refreshes screen when it scrolls
void mouse_drag(int flags);
int edit_level();		//main editor loop
int load_romfile();		//loads rom file
int load_romfile_new();
int change_object_set();
int change_object_set_2();
int change_level_rom_offset();
int change_level_rom_offset_2();
int specify_offset();
int specify_offset_2();
int change_enemy_rom_offset();
int change_enemy_rom_offset_2();
int change_pointer_position();
int change_mushroom_house_type();
void load_mapscreen(MAX255 level_sections);
void load_objects_0(MAX255 level_sections);
void load_objects_1(MAX255 level_sections);
void load_objects_2(MAX255 level_sections);
void load_objects_3(MAX255 level_sections);
void load_enemies();
void check_refresh();
void blit_screen();
void refreshmap();
int quit();
int do_stats_dialog();
int view_objects();
int updater_proc(int, DIALOG *, int);
int u_textbox_proc(int, DIALOG *, int);
void add_4byte_object();
void add_3byte_object();
void add_enemy();
void delete_enemy(int object);
void delete_4byte(int object);
void delete_3byte(int object);
int save_m3l_file();


//for "Load Level from Offset" function
char specifyoffsetbuf[7] = "";
char leveloffsetbuf[7] = "";
char enemyoffsetbuf[7] = "";
char pointeroffsetbuf[7] = "";
char llfo_worldbuf[2] = "";
char llfo_levelbuf[3] = "";
char nl_worldbuf[2] = "";
char nl_levelbuf[2] = "";

char pd3_hriz_buf[100] = "";
char pd3_vert_buf[100] = "";
char pd3_hriz_buf_2[3] = "";

char m3l_filename[256];
const int ptr3_vert_values[16] = { 0x0, 0x5, 0x8, 0xC,
   0x10, 0x14, 0x17, 0x18,
   0x0, 0x5, 0x8, 0xC,
   0x10, 0x14, 0x17, 0x18
};

int from_save_to_rom_func = FALSE;
int vertical_flag = FALSE;
int level_known = TRUE;
int key_f9_flag = FALSE;
int key_f10_flag = FALSE;
int key_f11_flag = FALSE;
int level = 1;			//number of level to edit in world
int world = 1;			//number of world to edit
int num_worlds;
int num_levels;
int map_space_flag = FALSE;
int map_mouse_flag = FALSE;
int map_space_flag2 = FALSE;
int map_mouse_flag2 = FALSE;
int load_offset_flag = FALSE;
int enemy_offset;
int arg_flag = FALSE;
int map_temp2;

int ff_number_of_level_sections = 0;
int ff_object_flag = 0;
int ff_oldobject_flag = 0;

int allstars_flag = FALSE;

int close_level_chooser_dialog_ex_flag = FALSE;
int from_enemies_func = FALSE;
int from_level_func = FALSE;


int close_level_chooser_dialog_ex_flag_2 = FALSE;
int from_enemies_func_2 = FALSE;
int from_level_func_2 = FALSE;

int close_level_chooser_dialog_ex_flag_3 = FALSE;
int from_enemies_func_3 = FALSE;
int from_level_func_3 = FALSE;

int currently_selected_level_index;
int currently_selected_world;

int currently_selected_level_index_2;
int currently_selected_world_2;

int currently_selected_level_index_3;
int currently_selected_world_3;

int selected_level;
int selected_world;
int selected_offset;
int selected_raw_offset;
int selected_object_set;
int refresh_dialog_flag = FALSE;

int selected_level_2;
int selected_world_2;
int selected_offset_2;
int selected_raw_offset_2;
int selected_object_set_2;
int refresh_dialog_flag_2 = FALSE;

int selected_level_3;
int selected_world_3;
int selected_offset_3;
int selected_raw_offset_3;
int selected_object_set_3;
int refresh_dialog_flag_1_3 = FALSE;

int selected_level_enemies;
int selected_world_enemies;
int selected_raw_offset_enemies;
int selected_offset_enemies;
int refresh_dialog_flag_1_2 = FALSE;

int selected_level_enemies_2;
int selected_world_enemies_2;
int selected_raw_offset_enemies_2;
int selected_offset_enemies_2;
int refresh_dialog_flag_2_2 = FALSE;

int selected_level_enemies_3;
int selected_world_enemies_3;
int selected_raw_offset_enemies_3;
int selected_offset_enemies_3;
int refresh_dialog_flag_3_2_1 = FALSE;

int refresh_dialog_flag_3 = FALSE;
int refresh_dialog_flag_4 = FALSE;
int refresh_dialog_flag_5 = FALSE;
int refresh_dialog_flag_6 = FALSE;

int refresh_dialog_flag_3_2 = FALSE;
int refresh_dialog_flag_4_2 = FALSE;
int refresh_dialog_flag_5_2 = FALSE;
int refresh_dialog_flag_6_2 = FALSE;

int refresh_dialog_flag_3_3 = FALSE;
int refresh_dialog_flag_4_3 = FALSE;
int refresh_dialog_flag_5_3 = FALSE;
int refresh_dialog_flag_6_3 = FALSE;

int level_offset_changed_flag = FALSE;
int enemy_offset_changed_flag = FALSE;

int level_offset_changed_flag_2 = FALSE;
int enemy_offset_changed_flag_2 = FALSE;

int pointer_mode = FALSE;
int pointer_numbers = TRUE;
int object_numbers = FALSE;
int the_romfile;
MAX64K enemy_bytes;
char fullname_text[80];

unsigned char map_sprites[9][4];
unsigned char map_ptr_vert[65664];
unsigned char map_ptr_hriz[65664];
unsigned char map_ptr_enemies[2][65664];
unsigned char map_ptr_levels[2][65664];
MAX64K level_index_number;
MAX64K object_ordering[21848];	//Object ordering table
int number_of_level_sections;
int the_first_object;
int pointer_offset;
int num_ptrs;
COLOR_MAP trans_table;
PALLETE the_pallete;
FILE *the_rom;
MAX4GIG level_offset;
MAX4GIG header_offset;
MAX64K level_bytes;		//stores the amount of bytes each level uses
MAX255 level_object_set;	//stores the number of the tile set each level uses
MAX255 level_table_string[MAX_LEVEL_SIZE];	//actual level data will be stored in this string

					//when the level is loaded
MAX255 enemy_string[MAX_LEVEL_SIZE];
MAX32K visible_page_offset = 0;	//offset of the visual page in video memory             
MAX32K hidden_page_offset = 200;	//offset of the hidden page
MAX32K screen_x = 0;		//visible screen horizontal position
MAX32K screen_y = 0;		//visible screen vertical position
MAX32K visible_page_bottom;	//bottom of visible page                
MAX32K hidden_page_bottom;	//bottom of hidden page
MAX255 object_x_position;	//horizontal position of object in level
MAX255 object_y_position;	//vertical position of object in level
MAX255 object_height;		//height of object
MAX255 object_width;		//width of object
MAX255 object_type;		//type of object
MAX255 object_length;		//length of object      
char romfile[256];		//rom filename
char savetoromfile[256];
MAX255 tbyte_array[3][21848];	//temporary reusable storage for 3-byte objects
MAX255 fbyte_array[4][16386];	//temporary reusable storage for 4-byte objects
MAX255 enemy_array[3][21848];	//temporary reusable storage for enemies
SMB3_ENEMY sort[21848];
unsigned short object_numbers_3[21848];
unsigned short object_numbers_4[16386];
MAX255 maparray[9][7296];
MAX255 header[9];		//Level header.
MAX255 level_sections;
MAX255 first_object;
MAX255 enemy_objs;
MAX255 tbyte_objs;
MAX255 fbyte_objs;
MAX32K cursor_x = 0x1;
MAX32K cursor_y = 0x15;
MAX32K old_x_loc = 0;
MAX32K old_y_loc = 15;
MAX32K x_screen_loc = 0x0;
MAX32K y_screen_loc = 0xF;
int check_flag = TRUE;
int blit_flag = TRUE;
int mapedit_flag = FALSE;
int tdomain;
int oldworld2;
MAX255 ftemp[192];
MAX255 temp[256];
MAX255 etemp[48];
MAX255 t_index;
MAX255 ft_index;
MAX255 e_index;
int real_level_object_set;
int show4byte_flag = TRUE;
int show3byte_flag = TRUE;
int showenemy_flag = TRUE;
BITMAP *main_display, *status_display, *buffer, *mouse_cursor;
BITMAP *lincoln_logo, *object_view;
BITMAP *gfx_preview, *palette_preview;
DATAFILE *obj_01_data;
DATAFILE *previews;
int mario3rom;
int mickey_x = 0;
int mickey_y = 0;
int tempt;
int temp_ptr;
int tempf;
int tempe;
int temptk;
int tempfk;
int tempek;
int map_temp;
int file_loaded = FALSE;
int levelmodified = FALSE;
int freeform_mode = FALSE;

int save_level_to_rom_location();
int new_level();
int load_m3l_file();
int change_level_rom_offset_3();
int change_enemy_rom_offset_3();



MENU file_menu[] = {
   {"&Load ROM...\tL", load_romfile_new, NULL, 0, NULL},
   {"Load from &Offset...\tCtrl+L", load_level_from_offset, NULL, D_DISABLED, NULL},
   {"&Save Level\tS", save_level_new, NULL, D_DISABLED, NULL},
   {"&New Level\tCtrl+N", new_level, NULL, 0, NULL},
   {"Save to &ROM Location\tCtrl+R", save_level_to_rom_location, NULL, D_DISABLED, NULL},
   {"Save M3L &file\tCtrl+S", save_m3l_file, NULL, D_DISABLED, NULL},
   {"Load &M3L file\tCtrl+O", load_m3l_file, NULL, 0, NULL},
   {"", NULL, NULL, 0, NULL},
   {"E&xit\tEsc", quit, NULL, 0, NULL},
   {NULL, NULL, NULL, 0, NULL}
};

MENU view_menu[] = {
   {"  &3-byte Objects\t3", toggle_3byte, NULL, D_SELECTED, NULL},
   {"  &4-byte Objects\t4", toggle_4byte, NULL, D_SELECTED, NULL},
   {"  &Enemies\tE", toggle_enemies, NULL, D_SELECTED, NULL},
   {"", NULL, NULL, 0, NULL},
   {"  &Options...\tO", do_options_dialog, NULL, 0, NULL},
   {"  &Pointer Mode\tP", toggle_pointer_mode, NULL, D_DISABLED, NULL},
   {"  Pointer &Numbers\tN", toggle_pointer_numbers, NULL, D_DISABLED, NULL},
   {NULL, NULL, NULL, 0, NULL}
};

MENU level_menu[] = {
   {"Select &Level...\tW", user_choose_level, NULL, D_DISABLED, NULL},
   {"Level &Info...\tI", do_stats_dialog, NULL, D_DISABLED, NULL},
   {"", NULL, NULL, 0, NULL},
   {"&Music...\tF2", do_music, NULL, D_DISABLED, NULL},
   {"&Graphics...\tF3", do_gfx, NULL, D_DISABLED, NULL},
   {"&Palette...\tF4", do_palettes, NULL, D_DISABLED, NULL},
   {"&Scrolling...\tF5", do_scrolling, NULL, D_DISABLED, NULL},
   {"Misc Level &Options...\tF6", do_length, NULL, D_DISABLED, NULL},
   {"Poin&ters...\tF7", do_pointer_dialog_2, NULL, D_DISABLED, NULL},
   {NULL, NULL, NULL, 0, NULL}
};

MENU help_menu[] = {
   {"&Help\tF1", do_help, NULL, 0, NULL},
   {"", NULL, NULL, 0, NULL},
   {"&About MI3...", do_about, NULL, 0, NULL},
   {NULL, NULL, NULL, 0, NULL}
};






MENU main_menu[] = {
   {"&File", NULL, file_menu, 0, NULL},
   {"&View", NULL, view_menu, 0, NULL},
   {"&Level", NULL, level_menu, 0, NULL},
   {"&Help                                               ", NULL, help_menu, 0, NULL},
   {NULL, NULL, NULL, 0, NULL}
};


DIALOG main_dialog[] = {
//dialog proc       x    y    w    h    fg  bg  key  flags   d1   d2   dp         dp2       dp3
   {d_billmenu_proc, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, main_menu, NULL, NULL},
   {d_keyboard_proc, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, quit, NULL, NULL},
   {d_keyboard_proc, 0, 0, 0, 0, 0, 0, 's', 0, 0, 0, save_level_new, NULL, NULL},
   {d_keyboard_proc, 0, 0, 0, 0, 0, 0, 'l', 0, 0, 0, load_romfile_new, NULL, NULL},
   {d_keyboard_proc, 0, 0, 0, 0, 0, 0, '3', 0, 0, 0, toggle_3byte, NULL, NULL},
   {d_keyboard_proc, 0, 0, 0, 0, 0, 0, '4', 0, 0, 0, toggle_4byte, NULL, NULL},
   {d_keyboard_proc, 0, 0, 0, 0, 0, 0, 'o', 0, 0, 0, do_options_dialog, NULL, NULL},
   {d_keyboard_proc, 0, 0, 0, 0, 0, 0, 'w', 0, 0, 0, user_choose_level, NULL, NULL},
   {d_keyboard_proc, 0, 0, 0, 0, 0, 0, 'i', 0, 0, 0, do_stats_dialog, NULL, NULL},
   {d_keyboard_proc, 0, 0, 0, 0, 0, 0, 'e', 0, 0, 0, toggle_enemies, NULL, NULL},
   {d_keyboard_proc, 0, 0, 0, 0, 0, 0, 0, 0, KEY_F1, 0, do_help, NULL, NULL},
   {d_keyboard_proc, 0, 0, 0, 0, 0, 0, 0, 0, KEY_F2, 0, do_music, NULL, NULL},
   {d_keyboard_proc, 0, 0, 0, 0, 0, 0, 0, 0, KEY_F3, 0, do_gfx, NULL, NULL},
   {d_keyboard_proc, 0, 0, 0, 0, 0, 0, 0, 0, KEY_F4, 0, do_palettes, NULL, NULL},
   {d_keyboard_proc, 0, 0, 0, 0, 0, 0, 0, 0, KEY_F5, 0, do_scrolling, NULL, NULL},
   {d_keyboard_proc, 0, 0, 0, 0, 0, 0, 0, 0, KEY_F6, 0, do_length, NULL, NULL},
   {d_keyboard_proc, 0, 0, 0, 0, 0, 0, 0, 0, KEY_F7, 0, do_pointer_dialog_2, NULL, NULL},
   {d_keyboard_proc, 0, 0, 0, 0, 0, 0, 'p', 0, 0, 0, toggle_pointer_mode, NULL, NULL},
   {d_keyboard_proc, 0, 0, 0, 0, 0, 0, 'n', 0, 0, 0, toggle_pointer_numbers, NULL, NULL},
   {d_keyboard_proc, 0, 0, 0, 0, 0, 0, 12, 0, 0, 0, load_level_from_offset, NULL, NULL},
   {d_keyboard_proc, 0, 0, 0, 0, 0, 0, 15, 0, 0, 0, load_m3l_file, NULL, NULL},
   {d_keyboard_proc, 0, 0, 0, 0, 0, 0, 14, 0, 0, 0, new_level, NULL, NULL},
   {d_keyboard_proc, 0, 0, 0, 0, 0, 0, 18, 0, 0, 0, save_level_to_rom_location, NULL, NULL},
   {NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, NULL, NULL, NULL}
};

DIALOG pointer_dialog_3[] = {
   {d_billwin_proc, CENTER_X(240), CENTER_Y(170), 240, 170, 28, 2, 0, 0, 0, 0, "Pointer Properties", NULL, NULL},
   {d_billtext_proc, (CENTER_X(240) + 8), (CENTER_Y(170) + 18), 240, 200, 28, 2, 0, 0, 0, 0, pd3_hriz_buf, NULL, NULL},
   {d_billslider_proc, (CENTER_X(240) + 8), (CENTER_Y(170) + 28), 120, 10, 0, 0, 0, 0, 0xF, 0, NULL, NULL, NULL},
   {d_billtext_proc, (CENTER_X(240) + 8), (CENTER_Y(170) + 42), 240, 200, 28, 2, 0, 0, 0, 0, "Exit Horizontal Location: ", NULL, NULL},
   {d_billtext_proc, (CENTER_X(240) + 8), (CENTER_Y(170) + 58), 240, 200, 28, 2, 0, 0, 0, 0, pd3_vert_buf, NULL, NULL},
   {d_billslider_proc, (CENTER_X(240) + 8), (CENTER_Y(170) + 68), 120, 10, 0, 0, 0, 0, 0xF, 0, NULL, NULL, NULL},
   {d_billtext_proc, (CENTER_X(240) + 8), (CENTER_Y(170) + 80), 240, 200, 28, 2, 0, 0, 0, 0, "Exit Action: ", NULL, NULL},
   {d_billlist_proc, (CENTER_X(240) + 8), (CENTER_Y(170) + 90), 224, 56, 0, 0, 0, 0, 0, 0, exit_action_getter, NULL, NULL},
   {d_billedit_proc, (CENTER_X(240) + 240 - 32), (CENTER_Y(170) + 42), 24, 12, 0, 0, 0, 0, 2, 0, pd3_hriz_buf_2, NULL, NULL},
   {d_billbutton_proc, (CENTER_X(240) + 8), (CENTER_Y(170) + 150), 80, 16, 0, 0, 0, D_EXIT, 0, 0, "OK", NULL, NULL},
   {d_billbutton_proc, (CENTER_X(240) + 240 - 88), (CENTER_Y(170) + 150), 80, 16, 0, 0, 0, D_EXIT, 0, 0, "Cancel", NULL, NULL},
   {NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, NULL, NULL, NULL}
};

DIALOG specify_offset_dialog[] = {
   {d_billwin_proc, CENTER_X(180), CENTER_Y(56), 180, 56, 28, 2, 0, 0, 0, 0, "Specify Offset", NULL, NULL},
   {d_billtext_proc, (CENTER_X(180) + 8), (CENTER_Y(56) + 18), 240, 200, 28, 2, 0, 0, 0, 0, "Offset: ", NULL, NULL},
   {d_billedit_proc, (CENTER_X(180) + 180 - 48), (CENTER_Y(56) + 18), 40, 12, 0, 0, 0, 0, 6, 0, specifyoffsetbuf, NULL, NULL},
   {d_billbutton_proc, (CENTER_X(180) + 8), (CENTER_Y(56) + 36), 80, 16, 0, 0, 0, D_EXIT, 0, 0, "OK", NULL, NULL},
   {d_billbutton_proc, (CENTER_X(180) + 180 - 88), (CENTER_Y(56) + 36), 80, 16, 0, 0, 0, D_EXIT, 0, 0, "Cancel", NULL, NULL},
   {NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, NULL, NULL, NULL}
};

DIALOG save_to_rom_dialog[] = {
   {d_billwin_proc, CENTER_X(240), CENTER_Y(120), 240, 120, 28, 2, 0, 0, 0, 0, "Save Level to ROM", NULL, NULL},
   {d_billtext_proc, (CENTER_X(240) + 8), (CENTER_Y(120) + 18), 0, 0, 28, 2, 0, 0, 0, 0, NULL, NULL, NULL},	//Object Set
   {d_billtext_proc, (CENTER_X(240) + 8), (CENTER_Y(120) + 28), 0, 0, 28, 2, 0, 0, 0, 0, NULL, NULL, NULL},	//Level Offset Range
   {d_billtext_proc, (CENTER_X(240) + 8), (CENTER_Y(120) + 38), 0, 0, 28, 2, 0, 0, 0, 0, NULL, NULL, NULL},	//Enemy Offset Range
   {d_callback_billbutton_proc, (CENTER_X(240) + 8), (CENTER_Y(120) + 58), 80, 16, 28, 2, 0, 0, 0, 0, "Level Offset...", change_level_rom_offset_3, NULL},
   {d_billtext_proc, (CENTER_X(240) + 92), (CENTER_Y(120) + 58), 16, 80, 28, 2, 0, 0, 0, 0, "Current Level Offset:", NULL, NULL},
   {d_billtext_proc, (CENTER_X(240) + 92), (CENTER_Y(120) + 68), 16, 80, 28, 2, 0, 0, 0, 0, NULL, NULL, NULL},
   {d_callback_billbutton_proc, (CENTER_X(240) + 8), (CENTER_Y(120) + 78), 80, 16, 28, 2, 0, 0, 0, 0, "Enemy Offset...", change_enemy_rom_offset_3, NULL},
   {d_billtext_proc, (CENTER_X(240) + 92), (CENTER_Y(120) + 78), 16, 80, 28, 2, 0, 0, 0, 0, "Current Enemy Offset:", NULL, NULL},
   {d_billtext_proc, (CENTER_X(240) + 92), (CENTER_Y(120) + 88), 16, 80, 28, 2, 0, 0, 0, 0, NULL, NULL, NULL},
   {d_billbutton_proc, (CENTER_X(240) + 8), (CENTER_Y(120) + 100), 80, 16, 0, 0, 0, D_EXIT, 0, 0, "OK", NULL, NULL},
   {d_billbutton_proc, (CENTER_X(240) + 152), (CENTER_Y(120) + 100), 80, 16, 0, 0, 0, D_EXIT, 0, 0, "Cancel", NULL, NULL},
   {NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, NULL, NULL, NULL}
};


DIALOG new_level_dialog[] = {
   {d_billwin_proc, CENTER_X(240), CENTER_Y(140), 240, 140, 28, 2, 0, 0, 0, 0, "New Level (Freeform Mode)", NULL, NULL},
   {d_billtext_proc, (CENTER_X(240) + 8), (CENTER_Y(140) + 18), 0, 0, 0, 0, 0, 0, 0, 0, "World #: ", NULL, NULL},
   {d_billtext_proc, (CENTER_X(240) + 8), (CENTER_Y(140) + 38), 0, 0, 0, 0, 0, 0, 0, 0, "Level #: ", NULL, NULL},
   {d_billtext_proc, (CENTER_X(240) + 8), (CENTER_Y(140) + 58), 0, 0, 0, 0, 0, 0, 0, 0, "Object Set: ", NULL, NULL},
   {d_billlist_proc, (CENTER_X(240) + 8), (CENTER_Y(140) + 68), 224, 48, 0, 0, 0, 0, 0, 0, object_set_getter, NULL, NULL},
   {d_billedit_proc, (CENTER_X(240) + 216), (CENTER_Y(140) + 18), 16, 12, 0, 0, 0, 0, 2, 0, nl_worldbuf, NULL, NULL},
   {d_billedit_proc, (CENTER_X(240) + 216), (CENTER_Y(140) + 38), 16, 12, 0, 0, 0, 0, 1, 0, nl_levelbuf, NULL, NULL},
   {d_billbutton_proc, (CENTER_X(240) + 8), (CENTER_Y(140) + 120), 80, 16, 0, 0, 0, D_EXIT, 0, 0, "OK", NULL, NULL},
   {d_billbutton_proc, (CENTER_X(240) + 152), (CENTER_Y(140) + 120), 80, 16, 0, 0, 0, D_EXIT, 0, 0, "Cancel", NULL, NULL},
   {NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, NULL, NULL, NULL}
};

DIALOG load_from_offset_dialog[] = {
   {d_billwin_proc, CENTER_X(240), CENTER_Y(180), 240, 180, 28, 2, 0, 0, 0, 0, "Load Level from Offset", NULL, NULL},
   {d_billtext_proc, (CENTER_X(240) + 8), (CENTER_Y(180) + 18), 0, 0, 0, 0, 0, 0, 0, 0, "Level Offset: ", NULL, NULL},
   {d_billtext_proc, (CENTER_X(240) + 8), (CENTER_Y(180) + 38), 0, 0, 0, 0, 0, 0, 0, 0, "Enemy Offset: ", NULL, NULL},
   {d_billtext_proc, (CENTER_X(240) + 8), (CENTER_Y(180) + 58), 0, 0, 0, 0, 0, 0, 0, 0, "World #: ", NULL, NULL},
   {d_billtext_proc, (CENTER_X(240) + 8), (CENTER_Y(180) + 78), 0, 0, 0, 0, 0, 0, 0, 0, "Level #: ", NULL, NULL},
   {d_billtext_proc, (CENTER_X(240) + 8), (CENTER_Y(180) + 98), 0, 0, 0, 0, 0, 0, 0, 0, "Object Set: ", NULL, NULL},
   {d_billlist_proc, (CENTER_X(240) + 8), (CENTER_Y(180) + 108), 224, 48, 0, 0, 0, 0, 0, 0, object_set_getter, NULL, NULL},
   {d_billedit_proc, (CENTER_X(240) + 192), (CENTER_Y(180) + 18), 40, 12, 0, 0, 0, 0, 6, 0, leveloffsetbuf, NULL, NULL},
   {d_billedit_proc, (CENTER_X(240) + 192), (CENTER_Y(180) + 38), 40, 12, 0, 0, 0, 0, 6, 0, enemyoffsetbuf, NULL, NULL},
   {d_billedit_proc, (CENTER_X(240) + 216), (CENTER_Y(180) + 58), 16, 12, 0, 0, 0, 0, 2, 0, llfo_worldbuf, NULL, NULL},
   {d_billedit_proc, (CENTER_X(240) + 216), (CENTER_Y(180) + 78), 16, 12, 0, 0, 0, 0, 1, 0, llfo_levelbuf, NULL, NULL},
   {d_billbutton_proc, (CENTER_X(240) + 8), (CENTER_Y(180) + 160), 80, 16, 0, 0, 0, D_EXIT, 0, 0, "OK", NULL, NULL},
   {d_billbutton_proc, (CENTER_X(240) + 152), (CENTER_Y(180) + 160), 80, 16, 0, 0, 0, D_EXIT, 0, 0, "Cancel", NULL, NULL},
   {NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, NULL, NULL, NULL}
};


DIALOG pointer_dialog[] = {
//dialog proc       x    y    w    h    fg  bg  key  flags   d1   d2   dp         dp2       dp3
   {d_billwin_proc, CENTER_X(316), CENTER_Y(108), 316, 108, 28, 2, 0, 0, 0, 0, NULL, NULL, NULL},
   {d_billtext_proc, (CENTER_X(316) + 8), (CENTER_Y(108) + 18), 0, 0, 0, 0, 0, 0, 0, 0, NULL, NULL, NULL},	//Level ROM Location
   {d_billtext_proc, (CENTER_X(316) + 8), (CENTER_Y(108) + 28), 0, 0, 0, 0, 0, 0, 0, 0, NULL, NULL, NULL},	//Level:
   {d_billtext_proc, (CENTER_X(316) + 8), (CENTER_Y(108) + 38), 0, 0, 0, 0, 0, 0, 0, 0, NULL, NULL, NULL},	//Enemy ROM Location
   {d_billtext_proc, (CENTER_X(316) + 8), (CENTER_Y(108) + 48), 0, 0, 0, 0, 0, 0, 0, 0, NULL, NULL, NULL},	//Enemy Level:
   {d_billtext_proc, (CENTER_X(316) + 8), (CENTER_Y(108) + 58), 0, 0, 0, 0, 0, 0, 0, 0, NULL, NULL, NULL},	//Level Object Set
   {d_callback_billbutton_proc, (CENTER_X(316) + 216), (CENTER_Y(108) + 18), 92, 16, 0, 0, 0, 0, 0, 0, "Change Level...", change_level_rom_offset, NULL},
   {d_callback_billbutton_proc, (CENTER_X(316) + 216), (CENTER_Y(108) + 38), 92, 16, 0, 0, 0, 0, 0, 0, "Change Enemies...", change_enemy_rom_offset, NULL},
   {d_callback_billbutton_proc, (CENTER_X(316) + 8), (CENTER_Y(108) + 68), 120, 16, 0, 0, 0, 0, 0, 0, "Change Object Set...", change_object_set, NULL},
   {d_billbutton_proc, (CENTER_X(316) + 8), (CENTER_Y(108) + 88), 80, 16, 0, 0, 0, D_EXIT, 0, 0, "OK", NULL, NULL},
   {d_billbutton_proc, (CENTER_X(316) + 228), (CENTER_Y(108) + 88), 80, 16, 0, 0, 0, D_EXIT, 0, 0, "Cancel", NULL, NULL},
   {d_billbutton_proc, (CENTER_X(316) + 98), (CENTER_Y(108) + 88), 120, 16, 0, 0, 0, D_EXIT, 0, 0, "Edit This Level", NULL, NULL},
   {NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, NULL, NULL, NULL}
};

DIALOG pointer_dialog_2[] = {
//dialog proc       x    y    w    h    fg  bg  key  flags   d1   d2   dp         dp2       dp3
   {d_billwin_proc, CENTER_X(316), CENTER_Y(108), 316, 108, 28, 2, 0, 0, 0, 0, NULL, NULL, NULL},
   {d_billtext_proc, (CENTER_X(316) + 8), (CENTER_Y(108) + 18), 0, 0, 0, 0, 0, 0, 0, 0, NULL, NULL, NULL},	//Level ROM Location
   {d_billtext_proc, (CENTER_X(316) + 8), (CENTER_Y(108) + 28), 0, 0, 0, 0, 0, 0, 0, 0, NULL, NULL, NULL},	//Level:
   {d_billtext_proc, (CENTER_X(316) + 8), (CENTER_Y(108) + 38), 0, 0, 0, 0, 0, 0, 0, 0, NULL, NULL, NULL},	//Enemy ROM Location
   {d_billtext_proc, (CENTER_X(316) + 8), (CENTER_Y(108) + 48), 0, 0, 0, 0, 0, 0, 0, 0, NULL, NULL, NULL},	//Enemy Level:
   {d_billtext_proc, (CENTER_X(316) + 8), (CENTER_Y(108) + 58), 0, 0, 0, 0, 0, 0, 0, 0, NULL, NULL, NULL},	//Level Object Set
   {d_callback_billbutton_proc, (CENTER_X(316) + 216), (CENTER_Y(108) + 18), 92, 16, 0, 0, 0, 0, 0, 0, "Change Level...", change_level_rom_offset_2, NULL},
   {d_callback_billbutton_proc, (CENTER_X(316) + 216), (CENTER_Y(108) + 38), 92, 16, 0, 0, 0, 0, 0, 0, "Change Enemies...", change_enemy_rom_offset_2, NULL},
   {d_callback_billbutton_proc, (CENTER_X(316) + 8), (CENTER_Y(108) + 68), 120, 16, 0, 0, 0, 0, 0, 0, "Change Object Set...", change_object_set_2, NULL},
   {d_billbutton_proc, (CENTER_X(316) + 8), (CENTER_Y(108) + 88), 80, 16, 0, 0, 0, D_EXIT, 0, 0, "OK", NULL, NULL},
   {d_billbutton_proc, (CENTER_X(316) + 228), (CENTER_Y(108) + 88), 80, 16, 0, 0, 0, D_EXIT, 0, 0, "Cancel", NULL, NULL},
   {d_billbutton_proc, (CENTER_X(316) + 98), (CENTER_Y(108) + 88), 120, 16, 0, 0, 0, D_EXIT, 0, 0, "Edit This Level", NULL, NULL},
   {NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, NULL, NULL, NULL}
};


DIALOG object_set_dialog[] =
//dialog proc       x    y    w    h    fg  bg  key  flags   d1   d2   dp         dp2       dp3
{
   {d_billwin_proc, CENTER_X(200), CENTER_Y(120), 200, 120, 28, 2, 0, 0, 0, 0, "Select Object Set", NULL, NULL},
   {d_billlist_proc, (CENTER_X(200) + 8), (CENTER_Y(120) + 16), 184, 80, 28, 2, 0, 0, 0, 0, object_set_getter_ex, NULL, NULL},
   {d_billbutton_proc, (CENTER_X(200) + 8), (CENTER_Y(120) + 101), 80, 16, 28, 2, 0, D_EXIT, 0, 0, "OK", NULL, NULL},
   {d_billbutton_proc, (CENTER_X(200) + 200 - 88), (CENTER_Y(120) + 101), 80, 16, 28, 2, 0, D_EXIT, 0, 0, "Cancel", NULL, NULL},
   {NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, NULL, NULL, NULL}
};

DIALOG object_set_dialog_2[] =
//dialog proc       x    y    w    h    fg  bg  key  flags   d1   d2   dp         dp2       dp3
{
   {d_billwin_proc, CENTER_X(200), CENTER_Y(120), 200, 120, 28, 2, 0, 0, 0, 0, "Select Object Set", NULL, NULL},
   {d_billlist_proc, (CENTER_X(200) + 8), (CENTER_Y(120) + 16), 184, 80, 28, 2, 0, 0, 0, 0, object_set_getter, NULL, NULL},
   {d_billbutton_proc, (CENTER_X(200) + 8), (CENTER_Y(120) + 101), 80, 16, 28, 2, 0, D_EXIT, 0, 0, "OK", NULL, NULL},
   {d_billbutton_proc, (CENTER_X(200) + 200 - 88), (CENTER_Y(120) + 101), 80, 16, 28, 2, 0, D_EXIT, 0, 0, "Cancel", NULL, NULL},
   {NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, NULL, NULL, NULL}
};

DIALOG mushroom_house_dialog[] =
//dialog proc       x    y    w    h    fg  bg  key  flags   d1   d2   dp         dp2       dp3
{
   {d_billwin_proc, CENTER_X(200), CENTER_Y(120), 200, 120, 28, 2, 0, 0, 0, 0, "Select Mushroom House Type", NULL, NULL},
   {d_billlist_proc, (CENTER_X(200) + 8), (CENTER_Y(120) + 16), 184, 80, 28, 2, 0, 0, 0, 0, mushroom_house_type_getter, NULL, NULL},
   {d_billbutton_proc, (CENTER_X(200) + 8), (CENTER_Y(120) + 101), 80, 16, 28, 2, 0, D_EXIT, 0, 0, "OK", NULL, NULL},
   {d_billbutton_proc, (CENTER_X(200) + 200 - 88), (CENTER_Y(120) + 101), 80, 16, 28, 2, 0, D_EXIT, 0, 0, "Cancel", NULL, NULL},
   {NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, NULL, NULL, NULL}
};

DIALOG music_dialog[] =
//dialog proc       x    y    w    h    fg  bg  key  flags   d1   d2   dp         dp2       dp3
{
   {d_billwin_proc, CENTER_X(200), CENTER_Y(120), 200, 120, 28, 2, 0, 0, 0, 0, "Music", NULL, NULL},
   {d_billlist_proc, (CENTER_X(200) + 8), (CENTER_Y(120) + 16), 184, 80, 28, 2, 0, 0, 0, 0, music_getter, NULL, NULL},
   {d_billbutton_proc, (CENTER_X(200) + 8), (CENTER_Y(120) + 101), 80, 16, 28, 2, 0, D_EXIT, 0, 0, "OK", NULL, NULL},
   {d_billbutton_proc, (CENTER_X(200) + 200 - 88), (CENTER_Y(120) + 101), 80, 16, 28, 2, 0, D_EXIT, 0, 0, "Cancel", NULL, NULL},
   {NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, NULL, NULL, NULL}
};

DIALOG gfx_dialog[] =
//dialog proc       x    y    w    h    fg  bg  key  flags   d1   d2   dp         dp2       dp3
{
   {d_billwin_proc, CENTER_X(200), CENTER_Y(160), 200, 160, 28, 2, 0, 0, 0, 0, "Graphics", NULL, NULL},
   {d_billlist_proc, (CENTER_X(200) + 8), (CENTER_Y(160) + 20), 184, 112, 28, 2, 0, 0, 0, 0, gfx_getter, NULL, NULL},
   {d_billbutton_proc, (CENTER_X(200) + 8), (CENTER_Y(160) + 140), 80, 16, 0, 0, 0, D_EXIT, 0, 0, "OK", NULL, NULL},
   {d_billbutton_proc, (CENTER_X(200) + 200 - 88), (CENTER_Y(160) + 140), 80, 16, 0, 0, 0, D_EXIT, 0, 0, "Cancel", NULL, NULL},
   {NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, NULL, NULL, NULL}
};


DIALOG palette_dialog[] =
//dialog proc       x    y    w    h    fg  bg  key  flags   d1   d2   dp         dp2       dp3
{
   {d_billwin_proc, CENTER_X(300), CENTER_Y(160), 300, 160, 28, 2, 0, 0, 0, 0, "Palette", NULL, NULL},
   {d_billlist_proc, (CENTER_X(300) + 8), (CENTER_Y(160) + 20), 124, 80, 28, 2, 0, 0, 0, 0, palette_getter, NULL, NULL},
   {d_billtext_proc, (CENTER_X(300) + 144), (CENTER_Y(160) + 20), 0, 0, 28, 2, 0, 0, 0, 0, "Preview:", NULL, NULL},
   {d_bitmap_proc, (CENTER_X(300) + 144), (CENTER_Y(160) + 30), 144, 96, 28, 2, 0, 0, 0, 0, NULL, NULL, NULL},
   {d_billbutton_proc, (CENTER_X(300) + 8), (CENTER_Y(160) + 140), 80, 16, 0, 0, 0, D_EXIT, 0, 0, "OK", NULL, NULL},
   {d_billbutton_proc, (CENTER_X(300) + 300 - 88), (CENTER_Y(160) + 140), 80, 16, 0, 0, 0, D_EXIT, 0, 0, "Cancel", NULL, NULL},
   {d_billradio_proc, (CENTER_X(300) + 8), (CENTER_Y(160) + 104), 10, 10, 0, 0, 'b', 0, 0, 0, "&Black enemies", NULL, NULL},
   {d_billradio_proc, (CENTER_X(300) + 8), (CENTER_Y(160) + 116), 10, 10, 0, 0, 'l', 0, 0, 0, "B&lueish enemies", NULL, NULL},
   {NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, NULL, NULL, NULL}
};

DIALOG scroll_dialog[] =
//dialog proc       x    y    w    h    fg  bg  key  flags   d1   d2   dp         dp2       dp3
{
   {d_billwin_proc, CENTER_X(200), CENTER_Y(120), 200, 120, 28, 2, 0, 0, 0, 0, "Scrolling", NULL, NULL},
   {d_billlist_proc, (CENTER_X(200) + 8), (CENTER_Y(120) + 16), 184, 80, 28, 2, 0, 0, 0, 0, scroll_getter, NULL, NULL},
   {d_billbutton_proc, (CENTER_X(200) + 8), (CENTER_Y(120) + 101), 80, 16, 28, 2, 0, D_EXIT, 0, 0, "OK", NULL, NULL},
   {d_billbutton_proc, (CENTER_X(200) + 200 - 88), (CENTER_Y(120) + 101), 80, 16, 28, 2, 0, D_EXIT, 0, 0, "Cancel", NULL, NULL},
   {NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, NULL, NULL, NULL}
};

DIALOG length_dialog[] = {
//dialog proc       x    y    w    h    fg  bg  key  flags   d1   d2   dp         dp2       dp3
   {d_billwin_proc, CENTER_X(300), CENTER_Y(176), 300, 176, 28, 2, 0, 0, 0, 0, "Misc Level Options", NULL, NULL},
   {d_billtext_proc, (CENTER_X(300) + 50), (CENTER_Y(176) + 18), 0, 0, 0, 0, 0, 0, 0, 0, NULL, NULL, NULL},
   {d_billslider_proc, (CENTER_X(300) + 8), (CENTER_Y(176) + 30), 120, 10, 0, 0, 'l', 0, 0xF, 0, NULL, NULL, NULL},
   {d_billtext_proc, (CENTER_X(300) + 115), (CENTER_Y(176) + 58), 0, 0, 0, 0, 0, 0, 0, 0, NULL, NULL, NULL},
   {d_billslider_proc, (CENTER_X(300) + 8), (CENTER_Y(176) + 70), 120, 10, 0, 0, 'v', 0, 0xF, 0, NULL, NULL, NULL},
   {d_billtext_proc, (CENTER_X(300) + 8), (CENTER_Y(176) + 80), 0, 0, 0, 0, 0, 0, 0, 0, "High", NULL, NULL},
   {d_billtext_proc, (CENTER_X(300) + 112), (CENTER_Y(176) + 80), 0, 0, 0, 0, 0, 0, 0, 0, "Low", NULL, NULL},
   {d_billbutton_proc, (CENTER_X(300) + 8), (CENTER_Y(176) + 156), 80, 16, 0, 0, 0, D_EXIT, 0, 0, "OK", NULL, NULL},
   {d_billbutton_proc, (CENTER_X(300) + 300 - 88), (CENTER_Y(176) + 156), 80, 16, 0, 0, 0, D_EXIT, 0, 0, "Cancel", NULL, NULL},
   {d_billtext_proc, (CENTER_X(300) + 8), (CENTER_Y(176) + 40), 0, 0, 0, 0, 0, 0, 0, 0, "Short", NULL, NULL},
   {d_billtext_proc, (CENTER_X(300) + 108), (CENTER_Y(176) + 40), 0, 0, 0, 0, 0, 0, 0, 0, "Long", NULL, NULL},
   {d_billtext_proc, (CENTER_X(300) + 120), (CENTER_Y(176) + 98), 0, 0, 0, 0, 0, 0, 0, 0, NULL, NULL, NULL},
   {d_billslider_proc, (CENTER_X(300) + 8), (CENTER_Y(176) + 110), 120, 10, 0, 0, 'h', 0, 0x7, 0, NULL, NULL, NULL},
   {d_billtext_proc, (CENTER_X(300) + 8), (CENTER_Y(176) + 120), 0, 0, 0, 0, 0, 0, 0, 0, "Left", NULL, NULL},
   {d_billtext_proc, (CENTER_X(300) + 104), (CENTER_Y(176) + 120), 0, 0, 0, 0, 0, 0, 0, 0, "Right", NULL, NULL},
   {d_billcheck_proc, (CENTER_X(300) + 154), (CENTER_Y(176) + 110), 10, 10, 0, 0, 'w', 0, 0, 0, "", NULL, NULL},
   {d_billtext_proc, (CENTER_X(300) + 172), (CENTER_Y(176) + 110), 0, 0, 0, 0, 0, 0, 0, 0, "&Weird colored enemies", NULL, NULL},
   {d_billlist_proc, (CENTER_X(300) + 147), (CENTER_Y(176) + 30), 146, 70, 0, 0, 's', 0, 0, 0, action_getter, NULL, NULL},
   {d_billtext_proc, (CENTER_X(300) + 147), (CENTER_Y(176) + 20), 0, 0, 0, 0, 0, 0, 0, 0, "Starting Action: ", NULL, NULL},
   {d_billtext_proc, (CENTER_X(300) + 8), (CENTER_Y(176) + 18), 0, 0, 0, 0, 0, 0, 0, 0, "&Length: ", NULL, NULL},
   {d_billtext_proc, (CENTER_X(300) + 8), (CENTER_Y(176) + 58), 0, 0, 0, 0, 0, 0, 0, 0, "&Vert. Starting Pos.: ", NULL, NULL},
   {d_billtext_proc, (CENTER_X(300) + 8), (CENTER_Y(176) + 98), 0, 0, 0, 0, 0, 0, 0, 0, "&Horiz. Starting Pos.: ", NULL, NULL},
   {d_billtext_proc, (CENTER_X(300) + 8), (CENTER_Y(176) + 132), 0, 0, 0, 0, 0, 0, 0, 0, "Time: ", NULL, NULL},
   {d_billradio_proc, (CENTER_X(300) + 40), (CENTER_Y(176) + 132), 10, 10, 0, 0, '3', 0, 0, 0, "&300", NULL, NULL},
   {d_billradio_proc, (CENTER_X(300) + 80), (CENTER_Y(176) + 132), 10, 10, 0, 0, '4', 0, 0, 0, "&400", NULL, NULL},
   {d_billradio_proc, (CENTER_X(300) + 120), (CENTER_Y(176) + 132), 10, 10, 0, 0, '2', 0, 0, 0, "&200", NULL, NULL},
   {d_billradio_proc, (CENTER_X(300) + 160), (CENTER_Y(176) + 132), 10, 10, 0, 0, 'u', 0, 0, 0, "&Unlimited", NULL, NULL},
   {NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, NULL, NULL, NULL}
};

DIALOG options_dialog[] = {
//dialog proc       x    y    w    h    fg  bg  key  flags   d1   d2   dp         dp2       dp3
   {d_billwin_proc, 10, 56, 300, 128, 28, 2, 0, 0, 0, 0, "Mario Improvement 3 Options", NULL, NULL},
   {d_billctext_proc, 160, 71, 0, 0, 28, 2, 0, 0, 0, 0, "", NULL, NULL},
   {d_billcheck_proc, 20, 78, 10, 10, 28, 2, 'w', D_SELECTED, 0, 0, "", NULL, NULL},
   {d_billtext_proc, 42, 78, 0, 0, 28, 2, 0, 0, 0, 0, "&Warn if Level Not Saved", NULL, NULL},
   {d_billcheck_proc, 20, 90, 10, 10, 28, 2, 'x', D_SELECTED, 0, 0, "", NULL, NULL},
   {d_billtext_proc, 42, 90, 0, 0, 28, 2, 0, 0, 0, 0, "Warn on E&xit", NULL, NULL},
   {d_billcheck_proc, 20, 102, 10, 10, 28, 2, 'm', D_SELECTED, 0, 0, "", NULL, NULL},
   {d_billtext_proc, 42, 102, 0, 0, 28, 2, 0, 0, 0, 0, "&Mouse Scrolling", NULL, NULL},
   {d_billcheck_proc, 20, 114, 10, 10, 28, 2, 'r', 0, 0, 0, "", NULL, NULL},
   {d_billtext_proc, 42, 114, 0, 0, 28, 2, 0, 0, 0, 0, "&Reset Coordinates when Loading Levels", NULL, NULL},
   {d_billcheck_proc, 20, 126, 10, 10, 28, 2, 'd', 0, 0, 0, "", NULL, NULL},
   {d_billtext_proc, 42, 126, 0, 0, 28, 2, 0, 0, 0, 0, "&Display 3-byte objects on top of 4-byte", NULL, NULL},
   {d_billcheck_proc, 20, 138, 10, 10, 28, 2, 'a', D_SELECTED, 0, 0, "", NULL, NULL},
   {d_billtext_proc, 42, 138, 0, 0, 28, 2, 0, 0, 0, 0, "&Automatically sort enemies", NULL, NULL},
   {d_billbutton_proc, 72, 156, 80, 16, 28, 2, 13, D_EXIT, 0, 0, "OK", NULL, NULL},
   {d_billbutton_proc, 168, 156, 80, 16, 28, 2, 27, D_EXIT, 0, 0, "Cancel", NULL, NULL},
   {NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, NULL, NULL, NULL}
};


DIALOG level_chooser_dialog[] = {
//dialog proc       x    y    w    h    fg  bg  key  flags   d1   d2   dp         dp2       dp3
   {d_billwin_proc, 10, 37, 300, 166, 28, 2, 0, 0, 0, 0, "World/Level Select", NULL, NULL},
   {d_billctext_proc, 160, 47, 0, 0, 28, 2, 0, 0, 0, 0, "", NULL, NULL},
   {d_billtext_proc, 20, 57, 0, 0, 28, 2, 0, 0, 0, 0, "World:", NULL, NULL},
   {d_billtext_proc, 160, 57, 0, 0, 28, 2, 0, 0, 0, 0, "Level:", NULL, NULL},
   {d_billlist_proc, 20, 67, 120, 100, 28, 2, 'w', 0, 0, 0, world_getter, NULL, NULL},
   {d_billlist_proc, 160, 67, 120, 100, 28, 2, 'l', 0, 0, 0, level_getter, NULL, NULL},
   {d_billbutton_proc, 72, 177, 80, 16, 28, 2, 0, D_EXIT, 0, 0, "OK", NULL, NULL},
   {d_billbutton_proc, 168, 177, 80, 16, 28, 2, 0, D_EXIT, 0, 0, "Cancel", NULL, NULL},
//{updater_proc,      0,   0,   0,   0,   0,   0,  0,  0,       0,   0,   NULL,   NULL, NULL},
   {NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, NULL, NULL, NULL}
};

DIALOG level_chooser_dialog_ex[] = {
//dialog proc       x    y    w    h    fg  bg  key  flags   d1   d2   dp         dp2       dp3
   {d_billwin_proc, 10, 37, 300, 166, 28, 2, 0, 0, 0, 0, "World/Level Select", NULL, NULL},
   {d_billctext_proc, 160, 47, 0, 0, 28, 2, 0, 0, 0, 0, "", NULL, NULL},
   {d_billtext_proc, 20, 57, 0, 0, 28, 2, 0, 0, 0, 0, "World:", NULL, NULL},
   {d_billtext_proc, 160, 57, 0, 0, 28, 2, 0, 0, 0, 0, "Level:", NULL, NULL},
   {d_billlist_proc, 20, 67, 120, 100, 28, 2, 'w', 0, 0, 0, world_getter_ex, NULL, NULL},
   {d_billlist_proc, 160, 67, 120, 100, 28, 2, 'l', 0, 0, 0, level_getter, NULL, NULL},
   {d_billbutton_proc, 18, 177, 80, 16, 28, 2, 0, D_EXIT, 0, 0, "OK", NULL, NULL},
   {d_billbutton_proc, 222, 177, 80, 16, 28, 2, 0, D_EXIT, 0, 0, "Cancel", NULL, NULL},
   {d_billbutton_proc, 110, 177, 100, 16, 28, 2, 0, D_EXIT, 0, 0, "Specify Offset", NULL, NULL},
//{updater_proc,      0,   0,   0,   0,   0,   0,  0,  0,       0,   0,   NULL,   NULL, NULL},
   {NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, NULL, NULL, NULL}
};

DIALOG level_stats_dialog[] = {
//dialog proc       x    y    w    h    fg  bg  key  flags   d1   d2   dp         dp2       dp3
   {d_billwin_proc, 32, 62, 256, 116, 28, 2, 0, 0, 0, 0, "Level Properties", NULL, NULL},
   {d_billctext_proc, 160, 72, 0, 0, 28, 2, 0, 0, 0, 0, "", NULL, NULL},
   {d_billtext_proc, 40, 82, 0, 0, 28, 2, 0, 0, 0, 0, "World:", NULL, NULL},
   {d_billtext_proc, 82, 82, 0, 0, 28, 2, 0, 0, 0, 0, NULL, NULL, NULL},
   {d_billtext_proc, 118, 82, 0, 0, 28, 2, 0, 0, 0, 0, "ROM Offset:", NULL, NULL},
   {d_billtext_proc, 190, 82, 0, 0, 28, 2, 0, 0, 0, 0, NULL, NULL, NULL},
   {d_billtext_proc, 40, 92, 0, 0, 28, 2, 0, 0, 0, 0, "Object Set:", NULL, NULL},
   {d_billtext_proc, 112, 92, 0, 0, 28, 2, 0, 0, 0, 0, NULL, NULL, NULL},
   {d_billtext_proc, 40, 102, 0, 0, 28, 2, 0, 0, 0, 0, "Total Number of Objects:", NULL, NULL},
   {d_billtext_proc, 190, 102, 0, 0, 28, 2, 0, 0, 0, 0, NULL, NULL, NULL},
   {d_billtext_proc, 50, 112, 0, 0, 28, 2, 0, 0, 0, 0, "4-byte:", NULL, NULL},
   {d_billtext_proc, 122, 112, 0, 0, 28, 2, 0, 0, 0, 0, "3-byte:", NULL, NULL},
   {d_billtext_proc, 194, 112, 0, 0, 28, 2, 0, 0, 0, 0, "Enemies:", NULL, NULL},
   {d_billtext_proc, 98, 112, 0, 0, 28, 2, 0, 0, 0, 0, NULL, NULL, NULL},
   {d_billtext_proc, 170, 112, 0, 0, 28, 2, 0, 0, 0, 0, NULL, NULL, NULL},
   {d_billtext_proc, 248, 112, 0, 0, 28, 2, 0, 0, 0, 0, NULL, NULL, NULL},
   {d_billtext_proc, 40, 122, 0, 0, 28, 2, 0, 0, 0, 0, "Size in Bytes:", NULL, NULL},
   {d_billtext_proc, 130, 122, 0, 0, 28, 2, 0, 0, 0, 0, NULL, NULL, NULL},
   {d_billtext_proc, 40, 132, 0, 0, 28, 2, 0, 0, 0, 0, "Enemy Offset:", NULL, NULL},
   {d_billtext_proc, 124, 132, 0, 0, 28, 2, 0, 0, 0, 0, NULL, NULL, NULL},
   {d_billtext_proc, 40, 142, 0, 0, 28, 2, 0, 0, 0, 0, "Size of Enemy Data:", NULL, NULL},
   {d_billtext_proc, 160, 142, 0, 0, 28, 2, 0, 0, 0, 0, NULL, NULL, NULL},
   {d_billbutton_proc, 120, 152, 80, 16, 28, 2, 0, D_EXIT, 0, 0, "OK", NULL, NULL},
   {NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, NULL, NULL, NULL}
};

DIALOG help_dialog[] = {
//dialog proc       x    y    w    h    fg  bg  key  flags   d1   d2   dp         dp2       dp3
   {d_billwin_proc, 0, 0, 320, 240, 28, 2, 0, 0, 0, 0, "Mario Improvement 3 Help", NULL, NULL},
   {d_billctext_proc, 160, 10, 0, 0, 28, 2, 0, 0, 0, 0, "", NULL, NULL},
   {d_billtextbox_proc, 10, 20, 300, 160, 28, 2, 0, 0, 0, 0, NULL, NULL, NULL},
   {d_billbutton_proc, 220, 212, 80, 16, 28, 2, 0, D_EXIT, 0, 0, "Close", NULL, NULL},
   {NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, NULL, NULL, NULL}
};


DIALOG about_dialog[] = {
//dialog proc       x    y    w    h    fg  bg  key  flags   d1   d2   dp         dp2       dp3
   {d_box_proc, 32, 8, 256, 224, 28, 2, 0, 0, 0, 0, "About Mario Improvement 3", NULL, NULL},
   {d_ctext_proc, 160, 14, 0, 0, 28, 2, 0, 0, 0, 0, "", NULL, NULL},
   {d_bitmap_proc, 40, 24, 128, 176, 28, 2, 0, 0, 0, 0, NULL, NULL, NULL},
   {d_text_proc, 176, 24, 0, 0, 28, 2, 0, 0, 0, 0, "       Mario       ", NULL, NULL},
   {d_text_proc, 176, 34, 0, 0, 28, 2, 0, 0, 0, 0, "   Improvement 3   ", NULL, NULL},
   {d_text_proc, 176, 44, 0, 0, 28, 2, 0, 0, 0, 0, " SMB3 Level Editor ", NULL, NULL},
   {d_text_proc, 176, 54, 0, 0, 28, 2, 0, 0, 0, 0, "    Version 0.95   ", NULL, NULL},
   {d_text_proc, 176, 64, 0, 0, 28, 2, 0, 0, 0, 0, "     DOS 32-bit    ", NULL, NULL},
   {d_text_proc, 176, 74, 0, 0, 28, 2, 0, 0, 0, 0, "Copyright 1999-2000", NULL, NULL},
   {d_text_proc, 176, 84, 0, 0, 28, 2, 0, 0, 0, 0, "   by LincolnSoft  ", NULL, NULL},
   {d_text_proc, 176, 94, 0, 0, 28, 2, 0, 0, 0, 0, "Compiled with BGUI,", NULL, NULL},
   {d_text_proc, 176, 104, 0, 0, 28, 2, 0, 0, 0, 0, "DJGPP, and Allegro ", NULL, NULL},
   {d_text_proc, 176, 114, 0, 0, 28, 2, 0, 0, 0, 0, "   Coded by Abe    ", NULL, NULL},
   {d_text_proc, 176, 124, 0, 0, 28, 2, 0, 0, 0, 0, "   July 22, 2000   ", NULL, NULL},
   {d_text_proc, 176, 134, 0, 0, 28, 2, 0, 0, 0, 0, "     Thanks to     ", NULL, NULL},
   {d_text_proc, 176, 144, 0, 0, 28, 2, 0, 0, 0, 0, "MarioExpert for the", NULL, NULL},
   {d_text_proc, 176, 154, 0, 0, 28, 2, 0, 0, 0, 0, " Allstars and \"Lost", NULL, NULL},
   {d_text_proc, 176, 164, 0, 0, 28, 2, 0, 0, 0, 0, "  Levels\" offsets. ", NULL, NULL},
   {d_text_proc, 40, 200, 0, 0, 28, 2, 0, 0, 0, 0, "abe@lincolnsoft.com", NULL, NULL},
   {d_text_proc, 40, 210, 0, 0, 28, 2, 0, 0, 0, 0, "http://www.lincolnsoft.com/", NULL, NULL},
   {d_billbutton_proc, 188, 188, 80, 16, 28, 2, 0, D_EXIT, 0, 0, "OK", NULL, NULL},
   {NULL, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, NULL, NULL, NULL}
};








int main(int argc, char *argv[])
{
   int mouse;

   if (argc > 1)
      {
	 strcpy(romfile, argv[1]);
	 arg_flag = TRUE;
      }

   allegro_init();

   install_keyboard();
   install_timer();
   mouse = install_mouse();
   if (mouse < 0)
      {
	 printf("Error: Mouse driver not loaded!\n");
	 exit(1);
      }

   //set VGA mode x resolution 320 by 240 pixels with 352 by 744 pixel virtual screen
   set_gfx_mode(GFX_MODEX, 320, 240, 352, 744);

   getwd(m3l_filename);
   put_backslash(m3l_filename);
   getwd(savetoromfile);
   put_backslash(savetoromfile);

   buffer = create_sub_bitmap(screen, 0, 256, 352, 184);
   if (buffer == NULL)
      {
	 printf("Error allocating buffer");
	 exit(1);
      }
   clear(buffer);

   status_display = create_sub_bitmap(screen, 0, 200, 320, 40);
   if (status_display == NULL)
      {
	 printf("Error allocating status display");
	 exit(1);
      }

   clear(status_display);

   main_display = create_sub_bitmap(screen, 0, 0, 352, 240);
   if (main_display == NULL)
      {
	 printf("Error allocating main display");
	 exit(1);
      }
   clear(main_display);

   obj_01_data = load_datafile("#");
   if (obj_01_data == NULL)
      {
	 printf("Error loading datafile");
	 exit(1);
      }
   else
      {
	 set_pallete((RGB *) obj_01_data[256 + (257 * level_object_set)].dat);
	 font = obj_01_data[3084].dat;
	 previews = (DATAFILE *) obj_01_data[3087].dat;
	 create_trans_table(&trans_table, (RGB *) obj_01_data[256 + (257 * level_object_set)].dat, 128, 128, 128, NULL);
	 color_map = &trans_table;
      }

   bill_init();
   bill_init_smallpal(80);

   mouse_cursor = create_bitmap(16, 16);
   clear(mouse_cursor);
   draw_sprite(mouse_cursor, obj_01_data[154 + (257 * level_object_set)].dat, 0, 0);
   set_mouse_speed(2, 2);
   position_mouse(((cursor_x - x_screen_loc) * 16), ((cursor_y - y_screen_loc) * 16));

   if (arg_flag)
      load_romfile_new();

   edit_level();
   unload_datafile(obj_01_data);
   close(mario3rom);
   allegro_exit();
   gotoxy(1, 1);
   cprintf("Mario Improvement 3 v0.95   Copyright(C) 1999-2000 LincolnSoft.");
   gotoxy(1, 2);
   cprintf("http://www.lincolnsoft.com/");
   gotoxy(1, 3);

   return 0;
}


void blit_screen()
{
   blit(buffer, main_display, 0, 0, 0, 16, 320, 200);
}

void
redraw_screen()
{
//This function refreshes the screen when it needs to be (i.e. if the user
//changes an object, if a new level is selected, or if the screen scrolls.)
//This function is a total mess and needs to be rewritten....

   MAX255 i;
   int e;
   int n;
   int o;
   int object;
   MAX255 domain;
   MAX255 length;
   MAX255 g;
   MAX255 h;
   MAX255 j;
   MAX255 k;
   MAX255 l;
   int p_ctr;
   MAX255 m;
   MAX255 a;
   MAX255 l_counter;
   MAX64K w_counter;
   int tbyte_drawn = FALSE;
   int x_position;
   int y_position;

//Check to see whether level is a vertical level.
//You can't edit headers in Mario Allstars so those levels will still
//be displayed horizontally, regardless if the level is vertical or not.

   if ((!mapedit_flag) && (!allstars_flag))
      {
	 if (((header[6] / 16) % 2) == 1)
	    vertical_flag = TRUE;
	 else
	    vertical_flag = FALSE;
      }
   else
      vertical_flag = FALSE;


   if (file_loaded == FALSE)
      {
	 rectfill(buffer, 0, 0, 352, 200, 0);
	 textprintf(status_display, font, 0, 0, 28, "No file loaded.");
	 goto skipsidescroll;
      }



   if (mapedit_flag == TRUE)
      {
//Screen refreshing function for mapscreen mode.
//Draw map screen
	 for (i = 0; i < (16 * (level_bytes / 144)); i++)
	    {
	       for (j = 0; j < 9; j++)
		  {
		     object = maparray[j][i];
		     if (maparray[j][i] <= 236)
			draw_sprite(buffer, obj_01_data[plains_level[0][object].obj_design[0]].dat, (16 * (i - x_screen_loc)), (16 * (j - y_screen_loc)));
		     else
			draw_sprite(buffer, obj_01_data[plains_level[0][236].obj_design[0]].dat, (16 * (i - x_screen_loc)), (16 * (j - y_screen_loc)));
		  }
	    }

//Draw sprites (except if on Warp Zone map, which has no sprites, or
//if you're editing Mario Allstars, which has no map sprite support.)

	 if ((!allstars_flag) && (level != 9))
	    {
	       for (i = 0; i < 9; i++)
		  {
		     if (map_sprites[i][3] < 0x11)
			draw_sprite(buffer, obj_01_data[map_sprites[i][3] + 170].dat, (16 * (((map_sprites[i][2] / 16) + (map_sprites[i][1] * 16)) - x_screen_loc)), (16 * (((map_sprites[i][0] / 16) - 2) - y_screen_loc)));
		     else
			draw_sprite(buffer, obj_01_data[145 + (257 * 1)].dat, (16 * (((map_sprites[i][2] / 16) + (map_sprites[i][1] * 16)) - x_screen_loc)), (16 * (((map_sprites[i][0] / 16) - 2) - y_screen_loc)));
		     draw_sprite(buffer, obj_01_data[155 + (257 * 11)].dat, (16 * (((map_sprites[i][2] / 16) + (map_sprites[i][1] * 16)) - x_screen_loc)), (16 * (((map_sprites[i][0] / 16) - 2) - y_screen_loc)));
		  }
	    }

//Draw pointers.  Use transparency to darken pointer squares.

	 if (pointer_mode)
	    {
	       for (i = 0; i < (16 * (level_bytes / 144)); i++)
		  for (j = 0; j < 9; j++)
		     {
			for (p_ctr = 0; p_ctr < num_ptrs; p_ctr++)
			   if ((map_ptr_hriz[p_ctr] == i) && (((map_ptr_vert[p_ctr] / 16) - 2) == j))
			      {
				 drawing_mode(DRAW_MODE_TRANS, NULL, 0, 0);
				 rectfill(buffer, (16 * (i - x_screen_loc)), (16 * (j - y_screen_loc)), ((16 * (i - x_screen_loc)) + 15), ((16 * (j - y_screen_loc)) + 15), 76);
				 drawing_mode(DRAW_MODE_SOLID, NULL, 0, 0);
				 if (pointer_numbers)
				    {
				       text_mode(-1);
				       textprintf_centre(buffer, font, ((16 * (i - x_screen_loc)) + 8), ((16 * (j - y_screen_loc)) + 5), 2, "%i", p_ctr);
				    }
			      }
		     }
	    }			//end of pointer drawing function


//end of Map screen drawing function.  Skip sidescrolling level drawing code.
	 goto skipsidescroll;
      }

   if (options_dialog[10].flags & D_SELECTED)
      goto drawthe4byteobjectsfirst;

 drawthe3byteobjectssecond:

   if (show3byte_flag)
      for (i = 0; i < tbyte_objs; i++)
	 {
	    domain = (tbyte_array[0][i] / 32);
	    if (vertical_flag)
	       {
		  x_position = (tbyte_array[1][i] % 16);
		  y_position = (((tbyte_array[1][i] / 16) * 15) + (tbyte_array[0][i] % 32));
	       }
	    else
	       {
		  x_position = tbyte_array[1][i];
		  y_position = (tbyte_array[0][i] % 32);
	       }

	    if (tbyte_array[2][i] < 16)
	       //if object is one of the single-length 0x00 to 0x0F objects//
	       {
		  object = ((tbyte_array[2][i] + (domain * 31)));

		  for (j = 0; j < plains_level[level_object_set][object].bmp_width; j++)
		     for (k = 0; k < plains_level[level_object_set][object].bmp_height; k++)
			draw_sprite(buffer, obj_01_data[plains_level[level_object_set][object].obj_design[(((plains_level[level_object_set][object].bmp_width) * k) + j)] + (257 * level_object_set)].dat, (16 * (x_position - (x_screen_loc)) + (16 * j)), ((16 * ((y_position) - y_screen_loc)) + (16 * k)));

		  draw_sprite(buffer, obj_01_data[156 + (257 * level_object_set)].dat, (16 * (x_position - (x_screen_loc))), ((16 * ((y_position) - y_screen_loc))));
	       }
	    if (tbyte_array[2][i] >= 16)
	       {
		  object = (((tbyte_array[2][i] / 16) + ((domain * 31) + 16)) - 1);

		  //test if object is 3 bytes
		  if (plains_level[level_object_set][object].obj_flag != THREE_BYTE)
		     draw_sprite(buffer, obj_01_data[145 + (257 * level_object_set)].dat, (16 * (x_position - x_screen_loc)), ((16 * ((y_position) - y_screen_loc))));
		  else
		     {
			length = (tbyte_array[2][i] % 16);
			if ((plains_level[level_object_set][object].orientation == HORIZ) || (plains_level[level_object_set][object].orientation == HORIZ_2))
			   //if object is horizontally oriented
			   {
			      if (plains_level[level_object_set][object].ends == 0)
				 //if all blocks are the same (e.g. a row of bricks)
				 {
				    for (l_counter = 0; l_counter < (length + 1); l_counter++)
				       for (l = 0; l < plains_level[level_object_set][object].bmp_height; l++)
					  for (m = 0; m < plains_level[level_object_set][object].bmp_width; m++)
					     draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[(((plains_level[level_object_set][object].bmp_width) * l) + m)]) + (257 * level_object_set)].dat, ((16 * (x_position - x_screen_loc) + (16 * m)) + (16 * (plains_level[level_object_set][object].bmp_width) * l_counter)), (((16 * ((y_position) - y_screen_loc)) + (16 * l))));

				    draw_sprite(buffer, obj_01_data[156 + (257 * level_object_set)].dat, (16 * (x_position - (x_screen_loc))), ((16 * ((y_position) - y_screen_loc))));

				 }
			      if (plains_level[level_object_set][object].ends == 1)
				 //if all blocks are the same except for the column on the left, e.g.
				 //rightward pipes
				 {
				    for (l_counter = 0; l_counter <= length; l_counter++)
				       {
					  if (l_counter == 0)
					     {
						for (l = 0; l < plains_level[level_object_set][object].bmp_height; l++)
						   {
						      m = 0;
						      draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[((plains_level[level_object_set][object].bmp_width) * l)]) + (257 * level_object_set)].dat, ((16 * (x_position - x_screen_loc) + (16 * m)) + (16 * (plains_level[level_object_set][object].bmp_width / 2) * l_counter)), (((16 * ((y_position) - y_screen_loc)) + (16 * l))));
						   }
					     }
					  else
					     {
						for (l = 0; l < plains_level[level_object_set][object].bmp_height; l++)
						   for (m = 1; m < plains_level[level_object_set][object].bmp_width; m++)
						      draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[((plains_level[level_object_set][object].bmp_width) * l) + m]) + (257 * level_object_set)].dat, ((16 * (x_position - x_screen_loc) + (16 * (m - 1))) + (16 * (plains_level[level_object_set][object].bmp_width - 1) * l_counter)), (((16 * ((y_position) - y_screen_loc)) + (16 * l))));

					     }
				       }
				    draw_sprite(buffer, obj_01_data[156 + (257 * level_object_set)].dat, (16 * (x_position - (x_screen_loc))), ((16 * ((y_position) - y_screen_loc))));
				 }	//end of if (plains_level[level_object_set][object].ends == 1)


			      if (plains_level[level_object_set][object].ends == 2)
				 //if all blocks are the same except for the column on the right, e.g.
				 //leftward pipes        
				 {
				    for (l_counter = 0; l_counter <= length; l_counter++)
				       {
					  if (l_counter == length)
					     {
						for (l = 0; l < plains_level[level_object_set][object].bmp_height; l++)
						   {
						      m = (plains_level[level_object_set][object].bmp_width - 1);
						      draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[((plains_level[level_object_set][object].bmp_width) * l) + m]) + (257 * level_object_set)].dat, (16 * (x_position - x_screen_loc) + (16 * l_counter)), (((16 * ((y_position) - y_screen_loc)) + (16 * l))));
						   }
					     }
					  else
					     {
						for (l = 0; l < plains_level[level_object_set][object].bmp_height; l++)
						   for (m = 0; m < (plains_level[level_object_set][object].bmp_width - 1); m++)
						      draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[((plains_level[level_object_set][object].bmp_width) * l) + m]) + (257 * level_object_set)].dat, ((16 * (x_position - x_screen_loc) + (16 * m)) + (16 * (plains_level[level_object_set][object].bmp_width - 1) * l_counter)), (((16 * ((y_position) - y_screen_loc)) + (16 * l))));
					     }
				       }
				    draw_sprite(buffer, obj_01_data[156 + (257 * level_object_set)].dat, (16 * (x_position - (x_screen_loc))), ((16 * ((y_position) - y_screen_loc))));
				 }	//end of if (plains_level[level_object_set][object].ends == 2)


			      if (plains_level[level_object_set][object].ends == 3)
				 //if all blocks in the middle are the same, but both the right
				 //and left edges use different bitmaps (e.g. the block platforms)       
				 {
				    if (plains_level[level_object_set][object].orientation == HORIZ)
				       {
					  for (l_counter = 0; l_counter <= length; l_counter++)
					     {
						if (l_counter == 0)
						   {
						      for (l = 0; l < plains_level[level_object_set][object].bmp_height; l++)
							 {
							    m = 0;
							    draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[0 + (l * plains_level[level_object_set][object].bmp_width)]) + (257 * level_object_set)].dat, ((16 * (x_position - x_screen_loc) + (16 * m)) + (16 * (plains_level[level_object_set][object].bmp_width) * l_counter)), (((16 * ((y_position) - y_screen_loc)) + (16 * l))));
							 }
						   }
						else if (l_counter == length)
						   {
						      for (l = 0; l < plains_level[level_object_set][object].bmp_height; l++)
							 {
							    m = (plains_level[level_object_set][object].bmp_width - 1);
							    draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[(plains_level[level_object_set][object].bmp_width - 1) + (l * plains_level[level_object_set][object].bmp_width)]) + (257 * level_object_set)].dat, ((16 * (x_position - x_screen_loc) + (16 * (m - 2))) + (16 * l_counter)), (((16 * ((y_position) - y_screen_loc)) + (16 * l))));
							 }
						   }
						else
						   {
						      for (l = 0; l < plains_level[level_object_set][object].bmp_height; l++)
							 {
							    h = (plains_level[level_object_set][object].bmp_width - 2);
							    for (m = 1; m < (plains_level[level_object_set][object].bmp_width - 1); m++)
							       draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[((plains_level[level_object_set][object].bmp_width) * l) + m]) + (257 * level_object_set)].dat, ((16 * (x_position - x_screen_loc) + (16 * (m - 1))) + (16 * l_counter)), (((16 * ((y_position) - y_screen_loc)) + (16 * l))));
							 }
						   }
					     }
				       }	//end of if(plains_level[level_object_set][object].orientation == HORIZ)
				    else
				       {
					  for (l_counter = 0; l_counter < length; l_counter++)
					     if (l_counter == 0)
						{
						   for (l = 0; l < plains_level[level_object_set][object].bmp_height; l++)
						      {
							 m = 0;
							 draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[0 + (l * plains_level[level_object_set][object].bmp_width)]) + (257 * level_object_set)].dat, ((16 * (x_position - x_screen_loc) + (16 * m)) + (16 * (plains_level[level_object_set][object].bmp_width) * l_counter)), (((16 * ((y_position) - y_screen_loc)) + (16 * l))));
						      }
						}
					     else if (l_counter == (length - 1))
						{
						   for (l = 0; l < plains_level[level_object_set][object].bmp_height; l++)
						      {
							 m = (plains_level[level_object_set][object].bmp_width - 1);
							 draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[(plains_level[level_object_set][object].bmp_width - 1) + (l * plains_level[level_object_set][object].bmp_width)]) + (257 * level_object_set)].dat, ((16 * (x_position - x_screen_loc) + (16 * (m - 2))) + (16 * l_counter)), (((16 * ((y_position) - y_screen_loc)) + (16 * l))));
						      }
						}
					     else
						{
						   for (l = 0; l < plains_level[level_object_set][object].bmp_height; l++)
						      {
							 h = (plains_level[level_object_set][object].bmp_width - 2);
							 for (m = 1; m < (plains_level[level_object_set][object].bmp_width - 1); m++)
							    draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[m + (l * plains_level[level_object_set][object].bmp_width)]) + (257 * level_object_set)].dat, ((16 * (x_position - x_screen_loc) + (16 * (m - 1))) + (16 * l_counter)), (((16 * ((y_position) - y_screen_loc)) + (16 * l))));
						      }
						}

				       }

				    draw_sprite(buffer, obj_01_data[156 + (257 * level_object_set)].dat, (16 * (x_position - (x_screen_loc))), ((16 * ((y_position) - y_screen_loc))));
				 }
			   }
			else if (plains_level[level_object_set][object].orientation == VERTICAL)
			   //if object is vertically oriented
			   {
			      if (plains_level[level_object_set][object].ends == 0)
				 //if all blocks are the same (e.g. ???)
				 {
				    for (l_counter = 0; l_counter <= length; l_counter++)
				       for (l = 0; l < plains_level[level_object_set][object].bmp_height; l++)
					  for (m = 0; m < plains_level[level_object_set][object].bmp_width; m++)
					     draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[((plains_level[level_object_set][object].bmp_width) * l) + m]) + (257 * level_object_set)].dat, (16 * (x_position - x_screen_loc) + (16 * m)), ((((16 * ((y_position) - y_screen_loc)) + (16 * l)) + (16 * (plains_level[level_object_set][object].bmp_height) * l_counter))));
				    draw_sprite(buffer, obj_01_data[156 + (257 * level_object_set)].dat, (16 * (x_position - (x_screen_loc))), ((16 * ((y_position) - y_screen_loc))));
				 }
			      if (plains_level[level_object_set][object].ends == 1)
				 //if all blocks are the same except for the row on the top (e.g.
				 //downward pipes)       
				 {
				    for (l_counter = 0; l_counter <= length; l_counter++)
				       if (l_counter == 0)
					  {
					     for (m = 0; m < plains_level[level_object_set][object].bmp_width; m++)
						{
						   if (length > 0)
						      {
							 for (l = 0; l < (plains_level[level_object_set][object].bmp_height - 1); l++)
							    draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[((plains_level[level_object_set][object].bmp_width) * l) + m]) + (257 * level_object_set)].dat, (16 * (x_position - x_screen_loc) + (16 * m)), ((((16 * ((y_position) - y_screen_loc)) + (16 * l)) + (16 * (plains_level[level_object_set][object].bmp_height) * l_counter))));
						      }
						   else
						      {
							 l = 0;
							 draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[((plains_level[level_object_set][object].bmp_width) * l) + m]) + (257 * level_object_set)].dat, (16 * (x_position - x_screen_loc) + (16 * m)), ((((16 * ((y_position) - y_screen_loc)) + (16 * l)) + (16 * (plains_level[level_object_set][object].bmp_height) * l_counter))));
						      }
						}
					  }
				       else
					  {
					     l = (plains_level[level_object_set][object].bmp_height - 1);
					     for (m = 0; m < plains_level[level_object_set][object].bmp_width; m++)
						if (plains_level[level_object_set][object].bmp_height <= 2)
						   draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[((plains_level[level_object_set][object].bmp_width) * l) + m]) + (257 * level_object_set)].dat, (16 * (x_position - x_screen_loc) + (16 * m)), ((((16 * ((y_position) - y_screen_loc)) + (16 * (l - 1))) + (16 * (plains_level[level_object_set][object].bmp_height - 1) * l_counter))));
						else
						   draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[((plains_level[level_object_set][object].bmp_width) * l) + m]) + (257 * level_object_set)].dat, (16 * (x_position - x_screen_loc) + (16 * m)), ((((16 * ((y_position) - y_screen_loc)) + (16 * (l - 1))) + (16 * (plains_level[level_object_set][object].bmp_height - 2) * (l_counter - 1)))));
					  }
				    draw_sprite(buffer, obj_01_data[156 + (257 * level_object_set)].dat, (16 * (x_position - (x_screen_loc))), ((16 * ((y_position) - y_screen_loc))));
				 }
			      if (plains_level[level_object_set][object].ends == 2)
				 //if all blocks are the same except for the row on the bottom, e.g.
				 //upward pipes  
				 {
				    for (l_counter = 0; l_counter <= length; l_counter++)
				       if (l_counter == length)
					  {
					     for (m = 0; m < plains_level[level_object_set][object].bmp_width; m++)
						{
						   l = (plains_level[level_object_set][object].bmp_height - 1);
						   draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[((plains_level[level_object_set][object].bmp_width) * l) + m]) + (257 * level_object_set)].dat, (16 * (x_position - x_screen_loc) + (16 * m)), (((16 * ((y_position) - y_screen_loc)) + (16 * l_counter))));
						}
					  }
				       else
					  {
					     for (l = 0; l < plains_level[level_object_set][object].bmp_height - 1; l++)
						for (m = 0; m < (plains_level[level_object_set][object].bmp_width); m++)
						   draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[((plains_level[level_object_set][object].bmp_width) * l) + m]) + (257 * level_object_set)].dat, ((16 * (x_position - x_screen_loc)) + (16 * m)), ((((16 * ((y_position) - y_screen_loc)) + (16 * l)) + (16 * (plains_level[level_object_set][object].bmp_height - 1) * l_counter))));
					  }
				    draw_sprite(buffer, obj_01_data[156 + (257 * level_object_set)].dat, (16 * (x_position - (x_screen_loc))), ((16 * ((y_position) - y_screen_loc))));
				 }
			      if (plains_level[level_object_set][object].ends == 3)
				 //if all blocks in the middle are the same, but both the top
				 //and bottom edges use different bitmaps (e.g. double-ended pipes)      
				 {
				    for (l_counter = 0; l_counter <= length; l_counter++)
				       if (l_counter == 0)
					  {
					     for (m = 0; m < plains_level[level_object_set][object].bmp_width; m++)
						{
						   l = 0;
						   draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[((plains_level[level_object_set][object].bmp_width) * l) + m]) + (257 * level_object_set)].dat, (16 * (x_position - x_screen_loc) + (16 * m)), ((((16 * ((y_position) - y_screen_loc)) + (16 * l)) + (16 * (plains_level[level_object_set][object].bmp_height) * l_counter))));
						}
					  }
				       else if (l_counter == length)
					  {
					     for (m = 0; m < plains_level[level_object_set][object].bmp_width; m++)
						{
						   l = (plains_level[level_object_set][object].bmp_height - 1);
						   draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[((plains_level[level_object_set][object].bmp_width) * l) + m]) + (257 * level_object_set)].dat, ((16 * (x_position - x_screen_loc)) + (16 * m)), ((((16 * ((y_position) - y_screen_loc)) + (16 * (l - 2))) + (16 * l_counter))));
						}
					  }
				       else
					  {
					     for (m = 0; m < plains_level[level_object_set][object].bmp_width; m++)
						for (l = 1; l < (plains_level[level_object_set][object].bmp_height - 1); l++)
						   draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[((plains_level[level_object_set][object].bmp_width) * l) + m]) + (257 * level_object_set)].dat, ((16 * (x_position - x_screen_loc)) + (16 * m)), ((((16 * ((y_position) - y_screen_loc)) + (16 * (l - 1))) + (16 * l_counter))));
					  }
				    draw_sprite(buffer, obj_01_data[156 + (257 * level_object_set)].dat, (16 * (x_position - (x_screen_loc))), ((16 * ((y_position) - y_screen_loc))));
				 }
			   }


			else if (plains_level[level_object_set][object].orientation == GD_EXT)
			   {
			      //if object is horizontally oriented but also extends to the ground
			      //Assumes ground is at vertical location 26 or 0x1A
			      //Some code could be placed right here to find the true location
			      //of the ground but I haven't done it yet.
			      if (plains_level[level_object_set][object].ends == 0)
				 //if all blocks are the same (e.g. ???) 
				 {
				    for (l_counter = 0; l_counter < length; l_counter++)
				       for (l = 0; l < plains_level[level_object_set][object].bmp_height; l++)
					  for (m = 0; m < plains_level[level_object_set][object].bmp_width; m++)
					     for (g = (y_position); g <= 25; g++)
						draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[((plains_level[level_object_set][object].bmp_width) * l) + m]) + (257 * level_object_set)].dat, ((16 * (x_position - x_screen_loc) + (16 * m)) + (16 * (plains_level[level_object_set][object].bmp_width) * l_counter)), (((16 * ((y_position) - y_screen_loc)) + (16 * l) + (16 * (g - (y_position))))));
				    draw_sprite(buffer, obj_01_data[156 + (257 * level_object_set)].dat, (16 * (x_position - (x_screen_loc))), ((16 * ((y_position) - y_screen_loc))));
				 }
			      if (plains_level[level_object_set][object].ends == 1)
				 //if all blocks are the same except for the column on the left (e.g. ???)               
				 {
				    for (l_counter = 0; l_counter < length; l_counter++)
				       {
					  if (l_counter == 0)
					     {
						for (g = (y_position); g <= 25; g++)
						   {
						      if (g == (y_position))
							 draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[0]) + (257 * level_object_set)].dat, (16 * (x_position - x_screen_loc)), ((16 * (y_position) - y_screen_loc)));
						      else if (g == 25)
							 draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[(plains_level[level_object_set][object].bmp_height - 1) * (plains_level[level_object_set][object].bmp_width)]) + (257 * level_object_set)].dat, (16 * (x_position - x_screen_loc)), ((16 * (25 - y_screen_loc))));
						      else
							 draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[(plains_level[level_object_set][object].bmp_height - 2) * (plains_level[level_object_set][object].bmp_width)]) + (257 * level_object_set)].dat, (16 * (x_position - x_screen_loc)), ((16 * (g - y_screen_loc))));
						   }
					     }
					  else
					     {
						for (g = (y_position); g <= 25; g++)
						   {
						      if (g == (y_position))
							 draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[1]) + (257 * level_object_set)].dat, ((16 * (x_position - x_screen_loc)) + (16 * l_counter)), ((16 * (y_position) - y_screen_loc)));
						      else if (g == 25)
							 draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[(plains_level[level_object_set][object].bmp_height - 1) * (plains_level[level_object_set][object].bmp_width) + 1]) + (257 * level_object_set)].dat, ((16 * (x_position - x_screen_loc)) + (16 * l_counter)), ((16 * (25 - y_screen_loc))));
						      else
							 draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[(plains_level[level_object_set][object].bmp_height - 2) * (plains_level[level_object_set][object].bmp_width) + 1]) + (257 * level_object_set)].dat, ((16 * (x_position - x_screen_loc)) + (16 * l_counter)), ((16 * (g - y_screen_loc))));
						   }
					     }
				       }
				    draw_sprite(buffer, obj_01_data[156 + (257 * level_object_set)].dat, (16 * (x_position - (x_screen_loc))), ((16 * ((y_position) - y_screen_loc))));
				 }
			      if (plains_level[level_object_set][object].ends == 2)
				 //if all blocks are the same except for the column on the right (e.g. ???)              
				 {
				    for (l_counter = 0; l_counter < length; l_counter++)
				       {
					  if (l_counter == (length - 1))
					     {
						for (g = (y_position); g <= 25; g++)
						   {
						      if (g == (y_position))
							 draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[1]) + (257 * level_object_set)].dat, ((16 * (x_position - x_screen_loc)) + (16 * l_counter)), (16 * (y_position) - y_screen_loc));
						      else if (g == 25)
							 draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[(plains_level[level_object_set][object].bmp_height - 1) * (plains_level[level_object_set][object].bmp_width) + 1]) + (257 * level_object_set)].dat, ((16 * (x_position - x_screen_loc)) + (16 * l_counter)), (16 * (25 - y_screen_loc)));
						      else
							 draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[(plains_level[level_object_set][object].bmp_height - 2) * (plains_level[level_object_set][object].bmp_width) + 1]) + (257 * level_object_set)].dat, ((16 * (x_position - x_screen_loc)) + (16 * l_counter)), (16 * (g - y_screen_loc)));
						   }
					     }
					  else
					     {
						for (g = (y_position); g <= 25; g++)
						   {
						      if (g == (y_position))
							 draw_sprite(main_display, obj_01_data[(plains_level[level_object_set][object].obj_design[0]) + (257 * level_object_set)].dat, ((16 * (x_position - x_screen_loc)) + (16 * l_counter)), (16 * (y_position) - y_screen_loc));
						      else if (g == 25)
							 draw_sprite(main_display, obj_01_data[(plains_level[level_object_set][object].obj_design[(plains_level[level_object_set][object].bmp_height - 1) * (plains_level[level_object_set][object].bmp_width)]) + (257 * level_object_set)].dat, ((16 * (x_position - x_screen_loc)) + (16 * l_counter)), (16 * (25 - y_screen_loc)));
						      else
							 draw_sprite(main_display, obj_01_data[(plains_level[level_object_set][object].obj_design[(plains_level[level_object_set][object].bmp_height - 2) * (plains_level[level_object_set][object].bmp_width)]) + (257 * level_object_set)].dat, ((16 * (x_position - x_screen_loc)) + (16 * l_counter)), (16 * (g - y_screen_loc)));
						   }
					     }
				       }
				    draw_sprite(buffer, obj_01_data[156 + (257 * level_object_set)].dat, (16 * (x_position - (x_screen_loc))), ((16 * ((y_position) - y_screen_loc))));
				 }
			      if (plains_level[level_object_set][object].ends == 3)
				 //if all blocks in the middle are the same but left and right
				 //edges use different bitmaps (e.g. the block platforms)
				 {
				    for (l_counter = 0; l_counter < (length + 1); l_counter++)
				       {
					  if (l_counter == 0)
					     {
						for (g = (y_position); g <= 25; g++)
						   {
						      if (g == (y_position))
							 draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[0]) + (257 * level_object_set)].dat, (16 * (x_position - x_screen_loc)), ((16 * ((y_position) - y_screen_loc))));
						      else if (g == 25)
							 draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[((plains_level[level_object_set][object].bmp_height - 1) * (plains_level[level_object_set][object].bmp_width))]) + (257 * level_object_set)].dat, (16 * (x_position - x_screen_loc)), ((16 * (25 - y_screen_loc))));
						      else
							 draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[((plains_level[level_object_set][object].bmp_height - 2) * (plains_level[level_object_set][object].bmp_width))]) + (257 * level_object_set)].dat, (16 * (x_position - x_screen_loc)), ((16 * (g - y_screen_loc))));
						   }
					     }
					  else if (l_counter == length)
					     {
						for (g = (y_position); g <= 25; g++)
						   for (l = ((plains_level[level_object_set][object].bmp_width) - ((plains_level[level_object_set][object].bmp_width - 2))); l < (plains_level[level_object_set][object].bmp_width); l++)
						      {
							 if (g == (y_position))
							    draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[l]) + (257 * level_object_set)].dat, ((16 * (x_position - x_screen_loc)) + (16 * l_counter)), ((16 * ((y_position) - y_screen_loc))));
							 else if (g == 25)
							    draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[((plains_level[level_object_set][object].bmp_height - 1) * (plains_level[level_object_set][object].bmp_width) + l)]) + (257 * level_object_set)].dat, ((16 * (x_position - x_screen_loc)) + (16 * (l_counter))), ((16 * (25 - y_screen_loc))));
							 else
							    draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[((plains_level[level_object_set][object].bmp_height - 2) * (plains_level[level_object_set][object].bmp_width) + l)]) + (257 * level_object_set)].dat, ((16 * (x_position - x_screen_loc)) + (16 * (l_counter))), ((16 * (g - y_screen_loc))));
						      }
					     }
					  else
					     {
						for (g = (y_position); g <= 25; g++)
						   {
						      if (g == (y_position))
							 draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[1]) + (257 * level_object_set)].dat, ((16 * (x_position - x_screen_loc)) + (16 * l_counter)), ((16 * ((y_position) - y_screen_loc))));
						      else if (g == 25)
							 draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[((plains_level[level_object_set][object].bmp_height - 1) * (plains_level[level_object_set][object].bmp_width) + 1)]) + (257 * level_object_set)].dat, ((16 * (x_position - x_screen_loc)) + (16 * l_counter)), ((16 * (25 - y_screen_loc))));
						      else
							 draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[((plains_level[level_object_set][object].bmp_height - 2) * (plains_level[level_object_set][object].bmp_width) + 1)]) + (257 * level_object_set)].dat, ((16 * (x_position - x_screen_loc)) + (16 * l_counter)), ((16 * (g - y_screen_loc))));
						   }
					     }
				       }
				    draw_sprite(buffer, obj_01_data[156 + (257 * level_object_set)].dat, (16 * (x_position - (x_screen_loc))), ((16 * ((y_position) - y_screen_loc))));
				 }
			   }
			else if (plains_level[level_object_set][object].orientation == DUMMY)
			   //used mostly or entirely for warning blocks    
			   {
			      for (m = 0; m < plains_level[level_object_set][object].bmp_width; m++)
				 for (l = 0; l < plains_level[level_object_set][object].bmp_height; l++)
				    draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[((plains_level[level_object_set][object].bmp_width) * m) + l]) + (257 * level_object_set)].dat, ((16 * (x_position - x_screen_loc)) + (16 * m)), (((16 * ((y_position) - y_screen_loc)) + (16 * l))));
			   }
			else if (plains_level[level_object_set][object].orientation == DIAG_DL)
			   {
			      if (plains_level[level_object_set][object].ends == 0)
				 {
				    for (l_counter = 0; l_counter <= length; l_counter++)
				       for (m = 0; m < plains_level[level_object_set][object].bmp_width; m++)
					  for (l = 0; l < plains_level[level_object_set][object].bmp_height; l++)
					     draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[((plains_level[level_object_set][object].bmp_width) * m) + l]) + (257 * level_object_set)].dat, (((16 * (x_position - x_screen_loc)) + (16 * m)) - (16 * plains_level[level_object_set][object].bmp_width * l_counter)), (((16 * ((y_position) - y_screen_loc)) + (16 * l)) + (16 * plains_level[level_object_set][object].bmp_height * l_counter)));
				    draw_sprite(buffer, obj_01_data[156 + (257 * level_object_set)].dat, (16 * (x_position - (x_screen_loc))), ((16 * ((y_position) - y_screen_loc))));
				 }
			      if (plains_level[level_object_set][object].ends == 1)
				 {
				    for (l_counter = 0; l_counter <= length; l_counter++)
				       for (m = 0; m < plains_level[level_object_set][object].bmp_width; m++)
					  for (l = 0; l < plains_level[level_object_set][object].bmp_height; l++)
					     {
						if (!(m == (plains_level[level_object_set][object].bmp_width - 1)))
						   draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[((plains_level[level_object_set][object].bmp_width) * l) + m]) + (257 * level_object_set)].dat, (((16 * (x_position - x_screen_loc)) + (16 * m)) - (16 * (plains_level[level_object_set][object].bmp_width - 1) * l_counter)), (((16 * ((y_position) - y_screen_loc)) + (16 * l)) + (16 * plains_level[level_object_set][object].bmp_height * l_counter)));
						else
						   {
						      for (h = 0; h < (l_counter * (plains_level[level_object_set][object].bmp_width - 1)); h++)
							 draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[((plains_level[level_object_set][object].bmp_width) - 1)]) + (257 * level_object_set)].dat, (((16 * (x_position - x_screen_loc)) + (16 * (h + plains_level[level_object_set][object].bmp_width - 1))) - (16 * (plains_level[level_object_set][object].bmp_width - 1) * l_counter)), (((16 * (((y_position)) - y_screen_loc)) + (16 * l)) + (16 * plains_level[level_object_set][object].bmp_height * l_counter)));
						   }
					     }

				    draw_sprite(buffer, obj_01_data[156 + (257 * level_object_set)].dat, (16 * (x_position - (x_screen_loc))), ((16 * ((y_position) - y_screen_loc))));


				 }
			      if (plains_level[level_object_set][object].ends == 2)
				 {
				    for (l_counter = 0; l_counter <= length; l_counter++)
				       for (m = 0; m < plains_level[level_object_set][object].bmp_width; m++)
					  for (l = 0; l < plains_level[level_object_set][object].bmp_height; l++)
					     draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[((plains_level[level_object_set][object].bmp_width) * m) + l]) + (257 * level_object_set)].dat, (((16 * (x_position - x_screen_loc)) + (16 * m)) - (16 * plains_level[level_object_set][object].bmp_width * l_counter)), (((16 * ((y_position) - y_screen_loc)) + (16 * l)) + (16 * (plains_level[level_object_set][object].bmp_height - 1) * l_counter)));
				    draw_sprite(buffer, obj_01_data[156 + (257 * level_object_set)].dat, (16 * (x_position - (x_screen_loc))), ((16 * ((y_position) - y_screen_loc))));


				 }


			   }
			else if (plains_level[level_object_set][object].orientation == DIAG_DR)
			   {
			      if (plains_level[level_object_set][object].ends == 0)
				 {
				    for (l_counter = 0; l_counter <= length; l_counter++)
				       for (m = 0; m < plains_level[level_object_set][object].bmp_width; m++)
					  for (l = 0; l < plains_level[level_object_set][object].bmp_height; l++)
					     draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[((plains_level[level_object_set][object].bmp_width) * m) + l]) + (257 * level_object_set)].dat, (((16 * (x_position - x_screen_loc)) + (16 * m)) + (16 * plains_level[level_object_set][object].bmp_width * l_counter)), (((16 * ((y_position) - y_screen_loc)) + (16 * l)) + (16 * plains_level[level_object_set][object].bmp_height * l_counter)));
				    draw_sprite(buffer, obj_01_data[156 + (257 * level_object_set)].dat, (16 * (x_position - (x_screen_loc))), ((16 * ((y_position) - y_screen_loc))));


				 }
			      if (plains_level[level_object_set][object].ends == 1)

				 {

				    for (l_counter = 0; l_counter <= length; l_counter++)
				       for (m = 0; m < plains_level[level_object_set][object].bmp_width; m++)
					  for (l = 0; l < plains_level[level_object_set][object].bmp_height; l++)
					     {
						if (!(m == 0))
						   draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[((plains_level[level_object_set][object].bmp_width) * l) + m]) + (257 * level_object_set)].dat, (((16 * (x_position - x_screen_loc)) + (16 * (m - 1))) + (16 * (plains_level[level_object_set][object].bmp_width - 1) * l_counter)), (((16 * ((y_position) - y_screen_loc)) + (16 * l)) + (16 * plains_level[level_object_set][object].bmp_height * l_counter)));
						else
						   for (h = 0; h < (l_counter * (plains_level[level_object_set][object].bmp_width - 1)); h++)
						      draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[0]) + (257 * level_object_set)].dat, (((16 * (x_position - x_screen_loc)) + (16 * h))), (((16 * (((y_position)) - y_screen_loc)) + (16 * l)) + (16 * plains_level[level_object_set][object].bmp_height * l_counter)));
					     }
				    draw_sprite(buffer, obj_01_data[156 + (257 * level_object_set)].dat, (16 * (x_position - (x_screen_loc))), ((16 * ((y_position) - y_screen_loc))));
				 }
			      if (plains_level[level_object_set][object].ends == 2)

				 {

				    for (l_counter = 0; l_counter <= length; l_counter++)
				       for (m = 0; m < plains_level[level_object_set][object].bmp_width; m++)
					  for (l = 0; l < plains_level[level_object_set][object].bmp_height; l++)
					     {
						if (!(m == (plains_level[level_object_set][object].bmp_width - 1)))

						   // draw_sprite(buffer, obj_01_data[156 + (257 * level_object_set)].dat, (16 * (x_position - (x_screen_loc ))), ((16 * ((y_position) - y_screen_loc))));
						   draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[((plains_level[level_object_set][object].bmp_width) * l) + m]) + (257 * level_object_set)].dat, (((16 * (x_position - x_screen_loc)) + (16 * m)) + (16 * (plains_level[level_object_set][object].bmp_width - 1) * l_counter)), (((16 * ((y_position) - y_screen_loc)) + (16 * l)) + (16 * plains_level[level_object_set][object].bmp_height * l_counter)));
						else
						   for (h = ((length - l_counter) * (plains_level[level_object_set][object].bmp_width - 1)); h > 0; h--)
						      draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[((plains_level[level_object_set][object].bmp_width) - 1)]) + (257 * level_object_set)].dat, (((16 * (x_position - x_screen_loc)) + (16 * (h + plains_level[level_object_set][object].bmp_width - 2))) + (16 * (plains_level[level_object_set][object].bmp_width - 1) * l_counter)), (((16 * (((y_position)) - y_screen_loc)) + (16 * l)) + (16 * plains_level[level_object_set][object].bmp_height * l_counter)));
					     }
				    draw_sprite(buffer, obj_01_data[156 + (257 * level_object_set)].dat, (16 * (x_position - (x_screen_loc))), ((16 * ((y_position) - y_screen_loc))));
				 }
			   }
			else if (plains_level[level_object_set][object].orientation == DIAG_CRNR)
			   {
			      for (l_counter = 0; l_counter <= length; l_counter++)
				 for (m = 0; m < plains_level[level_object_set][object].bmp_width; m++)
				    for (l = 0; l < plains_level[level_object_set][object].bmp_height; l++)

				       {
					  if (m == 0)
					     {
						for (h = ((length - l_counter) * (plains_level[level_object_set][object].bmp_width - 1)); h > 0; h--)
						   draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[0]) + (257 * level_object_set)].dat, (((16 * (x_position - x_screen_loc)) + (16 * (h - 1)))), (((16 * (((y_position)) - y_screen_loc)) + (16 * l)) + (16 * plains_level[level_object_set][object].bmp_height * l_counter)));
					     }
					  else
					     draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[((plains_level[level_object_set][object].bmp_width) * l) + m]) + (257 * level_object_set)].dat, ((16 * (x_position - x_screen_loc)) + ((16 * (((length - l_counter) * (plains_level[level_object_set][object].bmp_width - 1)) - 1)) + (16 * m))), (((16 * (((y_position)) - y_screen_loc)) + (16 * l)) + (16 * plains_level[level_object_set][object].bmp_height * l_counter)));

				       }
			      draw_sprite(buffer, obj_01_data[156 + (257 * level_object_set)].dat, (16 * (x_position - (x_screen_loc))), ((16 * ((y_position) - y_screen_loc))));
			   }
			else if (plains_level[level_object_set][object].orientation == DIAG_UR)
			   {
			      for (l_counter = 0; l_counter <= length; l_counter++)
				 for (m = 0; m < plains_level[level_object_set][object].bmp_width; m++)
				    for (l = 0; l < plains_level[level_object_set][object].bmp_height; l++)
				       draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[((plains_level[level_object_set][object].bmp_width) * m) + l]) + (257 * level_object_set)].dat, (((16 * (x_position - x_screen_loc)) + (16 * m)) + (16 * plains_level[level_object_set][object].bmp_width * l_counter)), (((16 * ((y_position) - y_screen_loc)) + (16 * l)) - (16 * plains_level[level_object_set][object].bmp_height * l_counter)));
			      draw_sprite(buffer, obj_01_data[156 + (257 * level_object_set)].dat, (16 * (x_position - (x_screen_loc))), ((16 * ((y_position) - y_screen_loc))));



			   }
			else if (plains_level[level_object_set][object].orientation == PIPEBOX)
			   {
			      for (l_counter = 0; l_counter <= ((length * 2) + 1); l_counter++)
				 for (h = 0; h <= 4; h++)
				    for (m = 0; m < plains_level[level_object_set][object].bmp_width; m++)

				       {

					  if (plains_level[level_object_set][object].bmp_height <= 4)
					     {
						if (h == 4)
						   {
						      l = 0;
						      draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[(((plains_level[level_object_set][object].bmp_width) * l) + m)]) + (257 * level_object_set)].dat, ((16 * (x_position - x_screen_loc) + (16 * m)) + (16 * (plains_level[level_object_set][object].bmp_width) * l_counter)), ((16 * ((y_position) - y_screen_loc)) + (16 * l) + (16 * (plains_level[level_object_set][object].bmp_height) * h)));
						   }
						else
						   {

						      for (l = 0; l < plains_level[level_object_set][object].bmp_height; l++)
							 draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[(((plains_level[level_object_set][object].bmp_width) * l) + m)]) + (257 * level_object_set)].dat, ((16 * (x_position - x_screen_loc) + (16 * m)) + (16 * (plains_level[level_object_set][object].bmp_width) * l_counter)), ((16 * ((y_position) - y_screen_loc)) + (16 * l) + (16 * (plains_level[level_object_set][object].bmp_height) * h)));
						   }
					     }
					  else
					     {
						if (h == 0)
						   {
						      for (l = 0; l < plains_level[level_object_set][object].bmp_height; l++)
							 draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[(((plains_level[level_object_set][object].bmp_width) * l) + m)]) + (257 * level_object_set)].dat, ((16 * (x_position - x_screen_loc) + (16 * m)) + (16 * (plains_level[level_object_set][object].bmp_width) * l_counter)), ((16 * ((y_position) - y_screen_loc)) + (16 * l) + (16 * (plains_level[level_object_set][object].bmp_height) * h)));
						   }
						else
						   {

						      for (l = 1; l < plains_level[level_object_set][object].bmp_height; l++)
							 draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[(((plains_level[level_object_set][object].bmp_width) * l) + m)]) + (257 * level_object_set)].dat, ((16 * (x_position - x_screen_loc) + (16 * m)) + (16 * (plains_level[level_object_set][object].bmp_width) * l_counter)), ((16 * ((y_position) - y_screen_loc)) + (16 * l) + (16 * (plains_level[level_object_set][object].bmp_height - 1) * h)));
						   }
					     }




				       }


			      for (h = 0; h <= 4; h++)
				 for (g = 0; g < 8; g++)
				    {
				       if (plains_level[level_object_set][object].bmp_height <= 4)
					  {
					     if (h == 4)
						draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[2]) + (257 * level_object_set)].dat, ((16 * (x_position - x_screen_loc) + (16 * g)) + (16 * ((length * 2) + 1) * plains_level[level_object_set][object].bmp_width) + 16), ((16 * ((y_position) - y_screen_loc)) + (16 * l) + (16 * (plains_level[level_object_set][object].bmp_height) * h)));
					     else
						draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[2]) + (257 * level_object_set)].dat, ((16 * (x_position - x_screen_loc) + (16 * g)) + (16 * ((length * 2) + 1) * plains_level[level_object_set][object].bmp_width) + 16), ((16 * ((y_position) - y_screen_loc)) + (16 * l) + (16 * (plains_level[level_object_set][object].bmp_height) * h)));
					  }
				       else
					  {
					     if (h == 0)
						draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[2]) + (257 * level_object_set)].dat, ((16 * (x_position - x_screen_loc) + (16 * g)) + (16 * ((length * 2) + 1) * plains_level[level_object_set][object].bmp_width) + 16), ((16 * ((y_position) - y_screen_loc))));
					  }
				    }
			      draw_sprite(buffer, obj_01_data[156 + (257 * level_object_set)].dat, (16 * (x_position - (x_screen_loc))), ((16 * ((y_position) - y_screen_loc))));
			   }

		     }


	       }
	 }

   if (options_dialog[10].flags & D_SELECTED)
      goto drawtheenemieslast;

 drawthe4byteobjectsfirst:
   if (show4byte_flag == TRUE)

      for (a = 0; a < fbyte_objs; a++)
	 {
	    domain = (fbyte_array[0][a] / 32);
	    if (vertical_flag)
	       {
		  x_position = (fbyte_array[1][a] % 16);
		  y_position = (((fbyte_array[1][a] / 16) * 15) + (fbyte_array[0][a] % 32));
	       }
	    else
	       {
		  x_position = fbyte_array[1][a];
		  y_position = (fbyte_array[0][a] % 32);
	       }
	    if (fbyte_array[2][a] < 16)
	       //values of 0x00 to 0x0F are invalid for 4-byte objects, 
	       //so show a warning block       
	       draw_sprite(buffer, obj_01_data[145 + (257 * level_object_set)].dat, (16 * (x_position - x_screen_loc)), ((16 * ((y_position) - y_screen_loc))));
	    if (fbyte_array[2][a] >= 16)
	       {
		  object = (((fbyte_array[2][a] / 16) + ((domain * 31) + 16)) - 1);
		  //show warning block if object is not 4 bytes
		  if (plains_level[level_object_set][object].obj_flag != FOUR_BYTE)
		     draw_sprite(buffer, obj_01_data[145 + (257 * level_object_set)].dat, (16 * (x_position - x_screen_loc)), ((16 * ((y_position) - y_screen_loc))));
		  else
		     {
			length = (fbyte_array[2][a] % 16);

			if ((plains_level[level_object_set][object].orientation == HORIZ) || (plains_level[level_object_set][object].orientation == HORIZ_2))
			   {
			      //if 4th byte extends object horizontally
			      if (plains_level[level_object_set][object].ends == 0)
				 //if every block is the same - e.g. X-blocks (note: allows for if
				 //the top edge of the object uses a different bitmap, e.g. water)               
				 {
				    for (l_counter = 0; l_counter <= length; l_counter++)
				       for (w_counter = 0; w_counter <= (fbyte_array[3][a]); w_counter++)
					  {
					     if (plains_level[level_object_set][object].orientation == HORIZ)
						{
						   if ((l_counter == 0) && (plains_level[level_object_set][object].orientation == HORIZ))
						      draw_sprite(buffer, obj_01_data[plains_level[level_object_set][object].obj_design[0] + (257 * level_object_set)].dat, ((16 * (x_position - x_screen_loc)) + (16 * w_counter)), ((16 * ((y_position) - y_screen_loc))));
						   else

						      draw_sprite(buffer, obj_01_data[plains_level[level_object_set][object].obj_design[(plains_level[level_object_set][object].bmp_height - 1)] + (257 * level_object_set)].dat, ((16 * (x_position - x_screen_loc)) + (16 * w_counter)), ((16 * ((y_position) - y_screen_loc) + (16 * l_counter))));
						}
					     if (plains_level[level_object_set][object].orientation == HORIZ_2)
						{
						   if (l_counter == length)
						      draw_sprite(buffer, obj_01_data[plains_level[level_object_set][object].obj_design[1] + (257 * level_object_set)].dat, ((16 * (x_position - x_screen_loc)) + (16 * w_counter)), ((16 * ((y_position) - y_screen_loc) + (16 * l_counter))));
						   else
						      draw_sprite(buffer, obj_01_data[plains_level[level_object_set][object].obj_design[0] + (257 * level_object_set)].dat, ((16 * (x_position - x_screen_loc)) + (16 * w_counter)), ((16 * ((y_position) - y_screen_loc) + (16 * l_counter))));



						}

					  }
				    draw_sprite(buffer, obj_01_data[155 + (257 * level_object_set)].dat, (16 * (x_position - (x_screen_loc))), ((16 * ((y_position) - y_screen_loc))));
				 }
			      if (plains_level[level_object_set][object].ends == 1)
				 //if left edge of object uses a different bitmap (e.g. ???)     
				 {
				    for (l_counter = 0; l_counter <= length; l_counter++)
				       for (w_counter = 0; w_counter < (fbyte_array[3][a]); w_counter++)
					  {
					     if (w_counter == 0)
						{
						   if (l_counter == 0)
						      draw_sprite(buffer, obj_01_data[plains_level[level_object_set][object].obj_design[0] + (257 * level_object_set)].dat, ((16 * (x_position - x_screen_loc)) + (16 * w_counter)), ((16 * ((y_position) - y_screen_loc))));
						   else
						      draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[(plains_level[level_object_set][object].bmp_width) * (plains_level[level_object_set][object].bmp_height - 1)]) + (257 * level_object_set)].dat, ((16 * (x_position - x_screen_loc)) + (16 * w_counter)), ((16 * ((y_position) - y_screen_loc) + (16 * l_counter))));
						}
					     else
						{
						   if (l_counter == 0)
						      draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[(plains_level[level_object_set][object].bmp_width) - 1]) + (257 * level_object_set)].dat, ((16 * (x_position - x_screen_loc)) + (16 * w_counter)), ((16 * ((y_position) - y_screen_loc))));
						   else
						      draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[(plains_level[level_object_set][object].bmp_width) * (plains_level[level_object_set][object].bmp_height - 1) + 1]) + (257 * level_object_set)].dat, ((16 * (x_position - x_screen_loc)) + (16 * w_counter)), ((16 * ((y_position) - y_screen_loc) + (16 * l_counter))));
						}
					  }
				    draw_sprite(buffer, obj_01_data[155 + (257 * level_object_set)].dat, (16 * (x_position - (x_screen_loc))), ((16 * ((y_position) - y_screen_loc))));
				 }
			      if (plains_level[level_object_set][object].ends == 2)
				 //if right edge of object uses a different bitmap (e.g. ???)    
				 {
				    for (l_counter = 0; l_counter < length; l_counter++)
				       for (w_counter = 0; w_counter < (fbyte_array[3][a]); w_counter++)
					  {
					     if (w_counter == (fbyte_array[3][a] - 1))
						{
						   if (l_counter == 0)
						      draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[(plains_level[level_object_set][object].bmp_width) - 1]) + (257 * level_object_set)].dat, ((16 * (x_position - x_screen_loc)) + (16 * w_counter)), ((16 * ((y_position) - y_screen_loc))));
						   else
						      draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[(plains_level[level_object_set][object].bmp_width) * (plains_level[level_object_set][object].bmp_height - 1) + 1]) + (257 * level_object_set)].dat, ((16 * (x_position - x_screen_loc)) + (16 * w_counter)), ((16 * ((y_position) - y_screen_loc) + (16 * l_counter))));
						}
					     else
						{
						   if (l_counter == 0)
						      draw_sprite(buffer, obj_01_data[plains_level[level_object_set][object].obj_design[0] + (257 * level_object_set)].dat, ((16 * (x_position - x_screen_loc)) + (16 * w_counter)), ((16 * ((y_position) - y_screen_loc))));
						   else
						      draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[(plains_level[level_object_set][object].bmp_width) * (plains_level[level_object_set][object].bmp_height - 1)]) + (257 * level_object_set)].dat, ((16 * (x_position - x_screen_loc)) + (16 * w_counter)), ((16 * ((y_position) - y_screen_loc) + (16 * l_counter))));
						}
					  }
				    draw_sprite(buffer, obj_01_data[155 + (257 * level_object_set)].dat, (16 * (x_position - (x_screen_loc))), ((16 * ((y_position) - y_screen_loc))));
				 }
			      if (plains_level[level_object_set][object].ends == 3)
				 //if all blocks in the middle use the same bitmap but right and left
				 //edges don't (e.g. the flat ground found in plains levels)     
				 {
				    for (l_counter = 0; l_counter <= length; l_counter++)
				       for (w_counter = 0; w_counter <= (fbyte_array[3][a]); w_counter++)
					  {
					     if (w_counter == 0)
						{
						   if (l_counter == 0)
						      draw_sprite(buffer, obj_01_data[plains_level[level_object_set][object].obj_design[0] + (257 * level_object_set)].dat, ((16 * (x_position - x_screen_loc)) + (16 * w_counter)), ((16 * ((y_position) - y_screen_loc))));
						   else if (l_counter == (length - 1))
						      draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[(plains_level[level_object_set][object].bmp_width) * (plains_level[level_object_set][object].bmp_height - 1)]) + (257 * level_object_set)].dat, ((16 * (x_position - x_screen_loc)) + (16 * w_counter)), (((16 * ((y_position) - y_screen_loc)) + (16 * l_counter))));
						   else
						      draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[3]) + (257 * level_object_set)].dat, ((16 * (x_position - x_screen_loc)) + (16 * w_counter)), ((16 * ((y_position) - y_screen_loc) + (16 * l_counter))));
						}
					     else if (w_counter == fbyte_array[3][a])
						{
						   if (l_counter == 0)
						      draw_sprite(buffer, obj_01_data[plains_level[level_object_set][object].obj_design[2] + (257 * level_object_set)].dat, ((16 * (x_position - x_screen_loc)) + (16 * w_counter)), ((16 * ((y_position) - y_screen_loc))));
						   else if (l_counter == (length - 1))
						      draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[(plains_level[level_object_set][object].bmp_width) * (plains_level[level_object_set][object].bmp_height - 1) + 2]) + (257 * level_object_set)].dat, ((16 * (x_position - x_screen_loc)) + (16 * w_counter)), ((16 * ((y_position) - y_screen_loc) + (16 * l_counter))));
						   else
						      draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[5]) + (257 * level_object_set)].dat, ((16 * (x_position - x_screen_loc)) + (16 * w_counter)), ((16 * ((y_position) - y_screen_loc) + (16 * l_counter))));
						}
					     else
						{
						   if (l_counter == 0)
						      draw_sprite(buffer, obj_01_data[plains_level[level_object_set][object].obj_design[1] + (257 * level_object_set)].dat, ((16 * (x_position - x_screen_loc)) + (16 * w_counter)), ((16 * ((y_position) - y_screen_loc))));
						   else if (l_counter == (length - 1))
						      draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[(plains_level[level_object_set][object].bmp_width) * (plains_level[level_object_set][object].bmp_height - 1) + 1]) + (257 * level_object_set)].dat, ((16 * (x_position - x_screen_loc)) + (16 * w_counter)), ((16 * ((y_position) - y_screen_loc) + (16 * l_counter))));
						   else
						      draw_sprite(buffer, obj_01_data[(plains_level[level_object_set][object].obj_design[4]) + (257 * level_object_set)].dat, ((16 * (x_position - x_screen_loc)) + (16 * w_counter)), ((16 * ((y_position) - y_screen_loc) + (16 * l_counter))));
						}
					  }

				 }
			      draw_sprite(buffer, obj_01_data[155 + (257 * level_object_set)].dat, (16 * (x_position - (x_screen_loc))), ((16 * ((y_position) - y_screen_loc))));
			   }

			else if (plains_level[level_object_set][object].orientation == VERTICAL)
			   //if 4th byte extends object vertically (note: only one object is like this,
			   //the X-block object in the Dungeon object set with values 0xF0 to 0xFF)        
			   {
			      for (l_counter = 0; l_counter <= length; l_counter++)
				 for (w_counter = 0; w_counter <= (fbyte_array[3][a]); w_counter++)
				    draw_sprite(buffer, obj_01_data[plains_level[level_object_set][object].obj_design[(plains_level[level_object_set][object].bmp_height - 1)] + (257 * level_object_set)].dat, ((16 * (x_position - x_screen_loc)) + (16 * l_counter)), ((16 * ((y_position) - y_screen_loc) + (16 * w_counter))));

			      draw_sprite(buffer, obj_01_data[155 + (257 * level_object_set)].dat, (16 * (x_position - (x_screen_loc))), ((16 * ((y_position) - y_screen_loc))));
			   }
			else if (plains_level[level_object_set][object].orientation == DUMMY)
			   //used mostly or entirely for warning blocks
			   draw_sprite(buffer, obj_01_data[plains_level[level_object_set][object].obj_design[0] + (257 * level_object_set)].dat, (16 * (x_position - x_screen_loc)), ((16 * ((y_position) - y_screen_loc))));
		     }
	       }


	 }

   if (options_dialog[10].flags & D_SELECTED)
      goto drawthe3byteobjectssecond;

 drawtheenemieslast:
   if (showenemy_flag == TRUE)
      for (e = 0; e < enemy_objs; e++)
	 {
	    object = enemy_array[0][e];
	    if (object >= 236)
	       //invalid enemy!!! enemies past value 0xD6 all crash the game.
	       draw_sprite(buffer, obj_01_data[145 + (257 * 11)].dat, (16 * (enemy_array[1][e] - x_screen_loc)), (16 * (enemy_array[2][e] - y_screen_loc)));
	    else
	       {
		  if (plains_level[11][object].orientation == DUMMY)
		     {
			//most enemies fall under this category.  enemies are simple
			//because you can't extend their lengths or anything.
			for (n = 0; n < plains_level[11][object].bmp_width; n++)
			   for (o = 0; o < plains_level[11][object].bmp_height; o++)
			      {
				 draw_sprite(buffer, obj_01_data[plains_level[11][object].obj_design[(((plains_level[11][object].bmp_width) * o) + n)] + (257 * 11)].dat, (16 * (enemy_array[1][e] - (x_screen_loc)) + (16 * n)), ((16 * (enemy_array[2][e] - y_screen_loc)) + (16 * o)));
				 draw_sprite(buffer, obj_01_data[155 + (257 * 11)].dat, (16 * (enemy_array[1][e] - (x_screen_loc))), ((16 * ((enemy_array[2][e]) - y_screen_loc))));
			      }
		     }
		  if (plains_level[11][object].orientation == CENTER)
		     //special process for "centered" enemies like spinning platforms.
		     {
			draw_sprite(buffer, obj_01_data[plains_level[11][object].obj_design[((plains_level[11][object].bmp_width) / 2)] + (257 * 11)].dat, (16 * (enemy_array[1][e] - x_screen_loc)), (16 * (enemy_array[2][e] - y_screen_loc)));
			for (n = 0; n < (plains_level[11][object].bmp_width / 2); n++)
			   {
			      o = 0;
			      draw_sprite(buffer, obj_01_data[plains_level[11][object].obj_design[(((plains_level[11][object].bmp_width) * o) + n)] + (257 * 11)].dat, (16 * (enemy_array[1][e] - (x_screen_loc)) + (16 * (n - (plains_level[11][object].bmp_width / 2)))), ((16 * (enemy_array[2][e] - y_screen_loc)) + (16 * o)));
			   }
			for (n = ((plains_level[11][object].bmp_width / 2) + 1); n < plains_level[11][object].bmp_width; n++)
			   {
			      o = 0;
			      draw_sprite(buffer, obj_01_data[plains_level[11][object].obj_design[(((plains_level[11][object].bmp_width) * o) + n)] + (257 * 11)].dat, (16 * (enemy_array[1][e] - (x_screen_loc)) + (16 * (n - (plains_level[11][object].bmp_width / 2)))), ((16 * (enemy_array[2][e] - y_screen_loc)) + (16 * o)));
			   }
			draw_sprite(buffer, obj_01_data[155 + (257 * 11)].dat, (16 * (enemy_array[1][e] - (x_screen_loc))), ((16 * ((enemy_array[2][e]) - y_screen_loc))));

		     }

	       }

	 }




 skipsidescroll:
   check_flag = FALSE;
}





int edit_level()
{
   char *bp;
   int debug = 0;
   int i = 0;
   int j = 0;
   int k = 0;
   int focus;
   int oldindex = 0;
   int old_x = 1;
   int old_y = 0x15;
   int oldindex4 = 0;
   int index = 0;
   int index4 = 0;
   int object = 0;
   int length;
   int length2;
   int domain;
   int key_flags[8] = { FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE };
   int flag = 0;
   int movet_flag = FALSE;
   int movef_flag = FALSE;
   int mouse_flag = TRUE;
   int mouse_button_flag;
   int space_flag;
   int diff_y = 0;
   int diff_x = 0;
   int object_num = 0;
   int diffk_y = 0;
   int diffk_x = 0;
   int oldtempt;
   int oldtempf;
   int oldtempe;
   int c = 0;
   void *player;
   void *pointer_player;
   int old_slider_pos1;
   int old_slider_pos2;
   int update_pointer_dialog_3 = FALSE;
   int error_chk_tmp;
   int x_position;
   int y_position;

   unsigned char real_hriz_exit_loc;

   for (;;)
      {
	 player = init_dialog(main_dialog, -1);
	 while (update_dialog(player))
	    {
	       focus = find_dialog_focus(main_dialog);
	       show_mouse(NULL);


	       if (options_dialog[6].flags & D_SELECTED)
		  set_mouse_range(0, 0, 319, 199);
	       else
		  set_mouse_range(0, 0, 319, 191);


	       if ((key[KEY_RIGHT] && key[KEY_LEFT]) || (key[KEY_RIGHT] && key[KEY_DOWN]) || (key[KEY_RIGHT] && key[KEY_UP]) || (key[KEY_LEFT] && key[KEY_DOWN]) || (key[KEY_LEFT] && key[KEY_UP]) || (key[KEY_UP] && key[KEY_DOWN]))
		  goto invalid_key_combos;


	       if (freeform_mode)
		  {
		     if (key[KEY_F9])
			{
			   if (!key_f9_flag)
			      {
				 add_3byte_object();
				 key_f9_flag = TRUE;
			      }
			}
		     else
			key_f9_flag = FALSE;
		     if (key[KEY_F10])
			{
			   if (!key_f10_flag)
			      {
				 add_4byte_object();
				 key_f10_flag = TRUE;
			      }
			}
		     else
			key_f10_flag = FALSE;

		     if (key[KEY_F11])
			{
			   if (!key_f11_flag)
			      {
				 add_enemy();
				 key_f11_flag = TRUE;
			      }
			}
		     else
			key_f11_flag = FALSE;

		     if (key[KEY_DEL])
			{
			   for (i = 0; i < tbyte_objs; i++)
			      {
				 if ((tbyte_array[1][i] == cursor_x) && ((tbyte_array[0][i] % 32) == cursor_y))
				    {
				       delete_3byte(i);
				       goto dontdeletetwoobjectsatonce;
				    }
			      }

			   for (i = 0; i < fbyte_objs; i++)
			      {
				 if ((fbyte_array[1][i] == cursor_x) && ((fbyte_array[0][i] % 32) == cursor_y))
				    {
				       delete_4byte(i);
				       goto dontdeletetwoobjectsatonce;
				    }
			      }

			   for (i = 0; i < enemy_objs; i++)
			      {
				 if ((enemy_array[1][i] == cursor_x) && (enemy_array[2][i] == cursor_y))
				    {
				       delete_enemy(i);
				       break;
				    }
			      }

			 dontdeletetwoobjectsatonce:
			}
		  }






	       if (mapedit_flag == TRUE)
		  {


		     if (key[KEY_UP])
			{
			   mouse_flag = FALSE;
			   rest(30);	//because cursor moves WAY too fast otherwise :)
			   if (key[KEY_CONTROL])
			      {
				 if ((cursor_y - 16) > 0)
				    cursor_y -= 16;
				 else
				    cursor_y = 0;
			      }
			   else
			      cursor_y--;
			   check_flag = TRUE;

			   if (cursor_y < 0)
			      cursor_y = 0;
			   if ((cursor_y >= 0) && (map_space_flag) && (pointer_mode))
			      {
				 if (key[KEY_CONTROL])
				    {
				       map_ptr_vert[map_temp] = ((map_ptr_vert[map_temp] % 16) + 0x20);
				    }
				 else
				    {
				       if ((map_ptr_vert[map_temp] - 16) >= 0x20)
					  map_ptr_vert[map_temp] -= 16;
				    }
				 levelmodified = TRUE;
			      }

			   if ((cursor_y >= 0) && (map_space_flag2))
			      {
				 if (key[KEY_CONTROL])
				    {
				       map_sprites[map_temp2][0] = 0x20;
				    }
				 else
				    {
				       if ((map_sprites[map_temp2][0] - 16) >= 0x20)
					  map_sprites[map_temp2][0] -= 16;
				    }
				 levelmodified = TRUE;
			      }

			   if ((cursor_y - y_screen_loc) < 1)
			      scroll_level_up();



			}


		     if (key[KEY_DOWN])
			{
			   mouse_flag = FALSE;
			   rest(30);
			   if (key[KEY_CONTROL])
			      {
				 if ((!map_space_flag) && (!map_space_flag2))
				    {
				       if ((cursor_y + 16) < 27)
					  cursor_y += 16;
				       else
					  cursor_y = 27;
				    }
				 else
				    cursor_y = 8;
			      }
			   else
			      cursor_y++;
			   check_flag = TRUE;


			   if ((cursor_y > 27) && (!map_space_flag) && (!map_space_flag2))
			      cursor_y = 27;
			   if ((cursor_y > 8) && (((map_space_flag) && (pointer_mode)) || (map_space_flag2)))
			      cursor_y = 8;
			   if ((cursor_y <= 8) && (map_space_flag) && (pointer_mode))
			      {
				 if (key[KEY_CONTROL])
				    {
				       map_ptr_vert[map_temp] = ((map_ptr_vert[map_temp] % 16) + 0xA0);
				    }
				 else
				    {
				       if ((map_ptr_vert[map_temp] + 16) < 0xB0)
					  map_ptr_vert[map_temp] += 16;
				    }
				 levelmodified = TRUE;
			      }
			   if ((cursor_y <= 8) && (map_space_flag2))
			      {
				 if (key[KEY_CONTROL])
				    {
				       map_sprites[map_temp2][0] = 0xA0;
				    }
				 else
				    {
				       if ((map_sprites[map_temp2][0] + 16) < 0xB0)
					  map_sprites[map_temp2][0] += 16;
				    }
				 levelmodified = TRUE;
			      }
			   if ((cursor_y - y_screen_loc) > 11)
			      scroll_level_down();


			}

		     if (key[KEY_LEFT])
			{
			   mouse_flag = FALSE;
			   rest(30);
			   if (key[KEY_CONTROL])
			      {
				 if ((cursor_x - 16) > 0)
				    cursor_x -= 16;
				 else
				    cursor_x = 0;
			      }
			   else
			      cursor_x--;

			   check_flag = TRUE;


			   if (cursor_x < 0)
			      cursor_x = 0;

			   if ((cursor_x >= 0) && (map_space_flag) && (pointer_mode))
			      {
				 if (key[KEY_CONTROL])
				    {
				       if ((map_ptr_hriz[map_temp] - 16) > 0)
					  map_ptr_hriz[map_temp] -= 16;
				       else
					  map_ptr_hriz[map_temp] = 0;
				    }
				 else
				    {
				       if ((map_ptr_hriz[map_temp] - 1) >= 0)
					  map_ptr_hriz[map_temp]--;
				    }
				 levelmodified = TRUE;
			      }

			   if ((cursor_x >= 0) && (map_space_flag2))
			      {
				 if (key[KEY_CONTROL])
				    {
				       if (map_sprites[map_temp2][1] > 0)
					  map_sprites[map_temp2][1]--;
				       else
					  map_sprites[map_temp2][2] = 0;
				    }
				 else
				    {
				       if (((map_sprites[map_temp2][2] / 16) + (map_sprites[map_temp2][1] * 16)) > 0)
					  {
					     if ((map_sprites[map_temp2][2] / 16) > 0)
						map_sprites[map_temp2][2] -= 16;
					     else
						{
						   map_sprites[map_temp2][2] = 0xF0;
						   map_sprites[map_temp2][1]--;
						}
					  }
				    }
				 levelmodified = TRUE;
			      }

			   if ((cursor_x - x_screen_loc) < 0)

			      scroll_level_left();

			}

		     if (key[KEY_RIGHT])
			{
			   mouse_flag = FALSE;
			   rest(30);
			   if (key[KEY_CONTROL])
			      {
				 if ((!map_space_flag) && (!map_space_flag2))
				    {
				       if ((cursor_x + 16) < 255)
					  cursor_x += 16;
				       else
					  cursor_x = 255;
				    }
				 else
				    {
				       if ((cursor_x + 16) < (((level_bytes / 144) * 16) - 1))
					  cursor_x += 16;
				       else
					  cursor_x = (((level_bytes / 144) * 16) - 1);
				    }

			      }
			   else
			      cursor_x++;

			   check_flag = TRUE;

			   if ((cursor_x > 255) && (!map_space_flag) && (!map_space_flag2))
			      cursor_x = 255;
			   if ((cursor_x > (((level_bytes / 144) * 16) - 1)) && (((map_space_flag) && (pointer_mode)) || (map_space_flag2)))
			      cursor_x = (((level_bytes / 144) * 16) - 1);
			   if ((cursor_x <= (((level_bytes / 144) * 16) - 1)) && (map_space_flag) && (pointer_mode))
			      {
				 if (key[KEY_CONTROL])
				    {
				       if ((map_ptr_hriz[map_temp] + 16) < (((level_bytes / 144) * 16) - 1))
					  map_ptr_hriz[map_temp] += 16;
				       else
					  map_ptr_hriz[map_temp] = (((level_bytes / 144) * 16) - 1);
				    }
				 else
				    {
				       if ((map_ptr_hriz[map_temp] + 1) < ((level_bytes / 144) * 16))
					  map_ptr_hriz[map_temp]++;
				    }
				 levelmodified = TRUE;
			      }

			   if ((cursor_x <= (((level_bytes / 144) * 16) - 1)) && (map_space_flag2))
			      {
				 if (key[KEY_CONTROL])
				    {
				       if (map_sprites[map_temp2][1] < ((level_bytes / 144) - 1))
					  map_sprites[map_temp2][1]++;
				       else
					  map_sprites[map_temp2][2] = 0xF0;
				    }
				 else
				    {
				       if (((map_sprites[map_temp2][2] / 16) + (map_sprites[map_temp2][1] * 16)) < (((level_bytes / 144) * 16) - 1))
					  {
					     if ((map_sprites[map_temp2][2] / 16) == 0xF)
						{
						   map_sprites[map_temp2][2] = 0;
						   map_sprites[map_temp2][1]++;
						}
					     else
						map_sprites[map_temp2][2] += 16;
					  }
				    }
				 levelmodified = TRUE;
			      }



			   if ((cursor_x - x_screen_loc) > 19)
			      scroll_level_right();

			}

		     if ((key[KEY_STOP]) && (key[KEY_SPACE]) && (map_space_flag2))
			{
			   rest(30);
			   if ((cursor_x > ((level_bytes / 144) * 16)) || (cursor_y > 9))
			      goto skipmapa;

			   map_sprites[map_temp2][3]++;

			   check_flag = TRUE;
			   levelmodified = TRUE;
			 skipmapa:
			}

		     if ((key[KEY_COMMA]) && (key[KEY_SPACE]) && (map_space_flag2))
			{
			   rest(30);
			   if ((cursor_x > ((level_bytes / 144) * 16)) || (cursor_y > 9))
			      goto skipmapb;

			   map_sprites[map_temp2][3]--;

			   check_flag = TRUE;
			   levelmodified = TRUE;
			 skipmapb:
			}

		     if (((key[KEY_STOP]) && (!key[KEY_SPACE])) || ((mouse_b & 2) && (!pointer_mode) && (!map_mouse_flag2)))
			{
			   rest(30);
			   if ((cursor_x > ((level_bytes / 144) * 16)) || (cursor_y > 9))
			      goto skipmap1;

			   maparray[cursor_y][cursor_x]++;
			 skipmap1:

			   check_flag = TRUE;
			   levelmodified = TRUE;
			}

		     if (((mouse_b & 2) || (key[KEY_ENTER])) && (pointer_mode))
			{
			   do_pointer_dialog();
			}

		     if (key[KEY_SPACE])
			{
			   if (pointer_mode)
			      {
				 for (i = 0; i < num_ptrs; i++)
				    {
				       if ((map_ptr_hriz[i] == cursor_x) && (((map_ptr_vert[i] / 16) - 2) == cursor_y))
					  {
					     if ((!map_space_flag) && (!map_space_flag2))
						{
						   map_space_flag = TRUE;
						   map_temp = i;
						}
					     break;
					  }
				    }
			      }
			   for (j = 0; j < 9; j++)
			      {
				 if ((((map_sprites[j][0] / 16) - 2) == cursor_y) && (((map_sprites[j][1] * 16) + (map_sprites[j][2] / 16)) == cursor_x))
				    {
				       if ((!map_space_flag) && (!map_space_flag2))
					  {
					     map_space_flag2 = TRUE;
					     map_temp2 = j;

					  }
				       break;
				    }
			      }

			}
		     else
			{
			   map_space_flag = FALSE;
			   map_space_flag2 = FALSE;
			}
		     if (map_mouse_flag)
			{
			   if (cursor_x > (((level_bytes / 144) * 16) - 1))
			      cursor_x = (((level_bytes / 144) * 16) - 1);
			   if (cursor_y > 8)
			      cursor_y = 8;
			   map_ptr_hriz[map_temp] = cursor_x;
			   map_ptr_vert[map_temp] = ((map_ptr_vert[map_temp] % 16) + ((cursor_y + 2) * 16));
			   levelmodified = TRUE;
			}

		     if (map_mouse_flag2)
			{
			   if (cursor_x > (((level_bytes / 144) * 16) - 1))
			      cursor_x = (((level_bytes / 144) * 16) - 1);
			   if (cursor_y > 8)
			      cursor_y = 8;
			   map_sprites[map_temp2][1] = (cursor_x / 16);
			   map_sprites[map_temp2][2] = ((cursor_x % 16) * 16);
			   map_sprites[map_temp2][0] = ((cursor_y + 2) * 16);
			   levelmodified = TRUE;
			}
		     if (mouse_b & 1)
			{
			   if (pointer_mode)
			      {
				 for (i = 0; i < num_ptrs; i++)
				    {
				       if ((map_ptr_hriz[i] == cursor_x) && (((map_ptr_vert[i] / 16) - 2) == cursor_y))
					  {
					     if ((!map_mouse_flag) && (!map_mouse_flag2))
						{
						   map_mouse_flag = TRUE;
						   map_temp = i;
						}
					     break;
					  }
				    }
			      }
			   for (j = 0; j < 9; j++)
			      {
				 if ((((map_sprites[j][0] / 16) - 2) == cursor_y) && (((map_sprites[j][1] * 16) + (map_sprites[j][2] / 16)) == cursor_x))
				    {
				       if ((!map_mouse_flag) && (!map_mouse_flag2))
					  {
					     map_mouse_flag2 = TRUE;
					     map_temp2 = j;
					  }
				       break;
				    }
			      }
			}
		     else
			{
			   map_mouse_flag = FALSE;
			   map_mouse_flag2 = FALSE;
			}

		     if (((key[KEY_COMMA]) && (!key[KEY_SPACE])) || ((mouse_b & 1) && (!pointer_mode) && (!map_mouse_flag2)))
			{
			   rest(30);
			   if ((cursor_x > ((level_bytes / 144) * 16)) || (cursor_y > 9))
			      goto skipmap2;

			   maparray[cursor_y][cursor_x]--;
			 skipmap2:

			   check_flag = TRUE;
			   levelmodified = TRUE;
			}
		     if (key[KEY_J])
			{
			   rest(30);
			   if ((cursor_x > ((level_bytes / 144) * 16)) || (cursor_y > 9))
			      goto skipmap3;

			   maparray[cursor_y][cursor_x] -= 16;
			 skipmap3:

			   check_flag = TRUE;
			   levelmodified = TRUE;
			}
		     if (key[KEY_K])
			{
			   rest(30);
			   if ((cursor_x > ((level_bytes / 144) * 16)) || (cursor_y > 9))
			      goto skipmap4;

			   maparray[cursor_y][cursor_x] += 16;
			 skipmap4:

			   check_flag = TRUE;
			   levelmodified = TRUE;
			}







		     if (key[KEY_W])
			user_choose_level();

		     if (key[KEY_S])
			{
			   save_level_new();
			}
		     if (key[KEY_ESC])
			{
			   quit();
			}

		     if (key[KEY_P])
			{
			   PALLETE dump_pallete;
			   BITMAP *dump = create_sub_bitmap(screen, 0, 480, 320, 240);

			   blit(main_display, dump, 0, 0, 0, 0, 320, 200);
			   blit(status_display, dump, 0, 0, 0, 200, 320, 40);
			   get_pallete(dump_pallete);
			   save_bitmap("m3i.pcx", dump, dump_pallete);
			   destroy_bitmap(dump);
			}


		     goto skipnormalkeys;

		  }

	       if (key[KEY_3])
		  {
		     toggle_3byte();
		  }
	       if (key[KEY_4])
		  {
		     toggle_4byte();
		  }

	       if (key[KEY_W])
		  user_choose_level();

	       if (key[KEY_S])
		  {
		     save_level_new();
		  }
	       if (key[KEY_ESC])
		  {
		     quit();
		  }



	       if (key[KEY_ENTER])
		  {
		     for (i = 0; i < tbyte_objs; i++)
			{
			   if (vertical_flag)
			      {
				 x_position = (tbyte_array[1][i] % 16);
				 y_position = (((tbyte_array[1][i] / 16) * 15) + (tbyte_array[0][i] % 32));
			      }
			   else
			      {
				 x_position = tbyte_array[1][i];
				 y_position = (tbyte_array[0][i] % 32);
			      }
			   if ((cursor_x == x_position) && (cursor_y == y_position) && ((tbyte_array[0][i] / 32) == 7))
			      {
				 temp_ptr = i;
			       redo_pointer_dialog_number_3:
				 sprintf(pd3_hriz_buf, "Entrance Horizontal Location: %X0-%XF", (tbyte_array[0][temp_ptr] % 16), (tbyte_array[0][temp_ptr] % 16));
				 if ((tbyte_array[1][temp_ptr] / 16) < 8)
				    sprintf(pd3_vert_buf, "Exit Vertical Location: %X", ptr3_vert_values[tbyte_array[1][temp_ptr] / 16]);
				 else
				    sprintf(pd3_vert_buf, "Exit Vertical Location: %X (vertical level)", ptr3_vert_values[tbyte_array[1][temp_ptr] / 16]);
				 real_hriz_exit_loc = ((tbyte_array[2][temp_ptr] % 16) * 16);
				 real_hriz_exit_loc += (tbyte_array[2][temp_ptr] / 16);
				 old_slider_pos1 = pointer_dialog_3[2].d2 = (tbyte_array[0][temp_ptr] % 16);
				 old_slider_pos2 = pointer_dialog_3[5].d2 = (tbyte_array[1][temp_ptr] / 16);
				 pointer_dialog_3[7].d1 = (tbyte_array[1][temp_ptr] % 16);
				 sprintf(pd3_hriz_buf_2, "%X", real_hriz_exit_loc);
				 init_moveable(pointer_dialog_3);
				 pointer_player = init_dialog(pointer_dialog_3, -1);
				 while (update_dialog(pointer_player))
				    {
				       if (pointer_dialog_3[2].d2 != old_slider_pos1)
					  {
					     sprintf(pd3_hriz_buf, "Entrance Horizontal Location: %X0-%XF  ", pointer_dialog_3[2].d2, pointer_dialog_3[2].d2);
					     SEND_MESSAGE((pointer_dialog_3 + 1), MSG_DRAW, 0);
					  }
				       if (pointer_dialog_3[5].d2 != old_slider_pos2)
					  {
					     if (pointer_dialog_3[5].d2 < 8)
						sprintf(pd3_vert_buf, "Exit Vertical Location: %X                            ", ptr3_vert_values[pointer_dialog_3[5].d2]);
					     else
						sprintf(pd3_vert_buf, "Exit Vertical Location: %X (vertical level)    ", ptr3_vert_values[pointer_dialog_3[5].d2]);
					     SEND_MESSAGE((pointer_dialog_3 + 4), MSG_DRAW, 0);
					  }
				       old_slider_pos2 = pointer_dialog_3[5].d2;
				       old_slider_pos1 = pointer_dialog_3[2].d2;
				    }
				 shutdown_moveable(pointer_dialog_3);
				 if (shutdown_dialog(pointer_player) == 9)
				    {
				       error_chk_tmp = strtol(pd3_hriz_buf_2, &bp, 16);
				       if (bp[0] != '\0')
					  {
					     billalert("Error", "Please enter a hexadecimal value between 0x0 and 0xFF", "for the exit horizontal location.", "OK", NULL, NULL, NULL);
					     goto redo_pointer_dialog_number_3;
					  }
				       real_hriz_exit_loc = strtol(pd3_hriz_buf_2, &bp, 16);
				       tbyte_array[2][temp_ptr] = ((real_hriz_exit_loc % 16) * 16);
				       tbyte_array[2][temp_ptr] += (real_hriz_exit_loc / 16);
				       tbyte_array[0][temp_ptr] = (((tbyte_array[0][temp_ptr] / 16) * 16) + pointer_dialog_3[2].d2);
				       tbyte_array[1][temp_ptr] = (pointer_dialog_3[5].d2 * 16);
				       tbyte_array[1][temp_ptr] += pointer_dialog_3[7].d1;
				       levelmodified = TRUE;
				    }
				 break;
			      }
			}
		  }



	       if (key[KEY_SPACE] && key[KEY_STOP])
		  {
		     for (i = 0; i < tbyte_objs; i++)
			{
			   domain = (tbyte_array[0][i] / 32);
			   if (vertical_flag)
			      {
				 x_position = (tbyte_array[1][i] % 16);
				 y_position = (((tbyte_array[1][i] / 16) * 15) + (tbyte_array[0][i] % 32));
			      }
			   else
			      {
				 x_position = tbyte_array[1][i];
				 y_position = (tbyte_array[0][i] % 32);
			      }

			   if ((cursor_x == x_position) && (cursor_y == y_position))
			      {
				 if (space_flag == TRUE)
				    space_flag = FALSE;
				 else
				    goto skipassign7;

				 flag = 0;
				 temptk = i;

			       skipassign7:
				 break;
			      }
			}
		     if (space_flag == FALSE)
			{
			   if (flag == 0)
			      {
				 if ((tbyte_array[2][temptk] + (domain * 256)) >= 2047)
				    goto skip9;


				 if (tbyte_array[2][temptk] >= 255)
				    {
				       tbyte_array[2][temptk] = 0;
				       tbyte_array[0][temptk] += 32;
				    }
				 rest(30);
				 tbyte_array[2][temptk]++;
			       skip9:
				 check_flag = TRUE;
				 levelmodified = TRUE;
			      }
			}


		     for (j = 0; j < fbyte_objs; j++)
			{
			   domain = (fbyte_array[0][j] / 32);
			   if (vertical_flag)
			      {
				 x_position = (fbyte_array[1][j] % 16);
				 y_position = (((fbyte_array[1][j] / 16) * 15) + (fbyte_array[0][j] % 32));
			      }
			   else
			      {
				 x_position = fbyte_array[1][j];
				 y_position = (fbyte_array[0][j] % 32);
			      }

			   if ((cursor_x == x_position) && (cursor_y == y_position))
			      {
				 if (space_flag == TRUE)
				    space_flag = FALSE;
				 else
				    goto skipassign8;
				 tempfk = j;
				 flag = 1;
			       skipassign8:
				 break;
			      }
			}
		     if (space_flag == FALSE)
			{
			   if (flag == 1)
			      {
				 if ((fbyte_array[2][tempfk] + (domain * 256)) >= 2047)
				    goto skip15;

				 if (fbyte_array[2][tempfk] >= 255)
				    {
				       fbyte_array[2][tempfk] = 0;
				       fbyte_array[0][tempfk] += 32;
				    }
				 rest(40);
				 fbyte_array[2][tempfk]++;
			       skip15:
				 check_flag = TRUE;
				 levelmodified = TRUE;
			      }
			}

		     for (k = 0; k < enemy_objs; k++)
			{
			   if ((cursor_x == enemy_array[1][k]) && (cursor_y == enemy_array[2][k]))
			      {
				 if (space_flag == TRUE)
				    space_flag = FALSE;
				 else
				    goto skipassign9;

				 tempek = k;
				 flag = 2;
			       skipassign9:
				 break;
			      }
			}
		     if (space_flag == FALSE)
			{
			   if (flag == 2)
			      {
				 if (enemy_array[0][tempek] >= 255)
				    goto skip32;

				 rest(30);
				 enemy_array[0][tempek]++;
			       skip32:
          			 check_flag = TRUE;
				 levelmodified = TRUE;
			      }
			}
		  }


	       if (key[KEY_SPACE] && key[KEY_COMMA])
		  {

		     for (i = 0; i < tbyte_objs; i++)
			{
			   domain = (tbyte_array[0][i] / 32);
			   if (vertical_flag)
			      {
				 x_position = (tbyte_array[1][i] % 16);
				 y_position = (((tbyte_array[1][i] / 16) * 15) + (tbyte_array[0][i] % 32));
			      }
			   else
			      {
				 x_position = tbyte_array[1][i];
				 y_position = (tbyte_array[0][i] % 32);
			      }

			   if ((cursor_x == x_position) && (cursor_y == (y_position)))
			      {
				 if (space_flag == TRUE)
				    space_flag = FALSE;
				 else
				    goto skipassign10;
				 temptk = i;
				 flag = 0;
			       skipassign10:
				 break;
			      }
			}
		     if (space_flag == FALSE)
			{
			   if (flag == 0)
			      {
				 if ((tbyte_array[2][temptk] + (domain * 256)) <= 0)
				    goto skip10;

				 if (tbyte_array[2][temptk] <= 0)
				    {
				       tbyte_array[2][temptk] = 255;
				       tbyte_array[0][temptk] -= 32;
				    }
				 rest(30);
				 tbyte_array[2][temptk]--;
			       skip10:
				 check_flag = TRUE;
				 levelmodified = TRUE;
			      }
			}



		     for (j = 0; j < fbyte_objs; j++)
			{
			   domain = (fbyte_array[0][j] / 32);
			   if (vertical_flag)
			      {
				 x_position = (fbyte_array[1][j] % 16);
				 y_position = (((fbyte_array[1][j] / 16) * 15) + (fbyte_array[0][j] % 32));
			      }
			   else
			      {
				 x_position = fbyte_array[1][j];
				 y_position = (fbyte_array[0][j] % 32);
			      }

			   if ((cursor_x == x_position) && (cursor_y == (y_position)))
			      {
				 if (space_flag == TRUE)
				    space_flag = FALSE;
				 else
				    goto skipassign11;

				 tempfk = j;
				 flag = 1;
			       skipassign11:
				 break;
			      }
			}
		     if (space_flag == FALSE)
			{
			   if (flag == 1)
			      {
				 if ((fbyte_array[2][tempfk] + (domain * 256)) <= 0)
				    goto skip16;

				 if (fbyte_array[2][tempfk] <= 0)
				    {
				       fbyte_array[2][tempfk] = 255;
				       fbyte_array[0][tempfk] -= 32;
				    }
				 rest(30);
				 fbyte_array[2][tempfk]--;
			       skip16:
				 check_flag = TRUE;
				 levelmodified = TRUE;
			      }
			}


		     for (k = 0; k < enemy_objs; k++)
			{

			   if ((cursor_x == enemy_array[1][k]) && (cursor_y == enemy_array[2][k]))
			      {
				 if (space_flag == TRUE)
				    space_flag = FALSE;
				 else
				    goto skipassign12;
				 flag = 2;
				 tempek = k;

			       skipassign12:
				 break;
			      }
			}
		     if (space_flag == FALSE)
			{
			   if (flag == 2)
			      {
				 if (enemy_array[0][tempek] <= 0)
				    goto skip34;

				 rest(30);
				 enemy_array[0][tempek]--;
			       skip34:
				 check_flag = TRUE;
				 levelmodified = TRUE;
			      }
			}
		  }
	       if (key[KEY_SPACE] && key[KEY_N])
		  {
		     for (i = 0; i < tbyte_objs; i++)
			{
			   domain = (tbyte_array[0][i] / 32);
			   if (vertical_flag)
			      {
				 x_position = (tbyte_array[1][i] % 16);
				 y_position = (((tbyte_array[1][i] / 16) * 15) + (tbyte_array[0][i] % 32));
			      }
			   else
			      {
				 x_position = tbyte_array[1][i];
				 y_position = (tbyte_array[0][i] % 32);
			      }

			   if ((cursor_x == x_position) && (cursor_y == (y_position)))
			      {
				 if (space_flag == TRUE)
				    space_flag = FALSE;
				 else
				    goto skipassign13;
				 flag = 0;
				 temptk = i;
			       skipassign13:
				 break;
			      }
			}
		     if (space_flag == FALSE)
			{
			   if (flag == 0)
			      {
				 if ((tbyte_array[2][temptk] + (domain * 256)) <= 0)
				    goto skip19;

				 rest(30);
				 tbyte_array[0][temptk] -= 32;
			       skip19:

				 check_flag = TRUE;
				 levelmodified = TRUE;
			      }

			}






		     for (j = 0; j < fbyte_objs; j++)
			{
			   domain = (fbyte_array[0][j] / 32);
			   if (vertical_flag)
			      {
				 x_position = (fbyte_array[1][j] % 16);
				 y_position = (((fbyte_array[1][j] / 16) * 15) + (fbyte_array[0][j] % 32));
			      }
			   else
			      {
				 x_position = fbyte_array[1][j];
				 y_position = (fbyte_array[0][j] % 32);
			      }

			   if ((cursor_x == x_position) && (cursor_y == (y_position)))
			      {
				 if (space_flag == TRUE)
				    space_flag = FALSE;
				 else
				    goto skipassign14;



				 flag = 1;
				 tempfk = j;

			       skipassign14:
				 break;
			      }
			}

		     if (space_flag == FALSE)
			{
			   if (flag == 1)
			      {
				 if ((fbyte_array[2][tempfk] + (domain * 256)) <= 0)
				    goto skip17;


				 rest(30);
				 fbyte_array[0][tempfk] -= 32;
			       skip17:
				 check_flag = TRUE;
				 levelmodified = TRUE;
			      }
			}
		  }

	       if (key[KEY_SPACE] && key[KEY_M])
		  {

		     for (i = 0; i < tbyte_objs; i++)
			{
			   domain = (tbyte_array[0][i] / 32);
			   if (vertical_flag)
			      {
				 x_position = (tbyte_array[1][i] % 16);
				 y_position = (((tbyte_array[1][i] / 16) * 15) + (tbyte_array[0][i] % 32));
			      }
			   else
			      {
				 x_position = tbyte_array[1][i];
				 y_position = (tbyte_array[0][i] % 32);
			      }

			   if ((cursor_x == x_position) && (cursor_y == (y_position)))
			      {
				 if (space_flag == TRUE)
				    space_flag = FALSE;
				 else
				    goto skipassign15;



				 flag = 0;
				 temptk = i;

			       skipassign15:
				 break;
			      }
			}
		     if (space_flag == FALSE)
			{
			   if (flag == 0)
			      {
				 if ((tbyte_array[2][temptk] + (domain * 256)) >= 2047)
				    goto skip20;

				 rest(30);
				 tbyte_array[0][temptk] += 32;
			       skip20:
				 check_flag = TRUE;
				 levelmodified = TRUE;
			      }
			}







		     for (j = 0; j < fbyte_objs; j++)
			{
			   domain = (fbyte_array[0][j] / 32);
			   if (vertical_flag)
			      {
				 x_position = (fbyte_array[1][j] % 16);
				 y_position = (((fbyte_array[1][j] / 16) * 15) + (fbyte_array[0][j] % 32));
			      }
			   else
			      {
				 x_position = fbyte_array[1][j];
				 y_position = (fbyte_array[0][j] % 32);
			      }

			   if ((cursor_x == x_position) && (cursor_y == (y_position)))
			      {
				 if (space_flag == TRUE)
				    space_flag = FALSE;
				 else
				    goto skipassign16;

				 flag = 1;
				 tempfk = j;

			       skipassign16:
				 break;
			      }
			}
		     if (space_flag == FALSE)
			{
			   if (flag == 1)
			      {
				 if ((fbyte_array[2][tempfk] + (domain * 256)) >= 2047)
				    goto skip18;


				 rest(30);
				 fbyte_array[0][tempfk] += 32;
			       skip18:
				 check_flag = TRUE;
				 levelmodified = TRUE;
			      }
			}
		  }










	       if (key[KEY_SPACE] && key[KEY_J])
		  {
		     for (i = 0; i < tbyte_objs; i++)
			{
			   domain = (tbyte_array[0][i] / 32);
			   if (vertical_flag)
			      {
				 x_position = (tbyte_array[1][i] % 16);
				 y_position = (((tbyte_array[1][i] / 16) * 15) + (tbyte_array[0][i] % 32));
			      }
			   else
			      {
				 x_position = tbyte_array[1][i];
				 y_position = (tbyte_array[0][i] % 32);
			      }

			   if ((cursor_x == x_position) && (cursor_y == (y_position)))
			      {
				 if (space_flag == TRUE)
				    space_flag = FALSE;
				 else
				    goto skipassign17;

				 flag = 0;
				 temptk = i;

			       skipassign17:
				 break;
			      }
			}

		     if (space_flag == FALSE)
			{
			   if (flag == 0)
			      {
				 if ((tbyte_array[2][temptk] + (domain * 256)) <= 0)
				    goto skip23;


				 if (tbyte_array[2][temptk] <= 15)
				    {
				       tbyte_array[2][temptk] = ((tbyte_array[2][temptk] % 16) + 240);
				       tbyte_array[0][temptk] -= 32;
				       rest(30);
				       goto skip23;
				    }
				 rest(30);
				 tbyte_array[2][temptk] -= 16;
			       skip23:

				 check_flag = TRUE;
				 levelmodified = TRUE;
			      }
			}

		     for (j = 0; j < fbyte_objs; j++)
			{
			   domain = (fbyte_array[0][j] / 32);
			   if (vertical_flag)
			      {
				 x_position = (fbyte_array[1][j] % 16);
				 y_position = (((fbyte_array[1][j] / 16) * 15) + (fbyte_array[0][j] % 32));
			      }
			   else
			      {
				 x_position = fbyte_array[1][j];
				 y_position = (fbyte_array[0][j] % 32);
			      }

			   if ((cursor_x == x_position) && (cursor_y == (y_position)))
			      {
				 if (space_flag == TRUE)
				    space_flag = FALSE;
				 else
				    goto skipassign18;
				 flag = 1;
				 tempfk = j;

			       skipassign18:
				 break;
			      }
			}
		     if (space_flag == FALSE)
			{
			   if (flag == 1)
			      {
				 if ((fbyte_array[2][tempfk] + (domain * 256)) <= 0)
				    goto skip26;

				 if (fbyte_array[2][tempfk] <= 15)
				    {
				       fbyte_array[2][tempfk] = ((fbyte_array[2][tempfk] % 16) + 240);
				       fbyte_array[0][tempfk] -= 32;
				       rest(30);
				       goto skip26;

				    }
				 rest(30);
				 fbyte_array[2][tempfk] -= 16;
			       skip26:

				 check_flag = TRUE;
				 levelmodified = TRUE;
			      }

			}


		     for (k = 0; k < enemy_objs; k++)
			{
			   if ((cursor_x == enemy_array[1][k]) && (cursor_y == enemy_array[2][k]))
			      {
				 if (space_flag == TRUE)
				    space_flag = FALSE;
				 else
				    goto skipassign19;

				 flag = 2;
				 tempek = k;

			       skipassign19:
				 break;
			      }
			}
		     if (space_flag == FALSE)
			{
			   if (flag == 2)
			      {
				 if (enemy_array[0][tempek] <= 0)
				    goto skip31;
				 rest(30);
				 enemy_array[0][tempek] -= 16;
			       skip31:
				 check_flag = TRUE;
				 levelmodified = TRUE;
			      }
			}
		  }

	       if (key[KEY_SPACE] && key[KEY_K])
		  {
		     for (i = 0; i < tbyte_objs; i++)
			{
			   domain = (tbyte_array[0][i] / 32);
			   if (vertical_flag)
			      {
				 x_position = (tbyte_array[1][i] % 16);
				 y_position = (((tbyte_array[1][i] / 16) * 15) + (tbyte_array[0][i] % 32));
			      }
			   else
			      {
				 x_position = tbyte_array[1][i];
				 y_position = (tbyte_array[0][i] % 32);
			      }

			   if ((cursor_x == x_position) && (cursor_y == (y_position)))
			      {
				 if (space_flag == TRUE)
				    space_flag = FALSE;
				 else
				    goto skipassign20;

				 flag = 0;
				 temptk = i;
			       skipassign20:
				 break;
			      }
			}
		     if (space_flag == FALSE)
			{
			   if (flag == 0)
			      {
				 if ((tbyte_array[2][temptk] + (domain * 256)) >= 2047)
				    goto skip24;

				 if (tbyte_array[2][temptk] >= 240)
				    {
				       tbyte_array[2][temptk] = (tbyte_array[2][temptk] % 16);
				       tbyte_array[0][temptk] += 32;
				       rest(30);
				       goto skip24;
				    }
				 rest(30);
				 tbyte_array[2][temptk] += 16;
			       skip24:
				 check_flag = TRUE;
				 levelmodified = TRUE;
			      }
			}


		     for (j = 0; j < fbyte_objs; j++)
			{
			   domain = (fbyte_array[0][j] / 32);
			   if (vertical_flag)
			      {
				 x_position = (fbyte_array[1][j] % 16);
				 y_position = (((fbyte_array[1][j] / 16) * 15) + (fbyte_array[0][j] % 32));
			      }
			   else
			      {
				 x_position = fbyte_array[1][j];
				 y_position = (fbyte_array[0][j] % 32);
			      }

			   if ((cursor_x == x_position) && (cursor_y == (y_position)))
			      {
				 if (space_flag == TRUE)
				    space_flag = FALSE;
				 else
				    goto skipassign21;

				 flag = 1;
				 tempfk = j;

			       skipassign21:
				 break;
			      }
			}

		     if (space_flag == FALSE)
			{
			   if (flag == 1)
			      {
				 if ((fbyte_array[2][tempfk] + (domain * 256)) >= 2047)
				    goto skip25;


				 if (fbyte_array[2][tempfk] >= 240)
				    {
				       fbyte_array[2][tempfk] = (fbyte_array[2][tempfk] % 16);
				       fbyte_array[0][tempfk] += 32;
				       rest(30);
				       goto skip25;
				    }
				 rest(30);
				 fbyte_array[2][tempfk] += 16;
			       skip25:
				 check_flag = TRUE;
				 levelmodified = TRUE;
			      }
			}


		     for (k = 0; k < enemy_objs; k++)
			{
			   if ((cursor_x == enemy_array[1][k]) && (cursor_y == enemy_array[2][k]))
			      {
				 if (space_flag == TRUE)
				    space_flag = FALSE;
				 else
				    goto skipassign22;
				 flag = 2;
				 tempek = k;

			       skipassign22:
				 break;
			      }
			}
		     if (space_flag == FALSE)
			{
			   if (flag == 2)
			      {
				 if (enemy_array[0][tempek] >= 256)
				    goto skip30;

				 rest(30);
				 enemy_array[0][tempek] += 16;
			       skip30:
				 check_flag = TRUE;
				 levelmodified = TRUE;
			      }
			}
		  }




	       if (key[KEY_SPACE] && key[KEY_QUOTE])
		  {
		     for (j = 0; j < fbyte_objs; j++)
			{
			   domain = (fbyte_array[0][j] / 32);
			   if (vertical_flag)
			      {
				 x_position = (fbyte_array[1][j] % 16);
				 y_position = (((fbyte_array[1][j] / 16) * 15) + (fbyte_array[0][j] % 32));
			      }
			   else
			      {
				 x_position = fbyte_array[1][j];
				 y_position = (fbyte_array[0][j] % 32);
			      }

			   if ((cursor_x == x_position) && (cursor_y == (y_position)))
			      {
				 index = j;
				 flag = 1;
				 break;
			      }
			}




		     if (flag == 1)
			{
			   if (fbyte_array[3][j] >= 254)
			      debug = 1;
			   if (fbyte_array[3][j] >= 255)
			      goto skip21;
			   rest(30);
			   fbyte_array[3][j]++;
			 skip21:
			   check_flag = TRUE;
			   levelmodified = TRUE;
			}
		  }






	       if (key[KEY_SPACE] && key[KEY_COLON])
		  {
		     for (j = 0; j < fbyte_objs; j++)
			{
			   domain = (fbyte_array[0][j] / 32);
			   if (vertical_flag)
			      {
				 x_position = (fbyte_array[1][j] % 16);
				 y_position = (((fbyte_array[1][j] / 16) * 15) + (fbyte_array[0][j] % 32));
			      }
			   else
			      {
				 x_position = fbyte_array[1][j];
				 y_position = (fbyte_array[0][j] % 32);
			      }

			   if ((cursor_x == x_position) && (cursor_y == (y_position)))
			      {
				 index = j;
				 flag = 1;
				 break;
			      }
			}



		     if (flag == 1)
			{
			   if (fbyte_array[3][j] <= 0)
			      goto skip22;
			   rest(30);
			   fbyte_array[3][j]--;
			 skip22:
			   check_flag = TRUE;
			   levelmodified = TRUE;
			}
		  }

	       if (((cursor_x != diff_x) || (cursor_y != diff_y)) && (!(mouse_b & 1)))
		  {
		     mouse_button_flag = TRUE;
		     set_mouse_speed(2, 2);
		  }

	       if (((cursor_x != diffk_x) || (cursor_y != diffk_y)) && (!(key[KEY_SPACE])))
		  {
		     space_flag = TRUE;
		  }


//  ************KEY_SPACE HANDLER*****************

	       if (key[KEY_SPACE])
		  {
		     for (i = 0; i < tbyte_objs; i++)
			{
			   if (vertical_flag)
			      {
				 x_position = (tbyte_array[1][i] % 16);
				 y_position = (((tbyte_array[1][i] / 16) * 15) + (tbyte_array[0][i] % 32));
			      }
			   else
			      {
				 x_position = tbyte_array[1][i];
				 y_position = (tbyte_array[0][i] % 32);
			      }


			   if ((cursor_x == x_position) && (cursor_y == (y_position)))
			      {
				 if (space_flag == TRUE)
				    space_flag = FALSE;
				 else
				    goto skipassign3;

				 flag = 0;
				 temptk = i;

			       skipassign3:
				 break;
			      }
			}
		     if (key[KEY_SPACE])
			{
			   if (space_flag == FALSE)
			      {
				 if (flag == 0)
				    {
				       if (!vertical_flag)
					  {
					     if (cursor_y > 27)
						cursor_y = 27;
					  }
				       else
					  {
					     if (cursor_x > 15)
						cursor_x = 15;
					  }
				    }
				 diffk_x = cursor_x;
				 diffk_y = cursor_y;
				 domain = (tbyte_array[0][temptk] / 32);
				 if (flag == 0)
				    {
				       if (!vertical_flag)
					  {
					     tbyte_array[1][temptk] = diffk_x;
					     tbyte_array[0][temptk] = (diffk_y + (domain * 32));
					  }
				       else
					  {
					     tbyte_array[1][temptk] = (diffk_x + ((diffk_y / 15) * 16));
					     tbyte_array[0][temptk] = ((diffk_y % 15) + (domain * 32));
					  }
				       levelmodified = TRUE;
				    }
			      }
			}



		     for (j = 0; j < fbyte_objs; j++)
			{
			   if (vertical_flag)
			      {
				 x_position = (fbyte_array[1][j] % 16);
				 y_position = (((fbyte_array[1][j] / 16) * 15) + (fbyte_array[0][j] % 32));
			      }
			   else
			      {
				 x_position = fbyte_array[1][j];
				 y_position = (fbyte_array[0][j] % 32);
			      }



			   if ((cursor_x == x_position) && (cursor_y == (y_position)))
			      {
				 if (space_flag == TRUE)
				    space_flag = FALSE;
				 else
				    goto skipassign4;
				 flag = 1;
				 tempfk = j;
			       skipassign4:
				 break;

			      }
			}


		     if (key[KEY_SPACE])
			{
			   if (space_flag == FALSE)
			      {
				 if (flag == 1)
				    {
				       if (!vertical_flag)
					  {
					     if (cursor_y > 27)
						cursor_y = 27;
					  }
				       else
					  {
					     if (cursor_x > 15)
						cursor_x = 15;
					  }
				    }
				 diffk_x = cursor_x;
				 diffk_y = cursor_y;
				 domain = (fbyte_array[0][tempfk] / 32);
				 if (flag == 1)
				    {
				       if (!vertical_flag)
					  {
					     fbyte_array[1][tempfk] = diffk_x;
					     fbyte_array[0][tempfk] = (diffk_y + (domain * 32));
					  }
				       else
					  {
					     fbyte_array[1][tempfk] = (diffk_x + ((diffk_y / 15) * 16));
					     fbyte_array[0][tempfk] = ((diffk_y % 15) + (domain * 32));
					  }
				       levelmodified = TRUE;
				    }
			      }
			}

		     for (k = 0; k < enemy_objs; k++)
			{
			   if ((cursor_x == enemy_array[1][k]) && (cursor_y == enemy_array[2][k]))
			      {
				 if (space_flag == TRUE)
				    space_flag = FALSE;
				 else
				    goto skipassign5;
				 flag = 2;
				 tempek = k;
			       skipassign5:
				 break;
			      }
			}


		     if (key[KEY_SPACE])
			{
			   if (space_flag == FALSE)
			      {
				 diffk_x = cursor_x;
				 diffk_y = cursor_y;
				 if (flag == 2)
				    {
				       enemy_array[1][tempek] = diffk_x;
				       enemy_array[2][tempek] = diffk_y;
				       levelmodified = TRUE;
				    }
			      }
			}
		  }



	       /////***************MOUSE HANDLER




	       if (mouse_b & 1)
		  {
		     for (i = 0; i < tbyte_objs; i++)
			{
			   if (vertical_flag)
			      {
				 x_position = (tbyte_array[1][i] % 16);
				 y_position = (((tbyte_array[1][i] / 16) * 15) + (tbyte_array[0][i] % 32));
			      }
			   else
			      {
				 x_position = tbyte_array[1][i];
				 y_position = (tbyte_array[0][i] % 32);
			      }


			   if ((cursor_x == x_position) && (cursor_y == (y_position)))
			      {
				 if (mouse_button_flag == TRUE)
				    mouse_button_flag = FALSE;
				 else
				    goto skipassign1;
				 flag = 0;
				 tempt = i;
			       skipassign1:
				 break;
			      }
			}
		     if (mouse_b & 1)
			{
			   if (mouse_button_flag == FALSE)
			      {
				 set_mouse_speed(2, 2);
				 if (flag == 0)
				    {
				       if (!vertical_flag)
					  {
					     if (cursor_y > 27)
						cursor_y = 27;
					  }
				       else
					  {
					     if (cursor_x > 15)
						cursor_x = 15;
					  }
				    }
				 diff_x = cursor_x;
				 diff_y = cursor_y;

				 domain = (tbyte_array[0][tempt] / 32);
				 if (flag == 0)
				    {
				       if (!vertical_flag)
					  {
					     tbyte_array[1][tempt] = diff_x;
					     tbyte_array[0][tempt] = (diff_y + (domain * 32));
					  }
				       else
					  {
					     tbyte_array[1][tempt] = (diff_x + ((diff_y / 15) * 16));
					     tbyte_array[0][tempt] = ((diff_y % 15) + (domain * 32));
					  }
				       levelmodified = TRUE;
				    }

			      }

			}





		     for (j = 0; j < fbyte_objs; j++)
			{
			   if (vertical_flag)
			      {
				 x_position = (fbyte_array[1][j] % 16);
				 y_position = (((fbyte_array[1][j] / 16) * 15) + (fbyte_array[0][j] % 32));
			      }
			   else
			      {
				 x_position = fbyte_array[1][j];
				 y_position = (fbyte_array[0][j] % 32);
			      }




			   if ((cursor_x == x_position) && (cursor_y == (y_position)))
			      {
				 if (mouse_button_flag == TRUE)
				    mouse_button_flag = FALSE;
				 else
				    goto skipassign2;
				 flag = 1;
				 tempf = j;
			       skipassign2:
				 break;
			      }
			}
		     if (mouse_b & 1)
			{
			   if (mouse_button_flag == FALSE)
			      {
				 set_mouse_speed(2, 2);
				 if (flag == 1)
				    {
				       if (!vertical_flag)
					  {
					     if (cursor_y > 27)
						cursor_y = 27;
					  }
				       else
					  {
					     if (cursor_x > 15)
						cursor_x = 15;
					  }
				    }
				 diff_x = cursor_x;
				 diff_y = cursor_y;
				 domain = (fbyte_array[0][tempf] / 32);
				 if (flag == 1)
				    {
				       if (!vertical_flag)
					  {
					     fbyte_array[1][tempf] = diff_x;
					     fbyte_array[0][tempf] = (diff_y + (domain * 32));
					  }
				       else
					  {
					     fbyte_array[1][tempf] = (diff_x + ((diff_y / 15) * 16));
					     fbyte_array[0][tempf] = ((diff_y % 15) + (domain * 32));
					  }
				       levelmodified = TRUE;
				    }
			      }
			}

		     for (k = 0; k < enemy_objs; k++)
			{
			   if ((cursor_x == enemy_array[1][k]) && (cursor_y == enemy_array[2][k]))
			      {
				 if (mouse_button_flag == TRUE)
				    mouse_button_flag = FALSE;
				 else
				    goto skipassign6;
				 flag = 2;
				 tempe = k;
			       skipassign6:
				 break;
			      }
			}
		     if (mouse_b & 1)
			{
			   if (mouse_button_flag == FALSE)
			      {
				 set_mouse_speed(2, 2);
				 diff_x = cursor_x;
				 diff_y = cursor_y;
				 if (flag == 2)
				    {
				       enemy_array[1][tempe] = diff_x;
				       enemy_array[2][tempe] = diff_y;
				       levelmodified = TRUE;
				    }
			      }
			}
		  }





	       if (key[KEY_P])
		  {
		     PALLETE dump_pallete;
		     BITMAP *dump = create_sub_bitmap(screen, 0, 480, 320, 240);
		     blit(main_display, dump, 0, 0, 0, 0, 320, 200);
		     blit(status_display, dump, 0, 0, 0, 200, 320, 40);
		     get_pallete(dump_pallete);
		     save_bitmap("m3i.pcx", dump, dump_pallete);
		     destroy_bitmap(dump);
		  }

	       else if (key[KEY_UP])
		  {
		     mouse_flag = FALSE;
		     rest(30);	//because cursor moves WAY too fast otherwise :)
		     if (key[KEY_CONTROL])
			{
			   if ((cursor_y - 16) > 0)
			      cursor_y -= 16;
			   else
			      cursor_y = 0;
			}
		     else
			cursor_y--;
		     check_flag = TRUE;

		     if (cursor_y < 0)
			cursor_y = 0;
		     if ((cursor_y - y_screen_loc) < 1)

			scroll_level_up();
		  }


	       else if (key[KEY_DOWN])
		  {
		     mouse_flag = FALSE;
		     rest(30);
		     if (key[KEY_CONTROL])
			{
			   if ((cursor_y + 16) < 0xFF)
			      cursor_y += 16;
			   else
			      cursor_y = 0xFF;
			}
		     else
			cursor_y++;
		     if ((space_flag == FALSE) && (key[KEY_SPACE]) && ((flag == 1) || (flag == 0)) && (!vertical_flag))
			{
			   if (cursor_y > 27)
			      cursor_y = 27;
			}


		     check_flag = TRUE;
		     if (cursor_y > 0xFF)
			cursor_y = 0xFF;


		     if ((cursor_y - y_screen_loc) > 11)

			scroll_level_down();
		  }

	       else if (key[KEY_LEFT])
		  {
		     mouse_flag = FALSE;
		     rest(30);
		     if (key[KEY_CONTROL])
			{
			   if ((cursor_x - 16) > 0)
			      cursor_x -= 16;
			   else
			      cursor_x = 0;
			}
		     else
			cursor_x--;

		     check_flag = TRUE;
		     if (cursor_x < 0)
			cursor_x = 0;

		     if ((cursor_x - x_screen_loc) < 0)
			scroll_level_left();
		  }

	       else if (key[KEY_RIGHT])
		  {
		     mouse_flag = FALSE;
		     rest(30);
		     if (key[KEY_CONTROL])
			{
			   if ((cursor_x + 16) < 255)
			      cursor_x += 16;
			   else
			      cursor_x = 255;
			}
		     else
			cursor_x++;

		     if ((space_flag == FALSE) && (key[KEY_SPACE]) && ((flag == 1) || (flag == 0)) && (vertical_flag))
			{
			   if (cursor_x > 15)
			      cursor_x = 15;
			}

		     check_flag = TRUE;

		     if (cursor_x > 255)
			cursor_x = 255;


		     if ((cursor_x - x_screen_loc) > 19)
			scroll_level_right();
		  }
	       if (!(key[KEY_SPACE]))
		  {
		     key_flags[0] = FALSE;
		     key_flags[1] = FALSE;
		     key_flags[2] = FALSE;
		     key_flags[3] = FALSE;
		  }
	       if (!(key[KEY_ALT]))
		  {
		     key_flags[4] = FALSE;
		     key_flags[5] = FALSE;
		     key_flags[6] = FALSE;
		     key_flags[7] = FALSE;
		  }


	     invalid_key_combos:
	     skipnormalkeys:


	       text_mode(0);
	       blit(status_display, main_display, 0, 0, 0, 200, 320, 40);

	       if ((file_loaded) && (mapedit_flag))
		  {
		     file_menu[1].flags = 0;
		     file_menu[2].flags = 0;
		     file_menu[6].flags = 0;
		     file_menu[5].flags = D_DISABLED;
		     file_menu[4].flags = D_DISABLED;
		     level_menu[3].flags = D_DISABLED;
		     level_menu[4].flags = D_DISABLED;
		     level_menu[5].flags = D_DISABLED;
		     level_menu[6].flags = D_DISABLED;
		     level_menu[7].flags = D_DISABLED;
		     level_menu[8].flags = D_DISABLED;
		     if (pointer_mode)
			{
			   view_menu[5].flags = D_SELECTED;
			   if (pointer_numbers)
			      view_menu[6].flags = D_SELECTED;
			   else
			      view_menu[6].flags = 0;
			}
		     else
			{
			   view_menu[5].flags = 0;
			   view_menu[6].flags = D_DISABLED;
			}
		  }
	       else if ((file_loaded) && (!mapedit_flag))
		  {
		     file_menu[1].flags = 0;
		     file_menu[2].flags = 0;
		     file_menu[4].flags = D_DISABLED;
		     file_menu[5].flags = 0;
		     file_menu[6].flags = 0;
		     view_menu[5].flags = D_DISABLED;
		     view_menu[6].flags = D_DISABLED;
		     level_menu[3].flags = 0;
		     level_menu[4].flags = 0;
		     level_menu[5].flags = 0;
		     level_menu[6].flags = 0;
		     level_menu[7].flags = 0;
		     level_menu[8].flags = 0;
		  }

	       if ((file_loaded) && (freeform_mode))
		  {
		     file_menu[4].flags = 0;
		     file_menu[6].flags = 0;
		     level_menu[0].flags = D_DISABLED;
		     level_menu[1].flags = 0;
		     level_menu[3].flags = 0;
		     level_menu[4].flags = 0;
		     level_menu[5].flags = 0;
		     level_menu[6].flags = 0;
		     level_menu[7].flags = 0;
		     level_menu[8].flags = 0;
		     view_menu[5].flags = D_DISABLED;
		     view_menu[6].flags = D_DISABLED;
		     file_menu[1].flags = D_DISABLED;
		     file_menu[2].flags = D_DISABLED;
		  }


	       if (allstars_flag)
		  {
		     file_menu[1].flags = 0;
		     file_menu[2].flags = 0;
		     file_menu[4].flags = D_DISABLED;
		     file_menu[5].flags = D_DISABLED;
		     file_menu[6].flags = 0;
		     level_menu[3].flags = D_DISABLED;
		     level_menu[4].flags = D_DISABLED;
		     level_menu[5].flags = D_DISABLED;
		     level_menu[6].flags = D_DISABLED;
		     level_menu[7].flags = D_DISABLED;
		     level_menu[8].flags = D_DISABLED;
		     view_menu[5].flags = D_DISABLED;
		     view_menu[6].flags = D_DISABLED;
		  }


	       if (file_loaded)
		  {
		     if (mapedit_flag == TRUE)
			{
			   if (maparray[cursor_y][cursor_x] < 236)
			      object = maparray[cursor_y][cursor_x];
			   else
			      object = 236;

			   if ((map_space_flag2) || (map_mouse_flag2))
			      {
				 textprintf(status_display, font, 80, 0, 28, "Object #: %02X  ", map_sprites[map_temp2][3]);
				 textprintf(status_display, font, 168, 0, 28, "Domain: N/A");
				 textprintf(status_display, font, 240, 0, 28, "Length: N/A");
				 if (level_known)
				    textprintf(status_display, font, 0, 0, 28, "World %i-%i      ", world, level);
				 else
				    textprintf(status_display, font, 0, 0, 28, "World %i-?      ", world);
				 textprintf(status_display, font, 0, 10, 28, "Horizontal Location: %02X ", cursor_x);
				 textprintf(status_display, font, 160, 10, 28, "Vertical Location: %02X ", cursor_y);
				 if (map_sprites[map_temp2][3] > 0x10)
				    textprintf(status_display, font, 0, 20, 28, "Object: WARNING: Crashes Game                                                     ");
				 else
				    textprintf(status_display, font, 0, 20, 28, "Object: %s                                                                        ", map_sprite_names[map_sprites[map_temp2][3]]);
				 goto skipprintnormalobjectstuff;
			      }

			   if ((cursor_x > ((level_bytes / 144) * 16)) || (cursor_y > 9))
			      textprintf(status_display, font, 80, 0, 28, "Object #: N/A  ");
			   else
			      textprintf(status_display, font, 80, 0, 28, "Object #: %02X  ", maparray[cursor_y][cursor_x]);
			   textprintf(status_display, font, 168, 0, 28, "Domain: N/A");
			   textprintf(status_display, font, 240, 0, 28, "Length: N/A");
			   if (level_known)
			      textprintf(status_display, font, 0, 0, 28, "World %i-%i      ", world, level);
			   else
			      textprintf(status_display, font, 0, 0, 28, "World %i-?      ", world);
			   textprintf(status_display, font, 0, 10, 28, "Horizontal Location: %02X ", cursor_x);
			   textprintf(status_display, font, 160, 10, 28, "Vertical Location: %02X ", cursor_y);
			   textprintf(status_display, font, 0, 20, 28, "Object: %s                                                                        ", plains_level[level_object_set][object].obj_descript);
			 skipprintnormalobjectstuff:
			   goto skipprintnormal;
			}



		     if (flag == 0)
			{
			   if (key[KEY_SPACE])
			      object_num = temptk;
			   if (mouse_b & 1)
			      object_num = tempt;
			   length = (tbyte_array[2][object_num] / 16);
			   if (length == 0)
			      object = (((tbyte_array[0][object_num] / 32) * 31) + (tbyte_array[2][object_num]));
			   else
			      object = (((tbyte_array[0][object_num] / 32) * 31) + (tbyte_array[2][object_num] / 16) + 15);
			   textprintf(status_display, font, 80, 0, 28, "Object #: %02X  ", tbyte_array[2][object_num]);
			   textprintf(status_display, font, 168, 0, 28, "Domain: %i    ", (tbyte_array[0][object_num] / 32));
			   textprintf(status_display, font, 240, 0, 28, "Length: N/A");
			   if (plains_level[level_object_set][object].obj_flag != THREE_BYTE)
			      {
				 object = 186;
			      }
			}
		     if (flag == 1)
			{
			   if (key[KEY_SPACE])
			      object_num = tempfk;
			   if (mouse_b & 1)
			      object_num = tempf;
			   length = (fbyte_array[2][object_num] / 16);
			   if (length == 0)
			      object = (((fbyte_array[0][object_num] / 32) * 31) + (fbyte_array[2][object_num]));
			   else
			      object = (((fbyte_array[0][object_num] / 32) * 31) + (fbyte_array[2][object_num] / 16) + 15);
			   textprintf(status_display, font, 80, 0, 28, "Object #: %02X  ", fbyte_array[2][object_num]);
			   textprintf(status_display, font, 168, 0, 28, "Domain: %i    ", (fbyte_array[0][object_num] / 32));
			   textprintf(status_display, font, 240, 0, 28, "Length: %02X  ", fbyte_array[3][object_num]);
			   if (plains_level[level_object_set][object].obj_flag != FOUR_BYTE)
			      {
				 object = 186;
			      }
			}

		     if (flag == 2)
			{
			   if (key[KEY_SPACE])
			      object_num = tempek;
			   if (mouse_b & 1)
			      object_num = tempe;
			   object = enemy_array[0][object_num];
			   textprintf(status_display, font, 80, 0, 28, "Object #: %02X  ", enemy_array[0][object_num]);
			   textprintf(status_display, font, 168, 0, 28, "Domain: N/A");
			   textprintf(status_display, font, 240, 0, 28, "Length: N/A");
			}

		     if (level_known)
			textprintf(status_display, font, 0, 0, 28, "World %i-%i      ", world, level);
		     else
			textprintf(status_display, font, 0, 0, 28, "World %i-?      ", world);
		     textprintf(status_display, font, 0, 10, 28, "Horizontal Location %02X  ", cursor_x);
		     textprintf(status_display, font, 160, 10, 28, "Vertical Location: %02X  ", cursor_y);

		     if (flag == 2)
			{
			   if (object > 236)
			      textprintf(status_display, font, 0, 20, 28, "Object: %s                                                                                                    ", plains_level[11][236].obj_descript);
			   else
			      textprintf(status_display, font, 0, 20, 28, "Object: %s                                                                                                    ", plains_level[11][object].obj_descript);
			}
		     else
			textprintf(status_display, font, 0, 20, 28, "Object: %s                                                                                                            ", plains_level[level_object_set][object].obj_descript);
		     textprintf(status_display, font, 0, 30, 28, "4-byte objs: %i    ", fbyte_objs);
		     textprintf(status_display, font, 90, 30, 28, "3-byte objs: %i    ", tbyte_objs);
		     textprintf(status_display, font, 182, 30, 28, "Enemies: %i    ", enemy_objs);
		     textprintf(status_display, font, 245, 30, 28, "# Bytes: %i    ", level_bytes);
		  }



	     skipprintnormal:

	       if (mouse_flag == TRUE)
		  {
		     cursor_x = ((mouse_x / 16) + x_screen_loc);
		     cursor_y = ((mouse_y / 16) + y_screen_loc);
		     if (options_dialog[6].flags & D_SELECTED)
			{
			   if (cursor_x < 0)
			      cursor_x = 0;
			   if ((cursor_x - x_screen_loc) <= 0)
			      {
				 rest(30);
				 scroll_level_left();
			      }

			   if (cursor_y < 0)
			      cursor_y = 0;
			   if ((cursor_y - y_screen_loc) <= 0)
			      {
				 rest(30);
				 scroll_level_up();
			      }
			   if (cursor_x > 255)
			      cursor_x = 255;

			   if ((cursor_x - x_screen_loc) >= 19)
			      {
				 rest(30);
				 scroll_level_right();
			      }

			   if (cursor_y > 0xFF)
			      cursor_y = 0xFF;

			   if ((cursor_y - y_screen_loc) > 11)
			      {
				 rest(30);
				 scroll_level_down();
			      }
			}
		  }

	       get_mouse_mickeys(&mickey_x, &mickey_y);

	       if ((mickey_x != 0) || (mickey_y != 0))	//check if mouse has moved
		  mouse_flag = TRUE;
	       rest(30);
	       position_mouse(((cursor_x - x_screen_loc) * 16), ((cursor_y - y_screen_loc) * 16));

	       redraw_screen();

	       if (((mouse_button_flag == TRUE) || (!(mouse_b & 1))) && ((space_flag == TRUE) || (!(key[KEY_SPACE]))) && (!map_space_flag) && (!map_mouse_flag) && (!map_mouse_flag2))
		  {
		     draw_sprite(buffer, obj_01_data[(154 + 257)].dat, ((cursor_x - x_screen_loc) * 16), ((cursor_y - y_screen_loc) * 16));
		  }

	       blit_screen();
	       clear(buffer);
	       if (mouse_y < 16)
		  show_mouse(main_display);
	    }
	 return shutdown_dialog(player);
	 break;
      }
}







void scroll_level_right()
{
   x_screen_loc = (cursor_x - 19);
   old_x_loc = x_screen_loc;
   if (x_screen_loc > 236)
      {
	 x_screen_loc = 236;
	 goto skip;
      }
   check_flag = TRUE;
 skip:
}

void scroll_level_left()
{
   x_screen_loc = cursor_x;
   old_x_loc = x_screen_loc;
   if (x_screen_loc < 0)
      {
	 x_screen_loc = 0;
	 goto skip2;
      }
   check_flag = TRUE;
 skip2:
}



void scroll_level_up()
{
   y_screen_loc = (cursor_y - 1);
   old_y_loc = y_screen_loc;
   if (y_screen_loc < -1)
      {
	 y_screen_loc = -1;
	 goto skip3;
      }
   check_flag = TRUE;
 skip3:
}



void scroll_level_down()
{
   y_screen_loc = (cursor_y - 11);
   old_y_loc = y_screen_loc;
   if (y_screen_loc > (0xFF - 11))
      {
	 y_screen_loc = (0xFF - 12);
	 goto skip4;
      }
   check_flag = TRUE;
 skip4:
}



int user_choose_level()
{
   void *player;
   char error_msg[64];
   int ret;
   int ret2;
   int oldlevel = level;
   int oldworld = world;
   void *lplayer;

   if (world > num_worlds)
      world = num_worlds;
   oldworld2 = world;
   level_chooser_dialog[4].d1 = oldworld2;
   if ((world == 0) && (level > WORLD_INDEXES[world]))
      level = WORLD_INDEXES[world];
   else if ((world >= num_worlds) && (level > (num_levels - WORLD_INDEXES[7])))
      level = (num_levels - WORLD_INDEXES[num_worlds - 1]);
   else if ((world < num_worlds) && (world > 0) && (level > (WORLD_INDEXES[world] - WORLD_INDEXES[world - 1])))
      level = (WORLD_INDEXES[world] - WORLD_INDEXES[world - 1]);

   level_chooser_dialog[5].d1 = (level - 1);

   if (level_menu[0].flags & D_DISABLED)
      return D_O_K;


 redo_dialog:
   init_moveable(level_chooser_dialog);
   lplayer = init_dialog(level_chooser_dialog, 4);
   while (update_dialog(lplayer))
      {
	 if (oldworld2 != level_chooser_dialog[4].d1)
	    {
	       oldworld2 = level_chooser_dialog[4].d1;
	       if (level_chooser_dialog[4].d1 == num_worlds)
		  {
		     if (level_chooser_dialog[5].d1 > ((num_levels - WORLD_INDEXES[num_worlds - 1]) - 1))
			level_chooser_dialog[5].d1 = ((num_levels - WORLD_INDEXES[num_worlds - 1]) - 1);
		     if (level_chooser_dialog[5].d2 > ((num_levels - WORLD_INDEXES[num_worlds - 1]) - 9))
			level_chooser_dialog[5].d2 = ((num_levels - WORLD_INDEXES[num_worlds - 1]) - 9);
		  }
	       else if (level_chooser_dialog[4].d1 == 0)
		  {
		     if (level_chooser_dialog[5].d1 > (WORLD_INDEXES[0] - 1))
			level_chooser_dialog[5].d1 = (WORLD_INDEXES[0] - 1);
		     if (level_chooser_dialog[5].d2 > 0)
			level_chooser_dialog[5].d2 = 0;
		  }
	       else
		  {
		     if (level_chooser_dialog[5].d1 > ((WORLD_INDEXES[level_chooser_dialog[4].d1] - WORLD_INDEXES[level_chooser_dialog[4].d1 - 1]) - 1))
			level_chooser_dialog[5].d1 = ((WORLD_INDEXES[level_chooser_dialog[4].d1] - WORLD_INDEXES[level_chooser_dialog[4].d1 - 1]) - 1);
		     if (level_chooser_dialog[5].d2 > ((WORLD_INDEXES[level_chooser_dialog[4].d1] - WORLD_INDEXES[level_chooser_dialog[4].d1 - 1]) - 9))
			level_chooser_dialog[5].d2 = ((WORLD_INDEXES[level_chooser_dialog[4].d1] - WORLD_INDEXES[level_chooser_dialog[4].d1 - 1]) - 9);
		  }
	       SEND_MESSAGE((level_chooser_dialog + 4), MSG_DRAW, 0);
	       SEND_MESSAGE((level_chooser_dialog + 5), MSG_DRAW, 0);
	    }
	 oldworld2 = level_chooser_dialog[4].d1;
      }
   shutdown_moveable(level_chooser_dialog);
   ret = shutdown_dialog(lplayer);
   if (ret == 6)
      {
	 if ((levelmodified == TRUE) && (options_dialog[2].flags & D_SELECTED))
	    {
	       sprintf(error_msg, "Level %i-%i has been modified.", world, level);
	       ret2 = billalert3(error_msg, "If you switch levels now, all changes", "will be lost. Save?", "Yes", "No", "Cancel", NULL, NULL, 27);
	       if (ret2 == 1)
		  {
		     save_level_new();
		     world = level_chooser_dialog[4].d1;
		     level = (level_chooser_dialog[5].d1 + 1);
		     load_level_new();
		     level_known = TRUE;
		  }
	       if (ret2 == 2)
		  {
		     world = level_chooser_dialog[4].d1;
		     level = (level_chooser_dialog[5].d1 + 1);
		     load_level_new();
		     level_known = TRUE;
		  }
	    }
	 else
	    {
	       world = level_chooser_dialog[4].d1;
	       level = (level_chooser_dialog[5].d1 + 1);
	       load_level_new();
	       level_known = TRUE;
	    }
      }

   if (ret == 7)
      {
	 level = oldlevel;
	 world = oldworld;
      }
   clear(status_display);
   return D_O_K;
}





int quit()
{
   int ret;
   int ret2;
   char error_msg[256];

   if (options_dialog[4].flags & D_SELECTED)
      ret = billalert("Do you really want to quit?", NULL, NULL, "Yes", "No", NULL, 27);
   else
      {
	 if ((levelmodified == TRUE) && (options_dialog[2].flags & D_SELECTED))
	    {
	       sprintf(error_msg, "Level %i-%i has been modified.", world, level);
	       ret2 = billalert3(error_msg, "Save changes?", NULL, "Yes", "No", "Cancel", NULL, NULL, 27);
	       if (ret2 == 1)
		  {
		     if (!freeform_mode)
			save_level_new();
		     else
			save_m3l_file();
		     return D_CLOSE;
		  }
	       if (ret2 == 2)
		  return D_CLOSE;
	       if (ret2 == 3)
		  return D_O_K;
	    }
	 else
	    return D_CLOSE;
      }



   if (ret == 1)
      {
	 if ((levelmodified == TRUE) && (options_dialog[2].flags & D_SELECTED))
	    {
	       sprintf(error_msg, "Level %i-%i has been modified.", world, level);
	       ret2 = billalert3(error_msg, "Save changes?", NULL, "Yes", "No", "Cancel", NULL, NULL, 27);
	       if (ret2 == 1)
		  {
		     if (!freeform_mode)
			save_level_new();
		     else
			save_m3l_file();
		     return D_CLOSE;
		  }
	       if (ret2 == 2)
		  return D_CLOSE;
	       if (ret2 == 3)
		  return D_O_K;
	    }
	 else
	    return D_CLOSE;
      }
   else if (ret == 2)
      return D_O_K;
   if ((!(options_dialog[4].flags & D_SELECTED)) && (!(options_dialog[2].flags & D_SELECTED)))
      return D_CLOSE;

}


int toggle_3byte()
{
   if (show3byte_flag == FALSE)
      {
	 show3byte_flag = TRUE;
	 view_menu[0].flags = D_SELECTED;
	 goto key3;
      }
   if (show3byte_flag == TRUE)
      {
	 show3byte_flag = FALSE;
	 view_menu[0].flags = 0;
      }
 key3:
   check_flag = TRUE;
   return D_O_K;
}




int toggle_4byte()
{
   if (show4byte_flag == FALSE)
      {
	 show4byte_flag = TRUE;
	 view_menu[1].flags = D_SELECTED;
	 goto key4;
      }
   if (show4byte_flag == TRUE)
      {
	 show4byte_flag = FALSE;
	 view_menu[1].flags = 0;
      }
 key4:
   check_flag = TRUE;
   return D_O_K;
}



int do_options_dialog()
{
   int ret;
   int notsaved_flag = options_dialog[2].flags;
   int exit_flag = options_dialog[4].flags;
   int mscroll_flag = options_dialog[6].flags;
   int reset_flag = options_dialog[8].flags;
   int tbyte_diaplay_flag = options_dialog[10].flags;
   int autosort_flag = options_dialog[12].flags;

   ret = moveable_do_dialog(options_dialog, -1);
   if (ret == 15)
      {
	 options_dialog[2].flags = notsaved_flag;
	 options_dialog[4].flags = exit_flag;
	 options_dialog[6].flags = mscroll_flag;
	 options_dialog[8].flags = reset_flag;
	 options_dialog[10].flags = tbyte_diaplay_flag;
	 options_dialog[12].flags = autosort_flag;
      }
   return D_O_K;
}


int do_stats_dialog()
{
   char world_text[5];
   char offset_text[6];
   char object_set_text[32];
   char objnum_text[5];
   char fbyte_text[4];
   char tbyte_text[4];
   char ebyte_text[4];
   char bytesize_text[4];
   char eoffset_text[6];
   char ebytesize_text[4];

   if (level_menu[1].flags & D_DISABLED)
      return D_O_K;


   sprintf(world_text, "%i-%i", world, level);
   if (world != 0)
      sprintf(offset_text, "%X", header_offset);
   else
      sprintf(offset_text, "%X", level_offset);
   sprintf(object_set_text, "%X - ", real_level_object_set);
   strcat(object_set_text, object_set_pointers[real_level_object_set].type_name);

   if (!(mapedit_flag))
      {
	 sprintf(objnum_text, "%i", (tbyte_objs + fbyte_objs + enemy_objs));
	 sprintf(fbyte_text, "%i", fbyte_objs);
	 sprintf(tbyte_text, "%i", tbyte_objs);
	 sprintf(ebyte_text, "%i", enemy_objs);
	 sprintf(ebytesize_text, "%i", enemy_bytes);
	 if (enemy_offset != 0)
	    sprintf(eoffset_text, "%X", (enemy_offset - 1));
	 else
	    sprintf(eoffset_text, "N/A");
      }
   else
      {
	 sprintf(objnum_text, "%i", level_bytes);
	 sprintf(fbyte_text, "N/A");
	 sprintf(tbyte_text, "N/A");
	 sprintf(ebyte_text, "N/A");
	 sprintf(eoffset_text, "N/A");
	 sprintf(ebytesize_text, "N/A");
      }
   sprintf(bytesize_text, "%i", level_bytes);

   if (freeform_mode)
      {
	 sprintf(eoffset_text, "N/A");
	 sprintf(offset_text, "N/A");
      }

   level_stats_dialog[3].dp = world_text;
   level_stats_dialog[5].dp = offset_text;
   level_stats_dialog[7].dp = object_set_text;
   level_stats_dialog[9].dp = objnum_text;
   level_stats_dialog[13].dp = fbyte_text;
   level_stats_dialog[14].dp = tbyte_text;
   level_stats_dialog[15].dp = ebyte_text;
   level_stats_dialog[17].dp = bytesize_text;
   level_stats_dialog[19].dp = eoffset_text;
   level_stats_dialog[21].dp = ebytesize_text;

   moveable_do_dialog(level_stats_dialog, 18);

   return D_O_K;
}


int do_help()
{
   char helpfile[32768];
   int helptext;
   set_mouse_range(0, 0, 320, 240);
   helptext = open("readme.txt", O_RDONLY | O_TEXT);
   if (helptext < 0)
      {
	 billalert("Error: File README.TXT not found!!!", NULL, NULL, "Not good", NULL, 13, NULL);
	 return D_O_K;
      }
   else
      read(helptext, helpfile, 32768);
   help_dialog[2].dp = helpfile;
   moveable_do_dialog(help_dialog, 3);
   if (options_dialog[6].flags & D_SELECTED)
      set_mouse_range(0, 0, 319, 199);
   else
      set_mouse_range(0, 0, 319, 191);
   close(helptext);
   return D_O_K;
}


int do_about()
{
   lincoln_logo = create_bitmap(128, 176);
   clear(lincoln_logo);
   scare_mouse();
   blit(obj_01_data[3085].dat, lincoln_logo, 0, 0, 0, 0, 128, 176);
   unscare_mouse();
   about_dialog[2].dp = lincoln_logo;
   do_dialog(about_dialog, 16);
   destroy_bitmap(lincoln_logo);
   clear(status_display);
   return D_O_K;
}




char *world_getter(int index, int *list_size)
{
   if (!allstars_flag)
      {
	 char *world_names[] = { "Map Screens", "World 1", "World 2", "World 3", "World 4",
	    "World 5", "World 6", "World 7", "World 8", "Lost Levels"
	 };

	 if (index < 0)
	    {
	       *list_size = 10;
	       return NULL;
	    }
	 else
	    return world_names[index];
      }
   else
      {
	 char *world_names[] = { "Map Screens", "World 1", "World 2", "World 3", "World 4",
	    "World 5", "World 6", "World 7", "World 8"
	 };

	 if (index < 0)
	    {
	       *list_size = 9;
	       return NULL;
	    }
	 else
	    return world_names[index];
      }
}


char *world_getter_ex(int index, int *list_size)
{
   if (!allstars_flag)
      {
	 char *world_names[] = { "World 1", "World 2", "World 3", "World 4",
	    "World 5", "World 6", "World 7", "World 8", "Lost Levels"
	 };

	 if (index < 0)
	    {
	       *list_size = 9;
	       return NULL;
	    }
	 else
	    return world_names[index];
      }
   else
      {
	 char *world_names[] = { "World 1", "World 2", "World 3", "World 4",
	    "World 5", "World 6", "World 7", "World 8"
	 };

	 if (index < 0)
	    {
	       *list_size = 8;
	       return NULL;
	    }
	 else
	    return world_names[index];
      }
}


char *music_getter(int index, int *list_size)
{
   char *music_names[] = { "0  Plains Level",
      "1  The Underground",
      "2  Underwater",
      "3  Dungeon",
      "4  Boss",
      "5  Ship",
      "6  Hammer Bros.",
      "7  P-switch music #1",
      "8  Hilly / Sky",
      "9  The King has been transformed!",
      "A  Cloud bonus area",
      "B  P-switch music #2",
      "C  No music #1",
      "D  P-switch music #3",
      "E  No music #2",
      "F  World 7 Map"
   };

   if (index < 0)
      {
	 *list_size = 16;
	 return NULL;
      }
   else
      return music_names[index];
}


char *action_getter(int index, int *list_size)
{
   char *action_names[] = { "Normal",
      "Sliding",
      "Upward pipe (coming out)",
      "Downward pipe (coming out)",
      "Rightward pipe (coming out)",
      "Leftward pipe (coming out)",
      "Weird running",
      "Weird autoscrolling"
   };

   if (index < 0)
      {
	 *list_size = 8;
	 return NULL;
      }
   else
      return action_names[index];
}


char *gfx_getter(int index, int *list_size)
{
   char *gfx_names[] = { "00  Unknown",
      "01  Plains Level",
      "02  Dungeon",
      "03  Underground #1",
      "04  Sky Level",
      "05  Piranha Plant",
      "06  Water Level",
      "07  Unknown",
      "08  Pipe Level #1",
      "09  Desert",
      "0A  Ship",
      "0B  Giant",
      "0C  Ice",
      "0D  Cloudy",
      "0E  Underground #2",
      "0F  Unknown",
      "10  Unknown",
      "11  Unknown",
      "12  Pipe Level #2",
      "13  Hilly",
      "14  World 3-7",
      "15  Tank",
      "16  The King has been transformed!",
      "17  Unknown",
      "18  Unknown",
      "19  Unknown",
      "1A  Unknown",
      "1B  Unknown",
      "1C  Unknown",
      "1D  Unknown",
      "1E  Unknown",
      "1F  Unknown"
   };

   if (index < 0)
      {
	 *list_size = 32;
	 return NULL;
      }
   else
      return gfx_names[index];
}


char *scroll_getter(int index, int *list_size)
{
   char *scroll_names[] = { "0  Scrolls when you fly up #1",
      "1  Upward Scrolling #1",
      "2  Freely Scrolling #1",
      "3  Upward Scrolling #2",
      "4  No upward scrolling #1",
      "5  Upward Scrolling #3",
      "6  No upward scrolling #2",
      "7  Upward Scrolling #4",
      "8  Scrolls when you fly up #2",
      "9  Upward Scrolling #5",
      "A  Freely Scrolling #2",
      "B  Upward Scrolling #6",
      "C  No upward scrolling #3",
      "D  Upward Scrolling #7",
      "E  No upward scrolling #4",
      "F  Upward Scrolling #8",
   };

   if (index < 0)
      {
	 *list_size = 16;
	 return NULL;
      }
   else
      return scroll_names[index];
}


char *palette_getter(int index, int *list_size)
{
   char *palette_names[10][8] = {
      {"0  Blue sky",
       "1  Orange sky",
       "2  Peach sky 1",
       "3  Green sky",
       "4  Dark blue sky",
       "5  Dark Land",
       "6  Peach sky 2",
       "7  Night",
       },
      {"0  Green Hills",
       "1  Sandy Desert",
       "2  Peach sky",
       "3  Dark Land",
       "4  Underground",
       "5  Pyramid",
       "6  World 5-2",
       "7  Ice Underground",
       },
      {"0  Blue Sky",
       "1  Peach Sky 1",
       "2  Blue and Pink",
       "3  Black and White 1",
       "4  Peach Sky 2",
       "5  Blue and White",
       "6  Black and White 2",
       "7  Haloween",
       },
      {"0  Blue dungeon",
       "1  Light blue",
       "2  Green dungeon",
       "3  Water dungeon",
       "4  Normal dungeon",
       "5  Crystal",
       "6  Black and White",
       "7  Bright blue",
       },
      {"0  Normal ship",
       "1  Green ship",
       "2  Blue ship",
       "3  Yellow ship",
       "4  Ice ship",
       "5  Boss room",
       "6  Tank",
       "7  Battleship",
       },
      {"0  Normal clouds 1",
       "1  Pink and Gray",
       "2  World 5-6",
       "3  Peach and White",
       "4  Normal clouds 2",
       "5  Black and blue",
       "6  Black and red",
       "7  Black and pink",
       },
      {"0  Blue sky 1",
       "1  Orange sky 1",
       "2  Dungeon",
       "3  Night",
       "4  Orange sky 2",
       "5  Peach sky",
       "6  Dark Land",
       "7  Blue sky 2",
       },
      {"0  Normal",
       "1  White donuts",
       "2  Orange sky, black water",
       "3  Orange sky, blue water",
       "4  Weird 1",
       "5  Weird 2",
       "6  Weird 3",
       "7  Weird 4",
       },
      {"0  Normal 1",
       "1  Normal 2",
       "2  Black and White",
       "3  Hand Trap",
       "4  Hand Drawn",
       "5  Dark Land",
       "6  Night 1",
       "7  Night 2",
       },
      {"0  Normal",
       "1  Dungeon",
       "2  Pink and Green",
       "3  Night 1",
       "4  White and Green",
       "5  Purple and Blue",
       "6  Night 2",
       "7  Haloween",
       }
   };

   if (index < 0)
      {
	 *list_size = 8;
	 return NULL;
      }
   else
      return palette_names[(level_object_set - 1)][index];
}




char *level_getter(int index, int *list_size)
{
   char *level_names[10][50] = {
      {"World 1 Map", "World 2 Map", "World 3 Map", "World 4 Map",
       "World 5 Map", "World 6 Map", "World 7 Map", "World 8 Map",
       "Warp Zone"},

      {"Level 1", "Level 2", "Level 3", "Level 4", "Level 5",
       "Level 6", "Dungeon", "Secret", "Ship", "L1 Bonus Area", "L2 Bonus Area",
       "L3 Bonus Area", "L4 Ending", "L5 Bonus Area", "L5 Ending",
       "D Spike Room", "S Ending", "Boss Room", "Hammer Bros 1", "Hammer Bros 2",
       "End Castle", "Anchors Away", "Coin Ship", "Coin Ship Boss Room"},

      {"Level 1", "Level 2", "Level 3", "Level 4", "Level 5",
       "Dungeon", "Quicksand", "Pyramid", "Ship", "L1 Bonus Area",
       "L2 Ending", "L3 Ending", "L5 Bonus Area", "D Spike Room",
       "P Outside Area", "Boss Room", "Hidden Hammer Bros", "Hammer Bros 1",
       "Hammer Bros 2", "Pipe 1 End 1", "Pipe 1 End 2", "End Castle",
       "Anchors Away"},

      {"Level 1", "Level 2", "Level 3", "Level 4", "Level 5",
       "Level 6", "Level 7", "Level 8", "Level 9", "Dungeon 1",
       "Dungeon 2", "Ship", "L1 Ending", "L2 Ending", "L3 Ending",
       "L5 Bonus Area", "L5 Ending", "L6 Ending", "L7 Bonus Area",
       "L8 Ending", "L9 Bonus Area", "L9 Ending", "D1 Water Room",
       "D2 Water Room", "Boss Room", "Hammer Bros 1", "Hammer Bros 2",
       "Hammer Bros 3", "Hammer Bros 4", "Hidden Hammer Bros", "Pipe 1 End 1",
       "Pipe 1 End 2", "Pipe 2 End 1", "Pipe 2 End 2", "Pipe 3 End 1",
       "Pipe 3 End 2", "End Castle", "Anchors Away"},

      {"Level 1", "Level 2", "Level 3", "Level 4", "Level 5",
       "Level 6", "Dungeon 1", "Dungeon 2", "Ship", "L1 Bonus Area",
       "L1 Ending", "L2 Ending", "L3 Beginning", "L3 Ending",
       "L4 Bonus Area", "L4 Ending", "L5 Bonus Area", "L5 Ending",
       "L6 Small Side", "D1 Bonus Area", "D2 Pipe Room",
       "D2 Bonus Area", "Boss Room", "Hammer Bros 1", "Pipe 1 End 1",
       "Pipe 1 End 2", "Pipe 2 End 1", "Pipe 2 End 2", "End Castle",
       "Anchors Away"},

      {"Level 1", "Level 2", "Level 3", "Level 4", "Level 5",
       "Level 6", "Level 7", "Level 8", "Level 9", "Dungeon 1",
       "Tower Part 1", "Tower Part 2", "Dungeon 2", "Ship",
       "L1 Bonus Area", "L2 Pipe Room", "L2 Bonus Area", "L2 Ending",
       "L3 Beginning", "L3 Ending", "L4 Ending", "L5 Bonus Area",
       "L6 Ending", "L7 Bonus Area", "L8 Ending", "L9 Ending",
       "D1 Bonus Area", "T Sky Area", "T Ending", "T Going Down",
       "D2 Begin/End", "Boss Room", "Hammer Bros 1", "Hammer Bros 2",
       "Hammer Bros 3", "Hammer Bros 4", "End Castle", "Anchors Away"},

      {"Level 1", "Level 2", "Level 3", "Level 4", "Level 5",
       "Level 6", "Level 7", "Level 8", "Level 9", "Level 10",
       "Dungeon 1", "Dungeon 2", "Dungeon 3", "Ship", "L1 Bonus Area",
       "L2 Ending", "L3 Bonus Area", "L4 Bonus Area", "L5 Outside Area",
       "L6 Begin/End", "L7 Ending", "L9 Outside Area", "L9 Bonus Area",
       "L10 Bonus Area", "D1 Spike Room", "D2 Ending", "D3 Falling Room",
       "Boss Room", "Hammer Bros 1", "Hammer Bros 2", "Pipe 1 End 1",
       "Pipe 1 End 2", "Pipe 2 End 1", "Pipe 2 End 2", "End Castle",
       "Anchors Away"},

      {"Level 1", "Level 2", "Level 3", "Level 4", "Level 5",
       "Level 6", "Level 7", "Level 8", "Level 9", "Piranha Plant 1",
       "Dungeon 1", "Dungeon 2", "Piranha Plant 2", "Ship",
       "L1 Begin/End", "L2 Ending", "L4 Outside Area", "L5 Begin/End",
       "L6 Begin/End", "L7 Begin/End", "L8 Bonus Area 1",
       "L8 Bonus Area 2", "L9 Ending", "PP1 Ending", "D1 Lonely Room",
       "D1 Bonus Area", "D2 Ending", "PP2 Ending", "Boss Room",
       "Hammer Bros 1", "Pipe 1 End 1", "Pipe 1 End 2", "Pipe 2 End 1",
       "Pipe 2 End 2", "Pipe 3 End 1", "Pipe 3 End 2", "Pipe 4 End 1",
       "Pipe 4 End 2", "Pipe 5 End 1", "Pipe 5 End 2", "Pipe 6 End 1",
       "Pipe 6 End 2", "Pipe 7 End 1", "Pipe 7 End 2", "Pipe 8 End 1",
       "Pipe 8 End 2", "End Castle", "Anchors Away"},

      {"Level 1", "Level 2", "Tank 1", "Ship 1", "Hand Trap 1",
       "Hand Trap 2", "Hand Trap 3", "Ship 2", "Dungeon", "Tank 2",
       "Bowser's Castle", "L1 Bonus Area", "L2 Bonus Area",
       "T1 Boss Room", "S1 Boss Room", "HT1 Ending", "HT2 Ending",
       "HT3 Ending", "S2 Boss Room", "D White Side", "T2 Boss Room",
       "Hidden Level", "Pipe 1 End 1", "Pipe 1 End 2", "Pipe 2 End 1",
       "Pipe 2 End 2", "Pipe 3 End 1", "Pipe 3 End 2", "Pipe 4 End 1",
       "Pipe 4 End 2", "Pipe 5 End 1", "Pipe 5 End 2", "Pipe 6 End 1",
       "Pipe 6 End 2", "BC Bowsers Lair"},

      {"Plains End", "Plains 1", "Plains 2", "Plains 2 End",
       "Dungeon", "Underground 1", "Hilly", "Underground 2", "Underground 3",
       "Sky 1", "Sky 2", "Sky 3", "Pipe", "Cloudy 1", "Cloudy 1 End",
       "Cloudy 2", "Ice"}
   };


   if (index < 0)
      {
	 if (oldworld2 == 9)
	    *list_size = (298 - WORLD_INDEXES[(oldworld2 - 1)]);
	 else if (oldworld2 == 0)
	    *list_size = WORLD_INDEXES[oldworld2];
	 else
	    *list_size = ((WORLD_INDEXES[oldworld2]) - (WORLD_INDEXES[(oldworld2 - 1)]));
      }
   else
      return level_names[oldworld2][index];
}





int do_music()
{
   int ret;

   if ((mapedit_flag) || (!file_loaded))
      return D_O_K;

   if (level_menu[3].flags & D_DISABLED)
      return D_O_K;

   music_dialog[1].d1 = (header[8] % 16);
   ret = moveable_do_dialog(music_dialog, 1);

   if (ret == 2)
      {
	 header[8] = ((header[8] / 16) * 16);
	 header[8] += music_dialog[1].d1;
	 levelmodified = TRUE;
      }

   return D_O_K;
}


int do_gfx()
{
   int ret;
   void *gfx_player;

   if ((mapedit_flag) || (!file_loaded) || (allstars_flag))
      return D_O_K;


   gfx_dialog[1].d1 = (header[7] % 32);

   init_moveable(gfx_dialog);
   gfx_player = init_dialog(gfx_dialog, 1);
   while (update_dialog(gfx_player))
      ;
   shutdown_moveable(gfx_dialog);
   ret = shutdown_dialog(gfx_player);
   if (ret == 2)
      {
	 header[7] = ((header[7] / 32) * 32);
	 header[7] += gfx_dialog[1].d1;
	 levelmodified = TRUE;
      }

   return D_O_K;
}


int do_scrolling()
{
   int ret;

   if ((mapedit_flag) || (!file_loaded) || (allstars_flag))
      return D_O_K;

   scroll_dialog[1].d1 = (header[6] / 16);
   ret = moveable_do_dialog(scroll_dialog, 1);

   if (ret == 2)
      {
	 header[6] = ((scroll_dialog[1].d1 * 16) + (header[6] % 16));
	 levelmodified = TRUE;
      }


   return D_O_K;
}


int do_palettes()
{
   int ret;
   void *pal_player;
   BITMAP *preview = create_bitmap(144, 96);
   int old_selection;

   if (level_menu[5].flags & D_DISABLED)
      return D_O_K;

   if(!preview)
      {
         billalert("Error", "Not enough memory to perform this function!", NULL, "OK", NULL, 0, 0);
         return D_O_K;
      }

   palette_dialog[1].d1 = ((header[5] % 16) % 8);
   old_selection = palette_dialog[1].d1;
   if (((header[5] % 16) / 8) == 0)
      {
	 palette_dialog[6].flags = D_SELECTED;
	 palette_dialog[7].flags = 0;
      }
   if (((header[5] % 16) / 8) == 1)
      {
	 palette_dialog[6].flags = 0;
	 palette_dialog[7].flags = D_SELECTED;
      }

   clear(preview);
   blit(previews[(((level_object_set - 1) * 8) + palette_dialog[1].d1)].dat, preview, 0, 0, 0, 0, 144, 96);
   palette_dialog[3].dp = preview;
   bill_init_radio_buttons();
   init_moveable(palette_dialog);
   pal_player = init_dialog(palette_dialog, 1);
   while (update_dialog(pal_player))
      {
	 if (old_selection != palette_dialog[1].d1)
	    {
	       clear(preview);
	       blit(previews[(((level_object_set - 1) * 8) + palette_dialog[1].d1)].dat, preview, 0, 0, 0, 0, 144, 96);
	       SEND_MESSAGE((palette_dialog + 3), MSG_DRAW, 0);
	    }
	 old_selection = palette_dialog[1].d1;
      }
   shutdown_moveable(palette_dialog);
   ret = shutdown_dialog(pal_player);

   if (ret == 4)
      {
	 if (palette_dialog[7].flags == D_SELECTED)
	    header[5] = (((header[5] / 16) * 16) + (palette_dialog[1].d1 + 8));
	 if (palette_dialog[6].flags == D_SELECTED)
	    header[5] = (((header[5] / 16) * 16) + palette_dialog[1].d1);
	 levelmodified = TRUE;
      }

   destroy_bitmap(preview);
   return D_O_K;
}


int do_length()
{
   char length_string[12];
   char starting_pos_string[40];
   char h_start_pos_string[80];
   int i;
   int oldpos1;
   int oldpos2;
   int oldpos3;
   int temp;
   int temp2;
   int temp3;
   int h_start_pos[8] = { 0x1, 0x7, 0xD, 0x8, 0x1, 0x7, 0xD, 0x8 };
   int h_sorted_pos[8] = { 0x1, 0x1, 0x7, 0x7, 0x8, 0x8, 0xD, 0xD };
   int starting_positions[16] = { 0x18, 0x18, 0x5, 0x5, 0x1, 0x1, 0x15, 0x15,
      0x8, 0x8, 0xC, 0xC, 0x10, 0x10, 0x19, 0x19
   };
   int sorted_pos[16] = { 0x1, 0x1, 0x5, 0x5, 0x8, 0x8, 0xC, 0xC,
      0x10, 0x10, 0x15, 0x15, 0x18, 0x18, 0x19, 0x19
   };
   void *length_player;
   int ret;

   if (level_menu[7].flags & D_DISABLED)
      return D_O_K;

   sprintf(length_string, "%XF", (header[4] % 16));
   sprintf(starting_pos_string, "%02X", starting_positions[header[4] / 16]);
   length_dialog[1].dp = length_string;
   length_dialog[3].dp = starting_pos_string;
   for (i = 0; i < 16; i++)
      {
	 if (sorted_pos[i] == starting_positions[header[4] / 16])
	    {
	       if (((header[4] / 16) % 2) == 0)
		  length_dialog[4].d2 = i;
	       if (((header[4] / 16) % 2) == 1)
		  length_dialog[4].d2 = (i + 1);
	       break;
	    }
      }
   for (i = 0; i < 8; i++)
      {
	 if (h_sorted_pos[i] == h_start_pos[((header[5] / 16) / 2)])
	    {
	       if (((header[5] / 16) / 2) >= 4)
		  length_dialog[12].d2 = (i + 1);
	       else
		  length_dialog[12].d2 = i;
	       break;
	    }
      }
   if (((header[5] / 16) % 2) == 0)
      length_dialog[15].flags = 0;
   if (((header[5] / 16) % 2) == 1)
      length_dialog[15].flags = D_SELECTED;
   length_dialog[2].d2 = (header[4] % 16);

   sprintf(h_start_pos_string, "%02X", h_sorted_pos[length_dialog[12].d2]);

   length_dialog[11].dp = h_start_pos_string;
   length_dialog[17].d1 = (header[7] / 32);

   if ((header[8] / 64) == 0)
      {
	 length_dialog[23].flags = D_SELECTED;
	 length_dialog[24].flags = 0;
	 length_dialog[25].flags = 0;
	 length_dialog[26].flags = 0;
      }
   if ((header[8] / 64) == 1)
      {
	 length_dialog[23].flags = 0;
	 length_dialog[24].flags = D_SELECTED;
	 length_dialog[25].flags = 0;
	 length_dialog[26].flags = 0;
      }
   if ((header[8] / 64) == 2)
      {
	 length_dialog[23].flags = 0;
	 length_dialog[24].flags = 0;
	 length_dialog[25].flags = D_SELECTED;
	 length_dialog[26].flags = 0;
      }
   if ((header[8] / 64) == 3)
      {
	 length_dialog[23].flags = 0;
	 length_dialog[24].flags = 0;
	 length_dialog[25].flags = 0;
	 length_dialog[26].flags = D_SELECTED;
      }
   bill_init_radio_buttons();
   init_moveable(length_dialog);
   length_player = init_dialog(length_dialog, 2);
   while (update_dialog(length_player))
      {
	 if (oldpos1 != length_dialog[2].d2)
	    {
	       sprintf(length_string, "%XF", length_dialog[2].d2);
	       SEND_MESSAGE((length_dialog + 1), MSG_DRAW, 0);
	    }
	 if (oldpos2 != length_dialog[4].d2)
	    {
	       sprintf(starting_pos_string, "%02X ", sorted_pos[length_dialog[4].d2]);
	       SEND_MESSAGE((length_dialog + 3), MSG_DRAW, 0);
	    }
	 if (oldpos3 != length_dialog[12].d2)
	    {
	       sprintf(h_start_pos_string, "%02X", h_sorted_pos[length_dialog[12].d2]);
	       SEND_MESSAGE((length_dialog + 11), MSG_DRAW, 0);
	    }
	 oldpos1 = length_dialog[2].d2;
	 oldpos2 = length_dialog[4].d2;
	 oldpos3 = length_dialog[12].d2;
      }
   shutdown_moveable(length_dialog);
   ret = shutdown_dialog(length_player);
   if (ret == 7)
      {
	 for (i = 0; i < 16; i++)
	    {
	       if (starting_positions[i] == sorted_pos[length_dialog[4].d2])
		  {
		     if ((length_dialog[4].d2 % 2) == 0)
			header[4] = (i * 16);
		     if ((length_dialog[4].d2 % 2) == 1)
			header[4] = ((i + 1) * 16);
		     break;
		  }
	    }
	 header[4] += length_dialog[2].d2;
	 temp = (header[5] % 16);	//save the palette bits
	 for (i = 0; i < 8; i++)
	    {
	       if (h_start_pos[i] == h_sorted_pos[length_dialog[12].d2])
		  {
		     if ((length_dialog[12].d2 % 2) == 0)
			header[5] = (i * 2 * 16);
		     if ((length_dialog[12].d2 % 2) == 1)
			header[5] = ((i + 4) * 2 * 16);
		     break;
		  }
	    }
	 if (length_dialog[15].flags == D_SELECTED)
	    header[5] += 16;
	 header[5] += temp;
	 header[7] = ((length_dialog[17].d1 * 32) + (header[7] % 32));
	 temp2 = (header[8] % 16);
	 temp3 = ((header[8] / 16) % 4);
	 if (length_dialog[23].flags & D_SELECTED)
	    header[8] = (0 + (temp3 * 16) + temp2);
	 if (length_dialog[24].flags & D_SELECTED)
	    header[8] = (64 + (temp3 * 16) + temp2);
	 if (length_dialog[25].flags & D_SELECTED)
	    header[8] = (128 + (temp3 * 16) + temp2);
	 if (length_dialog[26].flags & D_SELECTED)
	    header[8] = (192 + (temp3 * 16) + temp2);
	 levelmodified = TRUE;
      }
   return D_O_K;
}




int toggle_enemies()
{
   if (showenemy_flag == FALSE)
      {
	 showenemy_flag = TRUE;
	 view_menu[2].flags = D_SELECTED;
	 goto keye;
      }
   if (showenemy_flag == TRUE)
      {
	 showenemy_flag = FALSE;
	 view_menu[2].flags = 0;
      }
 keye:
   check_flag = TRUE;
   return D_O_K;

}


int qsort_by_h_location(const void *e1, const void *e2)
{
   return ((SMB3_ENEMY *) e1)->horiz - ((SMB3_ENEMY *) e2)->horiz;
}

int qsort_objects_by_h_location(const void *e1, const void *e2)
{
   return ((SMB3_OBJECT *) e1)->byte2 - ((SMB3_OBJECT *) e2)->byte2;
}

char *remove_filename(char *filename)
{
   char dir[250];
   char drive[10];

   fnsplit(filename, drive, dir, NULL, NULL);
   strcpy(filename, drive);
   strcat(filename, dir);

   return filename;
}


int load_level_new()
{
   int error;

   if (!load_offset_flag)
      {
	 if (!allstars_flag)
	    {
	       if (world == 0)
		  level_index_number = (level - 1);
	       else
		  level_index_number = ((WORLD_INDEXES[(world - 1)] + level) - 1);
	       if (level_index_number > 298)
		  level_index_number = 298;
	       real_level_object_set = level_array[level_index_number].real_obj_set;
	       level_object_set = convert_object_sets(real_level_object_set);
	       level_offset = level_array[level_index_number].rom_level_offset;
	       enemy_offset = level_array[level_index_number].enemy_offset;

	       header_offset = (level_offset - 9);
	       num_worlds = 9;
	       num_levels = NUM_SMB3_LEVELS;
	    }
	 else
	    {
	       pointer_mode = FALSE;
	       pointer_numbers = FALSE;
	       if (world == 0)
		  level_index_number = (level - 1);
	       else
		  level_index_number = ((WORLD_INDEXES[(world - 1)] + level) - 1);
	       if (level_index_number > 281)
		  level_index_number = 281;
	       real_level_object_set = allstars_array[level_index_number].real_obj_set;
	       level_object_set = convert_object_sets(real_level_object_set);
	       header_offset = allstars_array[level_index_number].rom_level_offset;
	       if (world > 0)
		  level_offset = (header_offset + 0xD);
	       else
		  level_offset = header_offset;
	       enemy_offset = (allstars_array[level_index_number].enemy_offset + 1);
	       num_worlds = 8;
	       num_levels = NUM_ALLSTARS_LEVELS;
	    }
	 if ((level_object_set == 0) && (!allstars_flag))
	    {
	       pointer_offset = pointer_tables[level - 1].offset;
	       num_ptrs = pointer_tables[level - 1].num_ptrs;
	    }
      }
   else
      {
	 header_offset = level_offset;
	 if (!allstars_flag)
	    level_offset += 9;
	 else
	    level_offset += 0xD;
	 if (enemy_offset != 0)
	    enemy_offset += 1;
      }

   error = read_objects(level_object_set);

   if (error > 0)
      return error;

   freeform_mode = FALSE;

   if (level_object_set > 0)
      mapedit_flag = FALSE;
   else
      mapedit_flag = TRUE;

   if (options_dialog[8].flags & D_SELECTED)
      {
	 cursor_x = 0x1;
	 cursor_y = 0x15;
	 y_screen_loc = 0x10;
	 x_screen_loc = 0x0;
	 position_mouse(((cursor_x - x_screen_loc) * 16), ((cursor_y - y_screen_loc) * 16));
      }
   levelmodified = FALSE;
   close(mario3rom);
   return 0;
}



int read_objects(int obs)
{
   int byte = 0;
   int i = 0;
   int j = 0;
   int k = 0;
   int temp_domain;
   int temp_test;
   int map_sections;
   char error_msg[256];
   int temp_buf[4];
   int old_offset;
   int byte_counter = 0;
   int object_section_counter = 0;
   int object_flag = 0;
   int oldobject_flag = 0;
   int any_object_counter = 0;
   int enemy_byte_counter = 0;
   int enemy_obj_counter = 0;
   int fbyte_obj_counter = 0;
   int tbyte_obj_counter = 0;

   number_of_level_sections = 0;

   the_rom = fopen(romfile, "rb");
   if (the_rom == NULL)
      {
	 sprintf(error_msg, "File %s not found!", get_filename(romfile));
	 billalert("Error", error_msg, NULL, "OK", NULL, 13, NULL);
	 return 1;
      }

   switch (obs)
      {
      case 0:
	 //Testing Phase
	 if (fseek(the_rom, level_offset, SEEK_SET) != 0)
	    {
	       billalert("Error", "Bad level offset!", NULL, "OK", NULL, 13, NULL);
	       return 4;
	    }
	 while ((byte != 0xFF) && (i < 65536))
	    {
	       if ((byte = getc(the_rom)) == EOF)
		  {
		     billalert("Error", "Bad level offset!", NULL, "OK", NULL, 13, NULL);
		     return 4;
		  }
	       if (byte != 0xFF)
		  i++;
	    }
	 fclose(the_rom);
	 if (i >= 65536)
	    {
	       billalert("Error", "Bad level offset or level too large!", "(Levels must be less than 64KB in size.)", "OK", NULL, 13, NULL);
	       return 2;
	    }
	 the_rom = fopen(romfile, "rb");
	 if (!allstars_flag)
	    {
	       if (fseek(the_rom, pointer_offset, SEEK_SET) != 0)
		  {
		     billalert("Error", "Bad pointer offset!", NULL, "OK", NULL, 13, NULL);
		     return 5;
		  }

	       for (i = 0; i < num_ptrs; i++)
		  {
		     if ((byte = getc(the_rom)) == EOF)
			{
			   billalert("Error", "Bad pointer offset!", NULL, "OK", NULL, 13, NULL);
			   return 4;
			}
		  }
	       for (i = 0; i < num_ptrs; i++)
		  {
		     if ((byte = getc(the_rom)) == EOF)
			{
			   billalert("Error", "Bad pointer offset!", NULL, "OK", NULL, 13, NULL);
			   return 4;
			}
		  }
	    }
	 if ((level != 9) && (!allstars_flag))
	    {
	       for (i = 0; i < (num_ptrs * 2); i++)
		  {
		     if ((byte = getc(the_rom)) == EOF)
			{
			   billalert("Error", "Bad pointer offset!", NULL, "OK", NULL, 13, NULL);
			   return 4;
			}
		  }
	       for (i = 0; i < (num_ptrs * 2); i++)
		  {
		     if ((byte = getc(the_rom)) == EOF)
			{
			   billalert("Error", "Bad pointer offset!", NULL, "OK", NULL, 13, NULL);
			   return 4;
			}
		  }
	    }
	 fclose(the_rom);

	 //Doing Phase
	 byte = 0;
	 i = 0;

	 if ((!allstars_flag) && (level != 9))
	    {
	       the_rom = fopen(romfile, "rb");
	       for (j = 0; j < 4; j++)
		  {
		     fseek(the_rom, (map_enemy_offset + ((level - 1) * 9) + (j * 0x48)), SEEK_SET);
		     for (i = 0; i < 9; i++)
			{
			   map_sprites[i][j] = getc(the_rom);
			}
		  }
	       fclose(the_rom);
	    }

	 i = 0;

	 the_rom = fopen(romfile, "rb");
	 if (fseek(the_rom, level_offset, SEEK_SET) != 0)
	    {
	       billalert("Error", "Bad level offset!", NULL, "OK", NULL, 13, NULL);
	       return 4;
	    }
	 while ((byte != 0xFF) && (i < 65536))
	    {
	       if ((byte = getc(the_rom)) == EOF)
		  {
		     billalert("Error", "Bad level offset!", NULL, "OK", NULL, 13, NULL);
		     return 4;
		  }
	       if (byte != 0xFF)
		  {
		     level_table_string[i] = byte;
		     i++;
		  }
	    }
	 fclose(the_rom);
	 if (i >= 65536)
	    {
	       billalert("Error", "Bad level offset or level too large!", "(Levels must be less than 64KB in size.)", "OK", NULL, 13, NULL);
	       return 2;
	    }
	 map_sections = (i / 144);
	 level_bytes = i;
	 for (k = 0; k < map_sections; ++k)
	    {
	       for (j = 0; j < 9; j++)
		  for (i = 0; i < 16; i++)
		     {
			maparray[j][(i + (16 * k))] = level_table_string[(144 * k) + ((16 * j) + i)];
		     }
	    }
	 if (!allstars_flag)
	    {
	       the_rom = fopen(romfile, "rb");
	       if (fseek(the_rom, pointer_offset, SEEK_SET) != 0)
		  {
		     billalert("Error", "Bad pointer offset!", NULL, "OK", NULL, 13, NULL);
		     return 5;
		  }
	       for (i = 0; i < num_ptrs; i++)
		  {
		     if ((byte = getc(the_rom)) == EOF)
			{
			   billalert("Error", "Bad pointer offset!", NULL, "OK", NULL, 13, NULL);
			   return 4;
			}
		     map_ptr_vert[i] = byte;
		  }
	       for (i = 0; i < num_ptrs; i++)
		  {
		     if ((byte = getc(the_rom)) == EOF)
			{
			   billalert("Error", "Bad pointer offset!", NULL, "OK", NULL, 13, NULL);
			   return 4;
			}
		     map_ptr_hriz[i] = byte;
		  }
	       if (level != 9)
		  {
		     for (i = 0; i < (num_ptrs * 2); i++)
			{
			   if ((byte = getc(the_rom)) == EOF)
			      {
				 billalert("Error", "Bad pointer offset!", NULL, "OK", NULL, 13, NULL);
				 return 4;
			      }
			   map_ptr_enemies[i % 2][i / 2] = byte;
			}
		     for (i = 0; i < (num_ptrs * 2); i++)
			{
			   if ((byte = getc(the_rom)) == EOF)
			      {
				 billalert("Error", "Bad pointer offset!", NULL, "OK", NULL, 13, NULL);
				 return 4;
			      }
			   map_ptr_levels[i % 2][i / 2] = byte;
			}
		  }
	       fclose(the_rom);
	    }
	 break;
      default:
	 //Testing Phase (so I don't have to double the array sizes in this program
	 //to hold temporary arrays in case of errors) Does everything the normal
	 //function does, except set critical variables.
	 if (fseek(the_rom, level_offset, SEEK_SET) != 0)
	    {
	       billalert("Error", "Bad level offset!", NULL, "OK", NULL, 13, NULL);
	       return 4;
	    }
	 while ((byte != 0xFF) && (byte_counter < 65536))
	    {
	       old_offset = (level_offset + byte_counter);
	       fseek(the_rom, old_offset, SEEK_SET);
	       for (i = 0; i < 4; i++)
		  {
		     if ((temp_buf[i] = getc(the_rom)) == EOF)
			{
			   billalert("Error", "Bad level offset!", NULL, "OK", NULL, 13, NULL);
			   return 4;
			}
		     if (temp_buf[0] == 0xFF)
			break;
		  }
	       byte = temp_buf[0];
	       if (byte != 0xFF)
		  {
		     temp_domain = (temp_buf[0] / 32);
		     temp_test = (temp_buf[2] / 16);
		     if (object_ranges[level_object_set - 1][temp_domain][temp_test] == 3)
			byte_counter += 3;
		     if (object_ranges[level_object_set - 1][temp_domain][temp_test] == 4)
			byte_counter += 4;
		  }
	    }
	 fclose(the_rom);
	 if (byte_counter >= 65536)
	    {
	       billalert("Error", "Bad level offset or level too large!", "(Levels must be less than 64KB in size.)", "OK", NULL, 13, NULL);
	       return 2;
	    }
	 the_rom = fopen(romfile, "rb");
	 if (fseek(the_rom, header_offset, SEEK_SET) != 0)
	    {
	       billalert("Error", "Bad level offset!", NULL, "OK", NULL, 13, NULL);
	       return 4;
	    }
	 if (enemy_offset != 0)
	    {
	       if (fseek(the_rom, enemy_offset, SEEK_SET) != 0)
		  {
		     billalert("Error", "Bad enemy offset!", NULL, "OK", NULL, 13, NULL);
		     return 4;
		  }
	       byte = 0;
	       while ((byte != 0xFF) && (enemy_byte_counter < 65536))
		  {
		     for (i = 0; i < 3; i++)
			{
			   if ((temp_buf[i] = getc(the_rom)) == EOF)
			      {
				 billalert("Error", "Bad enemy offset!", NULL, "OK", NULL, 13, NULL);
				 return 4;
			      }
			   if (temp_buf[0] == 0xFF)
			      break;
			}
		     byte = temp_buf[0];
		     if (byte != 0xFF)
			enemy_byte_counter += 3;
		  }
	    }
	 fclose(the_rom);
	 if (enemy_byte_counter >= 65536)
	    {
	       billalert("Error", "Bad enemy offset or enemy data too large!", "(Enemy data must be less than 64KB in size.)", "OK", NULL, 13, NULL);
	       return 3;
	    }
	 //Doing Phase
	 byte_counter = 0;
	 enemy_byte_counter = 0;
	 byte = 0;

	 the_rom = fopen(romfile, "rb");
	 if (fseek(the_rom, level_offset, SEEK_SET) != 0)
	    {
	       billalert("Error", "Bad level offset!", NULL, "OK", NULL, 13, NULL);
	       return 4;
	    }
	 while ((byte != 0xFF) && (byte_counter < 65536))
	    {
	       old_offset = (level_offset + byte_counter);
	       fseek(the_rom, old_offset, SEEK_SET);
	       for (i = 0; i < 4; i++)
		  {
		     if ((temp_buf[i] = getc(the_rom)) == EOF)
			{
			   billalert("Error", "Bad level offset!", NULL, "OK", NULL, 13, NULL);
			   return 4;
			}
		     if (temp_buf[0] == 0xFF)
			break;
		  }
	       byte = temp_buf[0];
	       if (byte != 0xFF)
		  {
		     temp_domain = (temp_buf[0] / 32);
		     temp_test = (temp_buf[2] / 16);
		     if (object_ranges[level_object_set - 1][temp_domain][temp_test] == 3)
			{
			   object_flag = 3;
			   if (oldobject_flag != object_flag)
			      {
				 if (byte_counter > 0)
				    object_ordering[number_of_level_sections - 1] = object_section_counter;
				 object_section_counter = 0;
				 oldobject_flag = object_flag;
				 number_of_level_sections++;
			      }
			   for (i = 0; i < 3; i++)
			      tbyte_array[i][tbyte_obj_counter] = temp_buf[i];
			   object_numbers_3[tbyte_obj_counter] = any_object_counter;
			   tbyte_obj_counter++;
			   if (byte_counter == 0)
			      the_first_object = 3;
			   byte_counter += 3;
			   object_section_counter++;
			   any_object_counter++;
			}
		     if (object_ranges[level_object_set - 1][temp_domain][temp_test] == 4)
			{
			   object_flag = 4;
			   if (oldobject_flag != object_flag)
			      {
				 if (byte_counter > 0)
				    object_ordering[number_of_level_sections - 1] = object_section_counter;
				 object_section_counter = 0;
				 oldobject_flag = object_flag;
				 number_of_level_sections++;
			      }
			   for (i = 0; i < 4; i++)
			      fbyte_array[i][fbyte_obj_counter] = temp_buf[i];
			   object_numbers_4[fbyte_obj_counter] = any_object_counter;
			   fbyte_obj_counter++;
			   if (byte_counter == 0)
			      the_first_object = 4;
			   byte_counter += 4;
			   object_section_counter++;
			   any_object_counter++;
			}
		  }
	    }
	 object_ordering[number_of_level_sections - 1] = object_section_counter;
	 fclose(the_rom);
	 if (byte_counter >= 65536)
	    {
	       billalert("Error", "Bad level offset or level too large!", "(Levels must be less than 64KB in size.)", "OK", NULL, 13, NULL);
	       return 2;
	    }
	 level_bytes = byte_counter;
	 fbyte_objs = fbyte_obj_counter;
	 tbyte_objs = tbyte_obj_counter;
	 the_rom = fopen(romfile, "rb");
	 fseek(the_rom, header_offset, SEEK_SET);
	 if (!allstars_flag)
	    {
	       for (i = 0; i < 9; i++)
		  header[i] = getc(the_rom);
	    }
	 if (enemy_offset != 0)
	    {
	       if (fseek(the_rom, enemy_offset, SEEK_SET) != 0)
		  {
		     billalert("Error", "Bad enemy offset!", NULL, "OK", NULL, 13, NULL);
		     return 4;
		  }
	       byte = 0;
	       while ((byte != 0xFF) && (enemy_byte_counter < 65536))
		  {
		     for (i = 0; i < 3; i++)
			{
			   if ((temp_buf[i] = getc(the_rom)) == EOF)
			      {
				 billalert("Error", "Bad enemy offset!", NULL, "OK", NULL, 13, NULL);
				 return 4;
			      }
			   if (temp_buf[0] == 0xFF)
			      break;
			}
		     byte = temp_buf[0];
		     if (byte != 0xFF)
			{
			   for (i = 0; i < 3; i++)
			      enemy_array[i][enemy_obj_counter] = temp_buf[i];
			   enemy_obj_counter++;
			   enemy_byte_counter += 3;
			}
		  }
	    }
	 fclose(the_rom);
	 if (enemy_byte_counter >= 65536)
	    {
	       billalert("Error", "Bad enemy offset or enemy data too large!", "(Enemy data must be less than 64KB in size.)", "OK", NULL, 13, NULL);
	       return 3;
	    }
	 enemy_bytes = enemy_byte_counter;
	 enemy_objs = enemy_obj_counter;
	 break;
      }
   if (enemy_offset == 0)
      {
	 enemy_bytes = 0;
	 enemy_objs = 0;
      }

   return 0;
}


int load_romfile_new()
{
   char old_romfile[256];
   char error_msg[512];
   int ret;

   if ((levelmodified == TRUE) && (options_dialog[2].flags & D_SELECTED))
      {
	 sprintf(error_msg, "Level %i-%i has been modified.", world, level);
	 ret = billalert3(error_msg, "If you load another ROM now, all changes", "will be lost. Save?", "Yes", "No", "Cancel", NULL, NULL, 27);
	 if (ret == 1)
	    {
	       if (!freeform_mode)
		  save_level_new();
	       else
		  save_m3l_file();
	    }
	 if (ret == 3)
	    {
	       return D_O_K;
	    }
      }
   strcpy(old_romfile, romfile);
   if ((!file_loaded) && (!arg_flag))
      {
	 getwd(romfile);
	 strcat(romfile, "\\");
      }
   else if (!arg_flag)
      remove_filename(romfile);
   else
      {
	 fix_filename_path(romfile, romfile, 256);	//then I don't have to waste space making a new string variable
	 strlwr(romfile);
	 if (stricmp(get_extension(romfile), "smc") == 0)
	    allstars_flag = TRUE;
	 else
	    allstars_flag = FALSE;

	 if (load_level_new() == 0)
	    {
	       file_loaded = TRUE;
	       file_menu[2].flags = 0;
	       file_menu[1].flags = 0;
	       level_menu[0].flags = 0;
	       level_menu[1].flags = 0;
	       level_menu[3].flags = 0;
	       level_menu[4].flags = 0;
	       level_menu[5].flags = 0;
	       level_menu[6].flags = 0;
	       level_menu[7].flags = 0;
	       level_menu[8].flags = 0;
	       level_known = TRUE;
	    }
      }

   if (!arg_flag)
      {
	 if (billfile_select("Load ROM (*.nes, *.smc)", romfile, "nes;smc"))
	    {
	       strlwr(romfile);
	       if (stricmp(get_extension(romfile), "smc") == 0)
		  allstars_flag = TRUE;
	       else
		  allstars_flag = FALSE;
	       if (allstars_flag)
		  {
		     num_worlds = 8;
		     num_levels = NUM_ALLSTARS_LEVELS;
		  }
	       else
		  {
		     num_worlds = 9;
		     num_levels = NUM_SMB3_LEVELS;
		  }
	       if ((world == 9) && (allstars_flag))
		  world = 1;
	       if ((world > 0) && (world < num_worlds) && (level > (WORLD_INDEXES[world] - WORLD_INDEXES[world - 1])))
		  level = 1;
	       if ((world == 0) && (level > WORLD_INDEXES[world]))
		  level = 1;
	       if ((world == num_worlds) && (level > (num_levels - WORLD_INDEXES[world - 1])))
		  level = 1;
	       if (load_level_new() == 0)
		  {
		     level_known = TRUE;
		     file_loaded = TRUE;
		     file_menu[2].flags = 0;
		     file_menu[1].flags = 0;
		     level_menu[0].flags = 0;
		     level_menu[1].flags = 0;
		     level_menu[3].flags = 0;
		     level_menu[4].flags = 0;
		     level_menu[5].flags = 0;
		     level_menu[6].flags = 0;
		     level_menu[7].flags = 0;
		     level_menu[8].flags = 0;
		  }
	    }
	 else
	    strcpy(romfile, old_romfile);
      }
   rectfill(status_display, 0, 0, 320, 40, 0);
   if (arg_flag)
      arg_flag = FALSE;
   return D_O_K;
}


int save_level_new()
{
   char error_msg[256];
   int k;
   int j;
   int i;
   int byte_counter = 0;
   int fbyte_obj_counter = 0;
   int tbyte_obj_counter = 0;
   unsigned char write_buf[1];

   if ((file_menu[2].flags & D_DISABLED) && (!from_save_to_rom_func))
      return D_O_K;

   the_romfile = open(romfile, O_RDWR | O_BINARY);
   if (the_romfile < 0)
      {
	 sprintf(error_msg, "Error saving to file %s!", get_filename(romfile));
	 billalert("Error", error_msg, NULL, "OK", NULL, 13, NULL);
	 return D_O_K;
      }

   lseek(the_romfile, level_offset, SEEK_SET);
   if (level_object_set == 0)
      {
	 for (k = 0; k < (level_bytes / 144); ++k)
	    {
	       for (j = 0; j < 9; j++)
		  for (i = 0; i < 16; i++)
		     {
			level_table_string[(144 * k) + ((16 * j) + i)] = maparray[j][(i + (16 * k))];
		     }
	    }
      }
   else
      {
	 for (i = 0; i < number_of_level_sections; i++)
	    {
	       if (the_first_object == 3)
		  {
		     if ((i % 2) == 0)
			{
			   for (j = 0; j < object_ordering[i]; j++)
			      {
				 for (k = 0; k < 3; k++)
				    level_table_string[k + byte_counter] = tbyte_array[k][tbyte_obj_counter];
				 tbyte_obj_counter++;
				 byte_counter += 3;
			      }
			}
		     if ((i % 2) == 1)
			{
			   for (j = 0; j < object_ordering[i]; j++)
			      {
				 for (k = 0; k < 4; k++)
				    level_table_string[k + byte_counter] = fbyte_array[k][fbyte_obj_counter];
				 fbyte_obj_counter++;
				 byte_counter += 4;
			      }
			}
		  }
	       if (the_first_object == 4)
		  {
		     if ((i % 2) == 1)
			{
			   for (j = 0; j < object_ordering[i]; j++)
			      {
				 for (k = 0; k < 3; k++)
				    level_table_string[k + byte_counter] = tbyte_array[k][tbyte_obj_counter];
				 tbyte_obj_counter++;
				 byte_counter += 3;
			      }
			}
		     if ((i % 2) == 0)
			{
			   for (j = 0; j < object_ordering[i]; j++)
			      {
				 for (k = 0; k < 4; k++)
				    level_table_string[k + byte_counter] = fbyte_array[k][fbyte_obj_counter];
				 fbyte_obj_counter++;
				 byte_counter += 4;
			      }
			}
		  }
	    }

	 if (options_dialog[12].flags & D_SELECTED)
	    {
	       for (i = 0; i < enemy_objs; i++)
		  {
		     sort[i].enemy = enemy_array[0][i];
		     sort[i].horiz = enemy_array[1][i];
		     sort[i].vert = enemy_array[2][i];
		  }

	       qsort(sort, enemy_objs, sizeof(SMB3_ENEMY), qsort_by_h_location);

	       for (i = 0; i < enemy_objs; i++)
		  {
		     enemy_array[0][i] = sort[i].enemy;
		     enemy_array[1][i] = sort[i].horiz;
		     enemy_array[2][i] = sort[i].vert;
		  }
	    }

	 for (i = 0; i < enemy_objs; i++)
	    for (j = 0; j < 3; j++)
	       enemy_string[(i * 3) + j] = enemy_array[j][i];
      }

   write(the_romfile, level_table_string, level_bytes);

   if (from_save_to_rom_func)
      {
	 write_buf[0] = 0xFF;
	 lseek(the_romfile, (level_offset + level_bytes), SEEK_SET);
	 write(the_romfile, write_buf, 1);
      }

   lseek(the_romfile, enemy_offset, SEEK_SET);
   write(the_romfile, enemy_string, enemy_bytes);

   if (from_save_to_rom_func)
      {
	 write_buf[0] = 0xFF;
	 lseek(the_romfile, (enemy_offset + enemy_bytes), SEEK_SET);
	 write(the_romfile, write_buf, 1);
      }

   if ((level_object_set > 0) && (!allstars_flag))
      {
	 lseek(the_romfile, header_offset, SEEK_SET);
	 write(the_romfile, header, 9);
      }

   if ((!allstars_flag) && (level != 9) && (level_object_set == 0))
      {
	 for (j = 0; j < 4; j++)
	    {
	       lseek(the_romfile, (map_enemy_offset + ((level - 1) * 9) + (j * 72)), SEEK_SET);
	       for (i = 0; i < 9; i++)
		  {
		     write_buf[0] = map_sprites[i][j];
		     write(the_romfile, write_buf, 1);
		  }
	    }
      }

   if (level_object_set == 0)
      {
	 lseek(the_romfile, pointer_offset, SEEK_SET);
	 write(the_romfile, map_ptr_vert, num_ptrs);
	 lseek(the_romfile, (pointer_offset + num_ptrs), SEEK_SET);
	 write(the_romfile, map_ptr_hriz, num_ptrs);
	 if (level != 9)
	    {
	       for (i = 0; i < (num_ptrs * 2); i++)
		  {
		     lseek(the_romfile, (pointer_offset + (num_ptrs * 2) + i), SEEK_SET);
		     write_buf[0] = map_ptr_enemies[i % 2][i / 2];
		     write(the_romfile, write_buf, 1);
		  }
	       for (i = 0; i < (num_ptrs * 2); i++)
		  {
		     lseek(the_romfile, (pointer_offset + (num_ptrs * 4) + i), SEEK_SET);
		     write_buf[0] = map_ptr_levels[i % 2][i / 2];
		     write(the_romfile, write_buf, 1);
		  }
	    }
      }

   billalert("Information", "Level saved.", NULL, "OK", NULL, 13, NULL);
   if (!from_save_to_rom_func)
      levelmodified = FALSE;
   close(the_romfile);
   return D_O_K;
}



int toggle_pointer_mode()
{
   if (view_menu[5].flags == D_DISABLED)
      return D_O_K;

   if (pointer_mode == FALSE)
      {
	 pointer_mode = TRUE;
	 view_menu[5].flags = D_SELECTED;
	 view_menu[6].flags = 0;
	 goto keyp;
      }
   if (pointer_mode == TRUE)
      {
	 pointer_mode = FALSE;
	 view_menu[5].flags = 0;
	 view_menu[6].flags = D_DISABLED;
      }
 keyp:
   check_flag = TRUE;
   return D_O_K;
}



int toggle_pointer_numbers()
{
   if (view_menu[6].flags == D_DISABLED)
      return D_O_K;

   if (pointer_numbers == FALSE)
      {
	 pointer_numbers = TRUE;
	 view_menu[6].flags = D_SELECTED;
	 goto keyn;
      }
   if (pointer_numbers == TRUE)
      {
	 pointer_numbers = FALSE;
	 view_menu[6].flags = 0;
      }
 keyn:
   check_flag = TRUE;
}




int change_object_set()
{
   char titlebuf[30];

   if (level == 9)
      {
	 sprintf(titlebuf, "Select World");
	 object_set_dialog[0].dp = titlebuf;
      }
   else
      {
	 sprintf(titlebuf, "Select Object Set");
	 object_set_dialog[0].dp = titlebuf;
      }

   object_set_dialog[1].d1 = selected_object_set;

   if (moveable_do_dialog(object_set_dialog, -1) == 2)
      {
	 selected_object_set = object_set_dialog[1].d1;
	 selected_raw_offset = selected_offset;
	 selected_raw_offset -= object_set_pointers[selected_object_set].ptr_type;
	 selected_raw_offset -= 0x10010;
	 level_offset_changed_flag = TRUE;
	 refresh_dialog_flag_3 = TRUE;
      }

   return D_O_K;
}

int change_level_rom_offset()
{
   void *player;
   char error_msg[64];
   int ret;
   int ret2;
   int oldlevel = level;
   int oldworld = world;
   void *lplayer;
   int selected_level_index;

 redo_the_level_chooser_dialog_please:

   oldworld2 = selected_world;
   level_chooser_dialog_ex[4].d1 = (selected_world - 1);
   level_chooser_dialog_ex[5].d1 = (selected_level - 1);

   from_enemies_func = FALSE;
   from_level_func = TRUE;


   init_moveable(level_chooser_dialog_ex);
   player = init_dialog(level_chooser_dialog_ex, 4);
   while (update_dialog(player))
      {
	 currently_selected_level_index = ((WORLD_INDEXES[level_chooser_dialog_ex[4].d1] + level_chooser_dialog_ex[5].d1));

	 if (oldworld2 != (level_chooser_dialog_ex[4].d1 + 1))
	    {
	       oldworld2 = (level_chooser_dialog_ex[4].d1 + 1);
	       if ((level_chooser_dialog_ex[4].d1 + 1) == num_worlds)
		  {
		     if (level_chooser_dialog_ex[5].d1 > ((num_levels - WORLD_INDEXES[num_worlds - 1]) - 1))
			level_chooser_dialog_ex[5].d1 = ((num_levels - WORLD_INDEXES[num_worlds - 1]) - 1);
		     if (level_chooser_dialog_ex[5].d2 > ((num_levels - WORLD_INDEXES[num_worlds - 1]) - 9))
			level_chooser_dialog_ex[5].d2 = ((num_levels - WORLD_INDEXES[num_worlds - 1]) - 9);
		  }
	       else if ((level_chooser_dialog_ex[4].d1 + 1) == 0)
		  {
		     if (level_chooser_dialog_ex[5].d1 > (WORLD_INDEXES[0] - 1))
			level_chooser_dialog_ex[5].d1 = (WORLD_INDEXES[0] - 1);
		     if (level_chooser_dialog_ex[5].d2 > 0)
			level_chooser_dialog_ex[5].d2 = 0;
		  }
	       else
		  {
		     if (level_chooser_dialog_ex[5].d1 > ((WORLD_INDEXES[level_chooser_dialog_ex[4].d1 + 1] - WORLD_INDEXES[level_chooser_dialog_ex[4].d1]) - 1))
			level_chooser_dialog_ex[5].d1 = ((WORLD_INDEXES[level_chooser_dialog_ex[4].d1 + 1] - WORLD_INDEXES[level_chooser_dialog_ex[4].d1]) - 1);
		     if (level_chooser_dialog_ex[5].d2 > ((WORLD_INDEXES[level_chooser_dialog_ex[4].d1 + 1] - WORLD_INDEXES[level_chooser_dialog_ex[4].d1]) - 9))
			level_chooser_dialog_ex[5].d2 = ((WORLD_INDEXES[level_chooser_dialog_ex[4].d1 + 1] - WORLD_INDEXES[level_chooser_dialog_ex[4].d1]) - 9);
		  }

	       SEND_MESSAGE((level_chooser_dialog_ex + 4), MSG_DRAW, 0);
	       SEND_MESSAGE((level_chooser_dialog_ex + 5), MSG_DRAW, 0);
	    }
	 oldworld2 = (level_chooser_dialog_ex[4].d1 + 1);
      }
   shutdown_moveable(level_chooser_dialog_ex);
   ret = shutdown_dialog(player);
   if (ret == 6)
      {

	 selected_world = (level_chooser_dialog_ex[4].d1 + 1);
	 selected_level = (level_chooser_dialog_ex[5].d1 + 1);
	 selected_level_index = ((WORLD_INDEXES[(selected_world - 1)] + selected_level) - 1);
	 selected_offset = (level_array[selected_level_index].rom_level_offset - 9);
	 level_offset_changed_flag = TRUE;
	 selected_object_set = level_array[selected_level_index].real_obj_set;

	 selected_raw_offset = selected_offset;
	 selected_raw_offset -= object_set_pointers[selected_object_set].ptr_type;
	 selected_raw_offset -= 0x10010;

	 refresh_dialog_flag = TRUE;
      }

   if (ret == 8)
      {
	 specify_offset();
	 if (!close_level_chooser_dialog_ex_flag)
	    goto redo_the_level_chooser_dialog_please;
	 close_level_chooser_dialog_ex_flag = FALSE;
      }
   return D_O_K;
}

int change_enemy_rom_offset()
{
   void *player;
   char error_msg[64];
   int ret;
   int ret2;
   int oldlevel = level;
   int oldworld = world;
   void *lplayer;
   int selected_level_index;

 redo_the_level_chooser_dialog_please_thank_you:

   oldworld2 = selected_world_enemies;
   level_chooser_dialog_ex[4].d1 = (selected_world_enemies - 1);
   level_chooser_dialog_ex[5].d1 = (selected_level_enemies - 1);

   from_enemies_func = TRUE;
   from_level_func = FALSE;

   init_moveable(level_chooser_dialog_ex);
   player = init_dialog(level_chooser_dialog_ex, 4);
   while (update_dialog(player))
      {
	 currently_selected_level_index = ((WORLD_INDEXES[level_chooser_dialog_ex[4].d1] + level_chooser_dialog_ex[5].d1));

	 if (oldworld2 != (level_chooser_dialog_ex[4].d1 + 1))
	    {
	       oldworld2 = (level_chooser_dialog_ex[4].d1 + 1);
	       if ((level_chooser_dialog_ex[4].d1 + 1) == num_worlds)
		  {
		     if (level_chooser_dialog_ex[5].d1 > ((num_levels - WORLD_INDEXES[num_worlds - 1]) - 1))
			level_chooser_dialog_ex[5].d1 = ((num_levels - WORLD_INDEXES[num_worlds - 1]) - 1);
		     if (level_chooser_dialog_ex[5].d2 > ((num_levels - WORLD_INDEXES[num_worlds - 1]) - 9))
			level_chooser_dialog_ex[5].d2 = ((num_levels - WORLD_INDEXES[num_worlds - 1]) - 9);
		  }
	       else if ((level_chooser_dialog_ex[4].d1 + 1) == 0)
		  {
		     if (level_chooser_dialog_ex[5].d1 > (WORLD_INDEXES[0] - 1))
			level_chooser_dialog_ex[5].d1 = (WORLD_INDEXES[0] - 1);
		     if (level_chooser_dialog_ex[5].d2 > 0)
			level_chooser_dialog_ex[5].d2 = 0;
		  }
	       else
		  {
		     if (level_chooser_dialog_ex[5].d1 > ((WORLD_INDEXES[level_chooser_dialog_ex[4].d1 + 1] - WORLD_INDEXES[level_chooser_dialog_ex[4].d1]) - 1))
			level_chooser_dialog_ex[5].d1 = ((WORLD_INDEXES[level_chooser_dialog_ex[4].d1 + 1] - WORLD_INDEXES[level_chooser_dialog_ex[4].d1]) - 1);
		     if (level_chooser_dialog_ex[5].d2 > ((WORLD_INDEXES[level_chooser_dialog_ex[4].d1 + 1] - WORLD_INDEXES[level_chooser_dialog_ex[4].d1]) - 9))
			level_chooser_dialog_ex[5].d2 = ((WORLD_INDEXES[level_chooser_dialog_ex[4].d1 + 1] - WORLD_INDEXES[level_chooser_dialog_ex[4].d1]) - 9);
		  }

	       SEND_MESSAGE((level_chooser_dialog_ex + 4), MSG_DRAW, 0);
	       SEND_MESSAGE((level_chooser_dialog_ex + 5), MSG_DRAW, 0);
	    }
	 oldworld2 = (level_chooser_dialog_ex[4].d1 + 1);
      }
   shutdown_moveable(level_chooser_dialog_ex);
   ret = shutdown_dialog(player);
   if (ret == 6)
      {
	 selected_world_enemies = (level_chooser_dialog_ex[4].d1 + 1);
	 selected_level_enemies = (level_chooser_dialog_ex[5].d1 + 1);
	 selected_level_index = ((WORLD_INDEXES[(selected_world_enemies - 1)] + selected_level_enemies) - 1);
	 selected_offset_enemies = level_array[selected_level_index].enemy_offset;
	 enemy_offset_changed_flag = TRUE;
	 selected_raw_offset_enemies = selected_offset_enemies;
	 selected_raw_offset_enemies -= 0x11;
	 refresh_dialog_flag_2 = TRUE;
      }

   if (ret == 8)
      {
	 specify_offset();
	 if (!close_level_chooser_dialog_ex_flag)
	    goto redo_the_level_chooser_dialog_please_thank_you;
	 close_level_chooser_dialog_ex_flag = FALSE;
      }

   return D_O_K;
}


void do_pointer_dialog()
{
   char button2buf[30];
   char buttonbuf[30];
   char error_msg[256];
   char windowtitlebuf[44];
   char levelrombuf[44];
   char enemyrombuf[44];
   char levelbuf[44];
   char enemybuf[44];
   char objectsetbuf[64];
   char positionbuf[44];
   int enemy_pointer = 0;
   int level_pointer = 0;
   int level_that_it_points_to = -1;
   int ret2;
   int world_that_it_points_to = -1;
   int level_enemies_that_it_points_to = -1;
   int world_enemies_that_it_points_to = -1;
   int ret;
   int i;
   int j;
   int map_ptr_index;
   int no_pointer_found = TRUE;
   void *player;
   FILE *f;
   int old_header_offset;
   int old_level_offset;
   int old_level;
   int old_real_object_set;
   int old_world;
   int old_enemy_offset;
   int old_level_index_number;
   int old_flag;
   int old_level_known = level_known;
   int old_level_object_set;

   for (i = 0; i < num_ptrs; i++)
      {
	 if ((map_ptr_hriz[i] == cursor_x) && (((map_ptr_vert[i] / 16) - 2) == cursor_y))
	    {
	       map_ptr_index = i;
	       no_pointer_found = FALSE;
	       break;
	    }
      }


   if (no_pointer_found)
      goto end_of_do_pointer_dialog_function;

   if (level != 9)
      {
	 enemy_pointer += (map_ptr_enemies[1][map_ptr_index] * 0x100);
	 enemy_pointer += map_ptr_enemies[0][map_ptr_index];
	 enemy_pointer += 0x10;

	 level_pointer += (map_ptr_levels[1][map_ptr_index] * 0x100);
	 level_pointer += map_ptr_levels[0][map_ptr_index];
	 level_pointer += object_set_pointers[(map_ptr_vert[map_ptr_index] % 16)].ptr_type;
	 level_pointer += 0x10010;

	 for (i = 0; i < num_levels; i++)
	    {
	       if ((level_array[i].enemy_offset == (enemy_pointer + 1)) && (level_array[i].enemy_offset != 0))
		  {
		     level_enemies_that_it_points_to = level_array[i].level_in_world;
		     world_enemies_that_it_points_to = level_array[i].game_world;
		     break;
		  }
	    }
	 for (i = 0; i < num_levels; i++)
	    {
	       if (level_array[i].rom_level_offset == (level_pointer + 9))
		  {
		     level_that_it_points_to = level_array[i].level_in_world;
		     world_that_it_points_to = level_array[i].game_world;
		     break;
		  }
	    }
      }

   if (((map_ptr_vert[map_ptr_index] % 16) == 0xF) || (level == 9))
      {
	 sprintf(levelrombuf, "Points to level at offset: N/A");
	 sprintf(enemyrombuf, "Points to enemies at offset: N/A");
      }
   else
      {
	 if ((map_ptr_vert[map_ptr_index] % 16) == 0x7)
	    sprintf(levelrombuf, "Points to level at offset: N/A");
	 else
	    sprintf(levelrombuf, "Points to level at offset: %X", level_pointer);
	 if ((map_ptr_vert[map_ptr_index] % 16) == 0x7)
	    sprintf(enemyrombuf, "Type: %X-%s", (enemy_pointer / 0x100), mushroom_houses[enemy_pointer / 0x100]);
	 else
	    sprintf(enemyrombuf, "Points to enemies at offset: %X", enemy_pointer);
      }
   if ((map_ptr_vert[map_ptr_index] % 16) == 0xF)
      sprintf(levelbuf, "Points to Spade House");
   else if ((map_ptr_vert[map_ptr_index] % 16) == 0x7)
      sprintf(levelbuf, "Points to Mushroom House");
   else
      {
	 if ((world_that_it_points_to == -1) || (level_that_it_points_to == -1))
	    sprintf(levelbuf, "Points to unknown level");
	 else
	    sprintf(levelbuf, "Points to World %i-%i", world_that_it_points_to, level_that_it_points_to);
      }

   if (level == 9)
      sprintf(levelbuf, "Points to nothing");

   if ((map_ptr_vert[map_ptr_index] % 16) == 0xF)
      sprintf(enemybuf, "Points to Spade House");
   else if ((map_ptr_vert[map_ptr_index] % 16) == 0x7)
      sprintf(enemybuf, "Points to Mushroom House");
   else
      {
	 if ((world_enemies_that_it_points_to == -1) || (level_enemies_that_it_points_to == -1))
	    sprintf(enemybuf, "Points to unknown enemies");
	 else
	    sprintf(enemybuf, "Points to World %i-%i enemies", world_enemies_that_it_points_to, level_enemies_that_it_points_to);
      }

   if (level == 9)
      sprintf(enemybuf, "Points to nothing");

   if (level != 9)
      sprintf(objectsetbuf, "Points to level with object set: %X - %s", (map_ptr_vert[map_ptr_index] % 16), object_set_pointers[(map_ptr_vert[map_ptr_index] % 16)].type_name);
   else
      sprintf(objectsetbuf, "Points to World %i", ((map_ptr_vert[map_ptr_index] % 16) + 1));

   selected_object_set = (map_ptr_vert[map_ptr_index] % 16);
   selected_offset_enemies = (enemy_pointer + 1);
   selected_offset = level_pointer;

   if (!((world_enemies_that_it_points_to == -1) || (level_enemies_that_it_points_to == -1)))
      {
	 selected_level_enemies = level_enemies_that_it_points_to;
	 selected_world_enemies = world_enemies_that_it_points_to;
      }
   else
      {
	 selected_level_enemies = 1;
	 selected_world_enemies = 1;
      }

   if (!((world_that_it_points_to == -1) || (level_that_it_points_to == -1)))
      {
	 selected_level = level_that_it_points_to;
	 selected_world = world_that_it_points_to;
      }
   else
      {
	 selected_level = 1;
	 selected_world = 1;
      }

   if (selected_object_set == 0x7)
      {
	 sprintf(button2buf, "Change Type...");
	 pointer_dialog[7].dp2 = change_mushroom_house_type;
      }
   else
      {
	 sprintf(button2buf, "Change Enemies...");
	 pointer_dialog[7].dp2 = change_enemy_rom_offset;
      }

   pointer_dialog[7].dp = button2buf;

   sprintf(windowtitlebuf, "Mapscreen Pointer Properties - #%i", map_ptr_index);

   pointer_dialog[0].dp = windowtitlebuf;
   pointer_dialog[1].dp = levelrombuf;
   pointer_dialog[3].dp = enemyrombuf;
   pointer_dialog[2].dp = levelbuf;
   pointer_dialog[4].dp = enemybuf;
   pointer_dialog[5].dp = objectsetbuf;

   if (level == 9)
      {
	 pointer_dialog[6].flags = D_DISABLED;
	 pointer_dialog[7].flags = D_DISABLED;
	 sprintf(buttonbuf, "Change World...");
	 pointer_dialog[8].dp = buttonbuf;
      }
   else
      {
	 pointer_dialog[6].flags = 0;
	 pointer_dialog[7].flags = 0;
	 sprintf(buttonbuf, "Change Object Set...");
	 pointer_dialog[8].dp = buttonbuf;
      }

   if (selected_object_set == 0x7)
      {
	 pointer_dialog[6].flags = D_DISABLED;
	 pointer_dialog[7].flags = 0;
      }
   else if (selected_object_set == 0xF)
      {
	 pointer_dialog[6].flags = D_DISABLED;
	 pointer_dialog[7].flags = D_DISABLED;
      }
   else
      {
	 pointer_dialog[6].flags = 0;
	 pointer_dialog[7].flags = 0;
      }

   init_moveable(pointer_dialog);
   player = init_dialog(pointer_dialog, -1);
   while (update_dialog(player))
      {
	 old_flag = pointer_dialog[11].flags;

	 if ((selected_object_set == 0xF) || (selected_object_set == 0x7) || (level == 9) || (selected_object_set == 0) || (strcmp(levelbuf, "Points to Mushroom House") == 0) || (strcmp(levelbuf, "Points to Spade House") == 0))
	    pointer_dialog[11].flags = D_DISABLED;
	 else
	    pointer_dialog[11].flags = D_EXIT;

	 if (pointer_dialog[11].flags != old_flag)
	    {
	       SEND_MESSAGE((pointer_dialog + 11), MSG_DRAW, 0);
	       old_flag = pointer_dialog[11].flags;
	    }


	 if (refresh_dialog_flag)
	    {
	       sprintf(levelrombuf, "Points to level at offset: %X", selected_offset);
	       sprintf(levelbuf, "Points to World %i-%i", selected_world, selected_level);
	       sprintf(objectsetbuf, "Points to level with object set: %X - %s", selected_object_set, object_set_pointers[selected_object_set].type_name);
	       broadcast_dialog_message(MSG_DRAW, 0);
	       refresh_dialog_flag = FALSE;
	    }
	 if (refresh_dialog_flag_2)
	    {
	       if (selected_offset_enemies != 0)
		  {
		     sprintf(enemyrombuf, "Points to enemies at offset: %X", (selected_offset_enemies - 1));
		     sprintf(enemybuf, "Points to World %i-%i enemies", selected_world_enemies, selected_level_enemies);
		  }
	       else
		  {
		     selected_offset_enemies = 0xC017;	//"null" enemy offset with no enemies.  I tried putting it at 0 but then the game crashes
		     sprintf(enemyrombuf, "Points to enemies at offset: %X", (selected_offset_enemies - 1));
		     sprintf(enemybuf, "Points to unknown enemies");
		  }
	       broadcast_dialog_message(MSG_DRAW, 0);
	       refresh_dialog_flag_2 = FALSE;
	    }

	 if (refresh_dialog_flag_3)
	    {
	       if (level != 9)
		  {
		     if (selected_object_set == 0x7)
			{
			   sprintf(button2buf, "Change Type...");
			   pointer_dialog[7].dp2 = change_mushroom_house_type;
			}
		     else
			{
			   sprintf(button2buf, "Change Enemies...");
			   pointer_dialog[7].dp2 = change_enemy_rom_offset;
			}

		     pointer_dialog[7].dp = button2buf;

		     if (selected_object_set == 0x7)
			{
			   pointer_dialog[6].flags = D_DISABLED;
			   pointer_dialog[7].flags = 0;
			   sprintf(levelrombuf, "Points to level at offset: N/A");
			   if ((selected_offset_enemies / 0x100) > 26)
			      sprintf(enemyrombuf, "Type: Invalid/Unknown");
			   else
			      sprintf(enemyrombuf, "Type: %X-%s", (selected_offset_enemies / 0x100), mushroom_houses[selected_offset_enemies / 0x100]);
			   sprintf(levelbuf, "Points to Mushroom House");
			   sprintf(enemybuf, "Points to Mushroom House");
			}
		     else if (selected_object_set == 0xF)
			{
			   sprintf(levelrombuf, "Points to level at offset: N/A");
			   sprintf(enemyrombuf, "Points to enemies at offset: N/A");
			   sprintf(levelbuf, "Points to Spade House");
			   sprintf(enemybuf, "Points to Spade House");
			   pointer_dialog[6].flags = D_DISABLED;
			   pointer_dialog[7].flags = D_DISABLED;
			}
		     else
			{
			   pointer_dialog[6].flags = 0;
			   pointer_dialog[7].flags = 0;
			   sprintf(enemyrombuf, "Points to enemies at offset: %X", (selected_offset_enemies - 1));
			   level_enemies_that_it_points_to = -1;
			   world_enemies_that_it_points_to = -1;
			   for (i = 0; i < num_levels; i++)
			      {
				 if ((level_array[i].enemy_offset == selected_offset_enemies) && (level_array[i].enemy_offset != 0))
				    {
				       level_enemies_that_it_points_to = level_array[i].level_in_world;
				       world_enemies_that_it_points_to = level_array[i].game_world;
				       break;
				    }
			      }
			   if ((world_enemies_that_it_points_to == -1) || (level_enemies_that_it_points_to == -1))
			      sprintf(enemybuf, "Points to unknown enemies");
			   else
			      sprintf(enemybuf, "Points to World %i-%i enemies", world_enemies_that_it_points_to, level_enemies_that_it_points_to);
			}
		  }
	       if (level == 9)
		  {
		     sprintf(objectsetbuf, "Points to World %i", (selected_object_set + 1));
		     broadcast_dialog_message(MSG_DRAW, 0);
		     refresh_dialog_flag_3 = FALSE;
		  }
	       else
		  {
		     sprintf(objectsetbuf, "Points to level with object set: %X - %s", selected_object_set, object_set_pointers[selected_object_set].type_name);
		     broadcast_dialog_message(MSG_DRAW, 0);
		     refresh_dialog_flag_3 = FALSE;
		  }
	    }
	 if (refresh_dialog_flag_4)
	    {
	       sprintf(enemyrombuf, "Type: %X-%s", (selected_offset_enemies / 0x100), mushroom_houses[selected_offset_enemies / 0x100]);
	       broadcast_dialog_message(MSG_DRAW, 0);
	       refresh_dialog_flag_4 = FALSE;
	    }
	 if (refresh_dialog_flag_5)
	    {
	       sprintf(levelrombuf, "Points to level at offset: %X", selected_offset);
	       level_that_it_points_to = -1;
	       world_that_it_points_to = -1;
	       for (i = 0; i < num_levels; i++)
		  {
		     if (level_array[i].rom_level_offset == (selected_offset + 9))

			{
			   level_that_it_points_to = level_array[i].level_in_world;
			   world_that_it_points_to = level_array[i].game_world;
			   selected_level = level_that_it_points_to;
			   selected_world = world_that_it_points_to;
			   break;
			}
		  }
	       if ((world_that_it_points_to == -1) || (level_that_it_points_to == -1))
		  sprintf(levelbuf, "Points to unknown level");
	       else
		  sprintf(levelbuf, "Points to World %i-%i", world_that_it_points_to, level_that_it_points_to);
	       broadcast_dialog_message(MSG_DRAW, 0);
	       refresh_dialog_flag_5 = FALSE;
	    }
	 if (refresh_dialog_flag_6)
	    {
	       sprintf(enemyrombuf, "Points to enemies at offset: %X", (selected_offset_enemies - 1));
	       level_enemies_that_it_points_to = -1;
	       world_enemies_that_it_points_to = -1;
	       for (i = 0; i < num_levels; i++)
		  {
		     if ((level_array[i].enemy_offset == selected_offset_enemies) && (level_array[i].enemy_offset != 0))
			{
			   level_enemies_that_it_points_to = level_array[i].level_in_world;
			   world_enemies_that_it_points_to = level_array[i].game_world;
			   selected_level_enemies = level_enemies_that_it_points_to;
			   selected_world_enemies = world_enemies_that_it_points_to;
			   break;
			}
		  }
	       if ((world_enemies_that_it_points_to == -1) || (level_enemies_that_it_points_to == -1))
		  sprintf(enemybuf, "Points to unknown enemies");
	       else
		  sprintf(enemybuf, "Points to World %i-%i enemies", world_enemies_that_it_points_to, level_enemies_that_it_points_to);
	       broadcast_dialog_message(MSG_DRAW, 0);
	       refresh_dialog_flag_6 = FALSE;
	    }
      }
   shutdown_moveable(pointer_dialog);
   ret = shutdown_dialog(player);
   if (ret == 9)
      {
	 levelmodified = TRUE;
	 map_ptr_vert[map_ptr_index] = (((map_ptr_vert[map_ptr_index] / 16) * 16) + selected_object_set);
	 if (selected_object_set == 0xF)
	    {
	       map_ptr_enemies[0][map_ptr_index] = 1;
	       map_ptr_enemies[1][map_ptr_index] = 0;
	       map_ptr_levels[0][map_ptr_index] = 0;
	       map_ptr_levels[1][map_ptr_index] = 0;
	    }
	 else if (selected_object_set == 0x7)
	    {
	       map_ptr_levels[0][map_ptr_index] = 0x60;
	       map_ptr_levels[1][map_ptr_index] = 0xAD;
	       map_ptr_enemies[0][map_ptr_index] = 0;
	       map_ptr_enemies[1][map_ptr_index] = (selected_offset_enemies / 0x100);
	    }
	 else
	    {
	       if ((selected_offset_enemies) > 0xFFFF)
		  selected_offset_enemies -= ((selected_offset_enemies / 0x10000) * 0x10000);
	       selected_offset_enemies -= 0x11;
	       map_ptr_enemies[0][map_ptr_index] = (selected_offset_enemies % 0x100);
	       map_ptr_enemies[1][map_ptr_index] = (selected_offset_enemies / 0x100);
	       selected_offset -= object_set_pointers[selected_object_set].ptr_type;
	       selected_offset -= 0x10010;
	       if (selected_offset > 0xFFFF)
		  selected_offset -= ((selected_offset / 0x10000) * 0x10000);
	       map_ptr_levels[0][map_ptr_index] = (selected_offset % 0x100);
	       map_ptr_levels[1][map_ptr_index] = (selected_offset / 0x100);
	    }
      }
   else if (ret == 11)
      {
	 if ((levelmodified == TRUE) && (options_dialog[2].flags & D_SELECTED))
	    {
	       sprintf(error_msg, "Level %i-%i has been modified.", world, level);
	       ret2 = billalert3(error_msg, "If you switch levels now, all changes", "will be lost. Save?", "Yes", "No", "Cancel", NULL, NULL, 27);
               if(ret2 == 1)
                  save_level_new();
               if(ret2 == 3)
                  return;
            }

	 load_offset_flag = TRUE;
	 old_real_object_set = real_level_object_set;
	 old_level_offset = level_offset;
	 old_level = level;
	 old_world = world;
	 old_enemy_offset = enemy_offset;
	 old_level_index_number = level_index_number;
	 old_level_object_set = level_object_set;
	 old_header_offset = header_offset;

	 level_offset = selected_offset;
	 enemy_offset = (selected_offset_enemies - 1);
	 real_level_object_set = selected_object_set;
	 level_object_set = convert_object_sets(real_level_object_set);

	 world = level;
	 if ((maparray[cursor_y][cursor_x] >= 0x03) && (maparray[cursor_y][cursor_x] <= 0x0C))
	    {
	       level = (maparray[cursor_y][cursor_x] - 2);
	       level_known = TRUE;
	    }
	 else
	    level_known = FALSE;

	 if (load_level_new())
	    {
	       level_offset = old_level_offset;
	       level = old_level;
	       world = old_world;
	       enemy_offset = old_enemy_offset;
	       level_index_number = old_level_index_number;
	       real_level_object_set = old_real_object_set;
	       level_object_set = old_level_object_set;
	       header_offset = old_header_offset;
	       level_known = old_level_known;
	    }
	 load_offset_flag = FALSE;
      }
 end_of_do_pointer_dialog_function:
}



int load_level_from_offset()
{
   int ret;
   char *bp;
   int temp;
   int old_header_offset;
   int old_level_offset;
   int old_level;
   int old_real_object_set;
   int old_world;
   int old_enemy_offset;
   int old_level_index_number;
   int old_level_object_set;
   int old_level_known = level_known;

   if (file_menu[1].flags == D_DISABLED)
      return D_O_K;

   if (leveloffsetbuf[0] == '\0')
      {
	 if (!allstars_flag)
	    sprintf(leveloffsetbuf, "%X", (level_offset - 9));
	 else
	    sprintf(leveloffsetbuf, "%X", (level_offset - 0xD));
      }
   if (enemyoffsetbuf[0] == '\0')
      {
	 if (enemy_offset == 0)
	    sprintf(enemyoffsetbuf, "0");
	 else
	    sprintf(enemyoffsetbuf, "%X", (enemy_offset - 1));
      }
   if (pointeroffsetbuf[0] == '\0')
      {
	 if (world == 0)
	    sprintf(pointeroffsetbuf, "%X", pointer_offset);
	 else
	    sprintf(pointeroffsetbuf, "0");
      }

   if (llfo_worldbuf[0] == '\0')
      {
	 if (world == 0)
	    sprintf(llfo_worldbuf, "1");
	 else
	    sprintf(llfo_worldbuf, "%i", world);
      }
   if (llfo_levelbuf[0] == '\0')
      {
	 if (world == 0)
	    sprintf(llfo_levelbuf, "%i", ((WORLD_INDEXES[1] - WORLD_INDEXES[0]) + 1));
	 else if (world >= num_worlds)
	    sprintf(llfo_levelbuf, "%i", ((num_levels - WORLD_INDEXES[world - 1]) + 1));
	 else
	    sprintf(llfo_levelbuf, "%i", ((WORLD_INDEXES[world] - WORLD_INDEXES[world - 1]) + 1));
      }

   if (real_level_object_set > 0)
      load_from_offset_dialog[6].d1 = (real_level_object_set - 1);
   if (real_level_object_set > 7)
      load_from_offset_dialog[6].d1 = (real_level_object_set - 2);
   if (real_level_object_set == 0x10)
      load_from_offset_dialog[6].d1 = 0;

 redo_load_from_offset_dialog:

   if (moveable_do_dialog(load_from_offset_dialog, -1) == 11)
      {
	 temp = strtol(leveloffsetbuf, &bp, 16);
	 if (bp[0] != '\0')
	    {
	       billalert("Error", "Please enter a hexadecimal value between 0x0 and 0xFFFFFF", "for the level offset.", "OK", NULL, NULL, NULL);
	       goto redo_load_from_offset_dialog;
	    }

	 temp = strtol(enemyoffsetbuf, &bp, 16);
	 if (bp[0] != '\0')
	    {
	       billalert("Error", "Please enter a hexadecimal value between 0x0 and 0xFFFFFF", "for the enemy offset.", "OK", NULL, NULL, NULL);
	       goto redo_load_from_offset_dialog;
	    }

	 temp = strtol(llfo_worldbuf, &bp, 10);
	 if ((bp[0] != '\0') || (temp == 0))
	    {
	       billalert("Error", "Please enter an integer between 1 and 9", "for the world.", "OK", NULL, NULL, NULL);
	       goto redo_load_from_offset_dialog;
	    }
	 temp = strtol(llfo_levelbuf, &bp, 10);
	 if ((bp[0] != '\0') || (temp == 0))
	    {
	       billalert("Error", "Please enter an integer between 1 and 99", "for the level.", "OK", NULL, NULL, NULL);
	       goto redo_load_from_offset_dialog;
	    }
	 load_offset_flag = TRUE;
	 old_real_object_set = real_level_object_set;
	 old_level_offset = level_offset;
	 old_level = level;
	 old_world = world;
	 old_enemy_offset = enemy_offset;
	 old_level_index_number = level_index_number;
	 old_level_object_set = level_object_set;
	 old_header_offset = header_offset;
	 world = strtol(llfo_worldbuf, &bp, 10);
	 level = strtol(llfo_levelbuf, &bp, 10);
	 level_offset = strtol(leveloffsetbuf, &bp, 16);
	 level_known = TRUE;
	 enemy_offset = strtol(enemyoffsetbuf, &bp, 16);
	 if (load_from_offset_dialog[6].d1 == 0)
	    level_object_set = 1;
	 if (load_from_offset_dialog[6].d1 == 1)
	    level_object_set = 4;
	 if ((load_from_offset_dialog[6].d1 == 2) || (load_from_offset_dialog[6].d1 == 12))
	    level_object_set = 2;
	 if (load_from_offset_dialog[6].d1 == 3)
	    level_object_set = 3;
	 if ((load_from_offset_dialog[6].d1 == 4) || (load_from_offset_dialog[6].d1 == 9))
	    level_object_set = 9;
	 if ((load_from_offset_dialog[6].d1 == 5) || (load_from_offset_dialog[6].d1 == 6))
	    level_object_set = 8;
	 if (load_from_offset_dialog[6].d1 == 7)
	    level_object_set = 7;
	 if (load_from_offset_dialog[6].d1 == 8)
	    level_object_set = 5;
	 if (load_from_offset_dialog[6].d1 == 10)
	    level_object_set = 10;
	 if (load_from_offset_dialog[6].d1 == 11)
	    level_object_set = 6;

	 if (load_from_offset_dialog[6].d1 < 6)
	    real_level_object_set = (load_from_offset_dialog[6].d1 + 1);
	 else
	    real_level_object_set = (load_from_offset_dialog[6].d1 + 2);

	 if (load_level_new())
	    {
	       level_offset = old_level_offset;
	       level = old_level;
	       world = old_world;
	       enemy_offset = old_enemy_offset;
	       level_index_number = old_level_index_number;
	       real_level_object_set = old_real_object_set;
	       level_object_set = old_level_object_set;
	       header_offset = old_header_offset;
	       level_known = old_level_known;
	    }
	 load_offset_flag = FALSE;
      }
   return D_O_K;
}


char *object_set_getter(int index, int *list_size)
{
   char *object_set_names[] = {
      "1  Plains",
      "2  Dungeon",
      "3  Hilly",
      "4  Sky",
      "5  Piranha Plant",
      "6  Water",
      "8  Pipe",
      "9  Desert",
      "A  Ship",
      "B  Giant",
      "C  Ice",
      "D  Cloudy",
      "E  Underground"
   };

   if (index < 0)
      {
	 *list_size = 13;
	 return NULL;
      }
   else
      return object_set_names[index];

}


char *object_set_getter_ex(int index, int *list_size)
{
   if (level == 9)
      {
	 char *object_set_names[] = { "World 1", "World 2", "World 3", "World 4",
	    "World 5", "World 6", "World 7", "World 8"
	 };

	 if (index < 0)
	    {
	       *list_size = 8;
	       return NULL;
	    }
	 else
	    return object_set_names[index];
      }
   else
      {
	 char *object_set_names[] = { "0 Unknown",
	    "1  Plains",
	    "2  Dungeon",
	    "3  Hilly",
	    "4  Sky",
	    "5  Piranha Plant",
	    "6  Water",
	    "7  Mushroom House",
	    "8  Pipe",
	    "9  Desert",
	    "A  Ship",
	    "B  Giant",
	    "C  Ice",
	    "D  Cloudy",
	    "E  Underground",
	    "F  Spade House"
	 };

	 if (index < 0)
	    {
	       *list_size = 16;
	       return NULL;
	    }
	 else
	    return object_set_names[index];
      }
}


int specify_offset()
{
   int temp;
   char *bp;

   if (from_enemies_func)
      {
	 if (level_array[currently_selected_level_index].enemy_offset != 0)
	    sprintf(specifyoffsetbuf, "%X", (level_array[currently_selected_level_index].enemy_offset - 1));
	 else
	    sprintf(specifyoffsetbuf, "0");
      }
   if (from_level_func)
      sprintf(specifyoffsetbuf, "%X", (level_array[currently_selected_level_index].rom_level_offset - 9));

 redo_specify_offset_dialog:

   if (moveable_do_dialog(specify_offset_dialog, -1) == 3)
      {
	 temp = strtol(specifyoffsetbuf, &bp, 16);
	 if (bp[0] != '\0')
	    {
	       billalert("Error", "Please enter a hexadecimal value between 0x0 and 0xFFFFFF", "for the offset.", "OK", NULL, NULL, NULL);
	       goto redo_specify_offset_dialog;
	    }

	 if (from_level_func)
	    {
	       selected_offset = strtol(specifyoffsetbuf, &bp, 16);
	       selected_raw_offset = selected_offset;
	       selected_raw_offset -= object_set_pointers[selected_object_set].ptr_type;
	       selected_raw_offset -= 0x10010;
	       refresh_dialog_flag_5 = TRUE;
	       close_level_chooser_dialog_ex_flag = TRUE;
	    }

	 if (from_enemies_func)
	    {
	       selected_offset_enemies = strtol(specifyoffsetbuf, &bp, 16);
	       selected_offset_enemies++;
	       selected_raw_offset_enemies = selected_offset_enemies;
	       selected_raw_offset_enemies -= 0x10;
	       refresh_dialog_flag_6 = TRUE;
	       close_level_chooser_dialog_ex_flag = TRUE;
	    }
      }
   return D_O_K;
}


char *mushroom_house_type_getter(int index, int *list_size)
{

   char *mushroom_house_names[27] = { "0  P-Wing Only", "1  Warp Whistle Only",
      "2  P-Wing Only", "3  Frog Suit Only",
      "4  Tanooki Suit Only", "5  Hammer Suit Only",
      "6  Frog, Tanooki, Hammer Suit", "7  Mushroom, Leaf, Flower",
      "8  Leaf, Flower, Frog Suit", "9  Leaf, Flower, Tanooki Suit",
      "A  Anchor Only",
      "B  Warp Whistle, P-Wing, Frog Suit", "C  Frog Suit, P-Wing, Tanooki Suit", "D  Frog, Tanooki, Hammer Suit",
      "E  Warp Whistle, P-Wing, Frog Suit", "F  Frog Suit, P-Wing, Tanooki Suit", "10 Frog, Tanooki, Hammer Suit",
      "11 Warp Whistle, P-Wing, Frog Suit", "12 Frog Suit, P-Wing, Tanooki Suit", "13 Frog, Tanooki, Hammer Suit",
      "14 Warp Whistle, P-Wing, Frog Suit", "15 Frog Suit, P-Wing, Tanooki Suit", "16 Frog, Tanooki, Hammer Suit",
      "17 Warp Whistle, P-Wing, Frog Suit", "18 Frog Suit, P-Wing, Tanooki Suit", "19 Frog, Tanooki, Hammer Suit",
      "1A Warp Whistle, P-Wing, Frog Suit"
   };

   if (index < 0)
      {
	 *list_size = 27;
	 return NULL;
      }
   else
      return mushroom_house_names[index];
}


char *exit_action_getter(int index, int *list_size)
{
   char *exit_actions[16] = { "0 Downward Pipe 1",
      "1 Upward Pipe",
      "2 Downward Pipe 2",
      "3 Rightward Pipe",
      "4 Leftward Pipe",
      "5 Not sure",
      "6 Not sure",
      "7 Not sure",
      "8 Door",
      "9 Not sure",
      "A Not sure",
      "B Not sure",
      "C Not sure",
      "D Not sure",
      "E Not sure",
      "F Not sure"
   };

   if (index < 0)
      {
	 *list_size = 16;
	 return NULL;
      }
   else
      return exit_actions[index];
}


int change_mushroom_house_type()
{
   if ((selected_offset_enemies / 0x100) > 26)
      mushroom_house_dialog[1].d1 = 0;
   else
      mushroom_house_dialog[1].d1 = (selected_offset_enemies / 0x100);

   if (moveable_do_dialog(mushroom_house_dialog, -1) == 2)
      {
	 selected_offset_enemies = ((mushroom_house_dialog[1].d1 * 0x100) + 11);
	 enemy_offset_changed_flag = TRUE;

	 selected_raw_offset_enemies = selected_offset_enemies;
	 selected_raw_offset_enemies -= 0x11;

	 refresh_dialog_flag_4 = TRUE;
      }
   return D_O_K;
}


int do_pointer_dialog_2()
{
   char button2buf[30];
   char buttonbuf[30];
   char windowtitlebuf[44];
   char levelrombuf[44];
   char enemyrombuf[44];
   char levelbuf[44];
   char enemybuf[44];
   char objectsetbuf[64];
   char positionbuf[44];
   char error_msg[256];
   int enemy_pointer = 0;
   int level_pointer = 0;
   int level_that_it_points_to = -1;
   int world_that_it_points_to = -1;
   int level_enemies_that_it_points_to = -1;
   int world_enemies_that_it_points_to = -1;
   int i;
   int j;
   int map_ptr_index;
   int no_pointer_found = TRUE;
   void *player;
   FILE *f;
   int ret;
   int ret2;
   int old_header_offset;
   int old_level_offset;
   int old_level;
   int old_real_object_set;
   int old_world;
   int old_enemy_offset;
   int old_level_index_number;
   int old_level_known = level_known;
   int old_level_object_set;
   int old_flag;

   if (level_menu[8].flags == D_DISABLED)
      return D_O_K;

   enemy_pointer += (header[3] * 0x100);
   enemy_pointer += header[2];
   enemy_pointer += 0x10;
   level_pointer += (header[1] * 0x100);
   level_pointer += header[0];
   level_pointer += object_set_pointers[(header[6] % 16)].ptr_type;
   level_pointer += 0x10010;

   for (i = 0; i < num_levels; i++)
      {
	 if ((level_array[i].enemy_offset == (enemy_pointer + 1)) && (level_array[i].enemy_offset != 0))
	    {
	       level_enemies_that_it_points_to = level_array[i].level_in_world;
	       world_enemies_that_it_points_to = level_array[i].game_world;
	       break;
	    }
      }
   for (i = 0; i < num_levels; i++)
      {
	 if (level_array[i].rom_level_offset == (level_pointer + 9))
	    {
	       level_that_it_points_to = level_array[i].level_in_world;
	       world_that_it_points_to = level_array[i].game_world;
	       break;
	    }
      }

   sprintf(levelrombuf, "Points to level at offset: %X", level_pointer);
   sprintf(enemyrombuf, "Points to enemies at offset: %X", enemy_pointer);

   if ((world_that_it_points_to == -1) || (level_that_it_points_to == -1))
      sprintf(levelbuf, "Points to unknown level");
   else
      sprintf(levelbuf, "Points to World %i-%i", world_that_it_points_to, level_that_it_points_to);


   if ((world_enemies_that_it_points_to == -1) || (level_enemies_that_it_points_to == -1))
      sprintf(enemybuf, "Points to unknown enemies");
   else
      sprintf(enemybuf, "Points to World %i-%i enemies", world_enemies_that_it_points_to, level_enemies_that_it_points_to);

   sprintf(objectsetbuf, "Points to level with object set: %X - %s", (header[6] % 16), object_set_pointers[(header[6] % 16)].type_name);
   selected_object_set_2 = (header[6] % 16);
   selected_offset_enemies_2 = (enemy_pointer + 1);
   selected_offset_2 = level_pointer;

   if ((header[2] == 0) && (header[3] == 0))
      {
	 sprintf(enemyrombuf, "Points to nothing");
	 sprintf(enemybuf, "Points to no enemies");
	 selected_offset_enemies_2 = 0;
      }

   if ((header[1] == 0) && (header[0] == 0))
      {
	 sprintf(levelrombuf, "Points to nothing");
	 sprintf(levelbuf, "Points to no level");
	 selected_offset_2 = 0;
      }

   if (!((world_enemies_that_it_points_to == -1) || (level_enemies_that_it_points_to == -1)))
      {
	 selected_level_enemies_2 = level_enemies_that_it_points_to;
	 selected_world_enemies_2 = world_enemies_that_it_points_to;
      }
   else
      {
	 selected_level_enemies_2 = 1;
	 selected_world_enemies_2 = 1;
      }

   if (!((world_that_it_points_to == -1) || (level_that_it_points_to == -1)))
      {
	 selected_level_2 = level_that_it_points_to;
	 selected_world_2 = world_that_it_points_to;
      }
   else
      {
	 selected_level_2 = 1;
	 selected_world_2 = 1;
      }


   sprintf(button2buf, "Change Enemies...");
   pointer_dialog_2[7].dp2 = change_enemy_rom_offset_2;
   pointer_dialog_2[7].dp = button2buf;

   sprintf(windowtitlebuf, "Bonus Area Pointer Properties");

   pointer_dialog_2[0].dp = windowtitlebuf;
   pointer_dialog_2[1].dp = levelrombuf;
   pointer_dialog_2[3].dp = enemyrombuf;
   pointer_dialog_2[2].dp = levelbuf;
   pointer_dialog_2[4].dp = enemybuf;
   pointer_dialog_2[5].dp = objectsetbuf;


   pointer_dialog_2[6].flags = 0;
   pointer_dialog_2[7].flags = 0;
   sprintf(buttonbuf, "Change Object Set...");
   pointer_dialog_2[8].dp = buttonbuf;

   pointer_dialog_2[6].flags = 0;
   pointer_dialog_2[7].flags = 0;


   init_moveable(pointer_dialog_2);
   player = init_dialog(pointer_dialog_2, -1);
   while (update_dialog(player))
      {
	 old_flag = pointer_dialog_2[11].flags;

	 if ((selected_object_set_2 == 0xF) || (selected_object_set_2 == 0x7) || (selected_object_set_2 == 0) || (strcmp(levelbuf, "Points to no level") == 0) || (strcmp(enemybuf, "Points to no enemies") == 0) || (freeform_mode))
	    pointer_dialog_2[11].flags = D_DISABLED;
	 else
	    pointer_dialog_2[11].flags = D_EXIT;

	 if (pointer_dialog_2[11].flags != old_flag)
	    {
	       SEND_MESSAGE((pointer_dialog_2 + 11), MSG_DRAW, 0);
	       old_flag = pointer_dialog_2[11].flags;
	    }

	 if (refresh_dialog_flag_1_2)
	    {
	       sprintf(levelrombuf, "Points to level at offset: %X", selected_offset_2);
	       sprintf(levelbuf, "Points to World %i-%i", selected_world_2, selected_level_2);
	       sprintf(objectsetbuf, "Points to level with object set: %X - %s", selected_object_set_2, object_set_pointers[selected_object_set_2].type_name);
	       broadcast_dialog_message(MSG_DRAW, 0);
	       refresh_dialog_flag_1_2 = FALSE;
	    }
	 if (refresh_dialog_flag_2_2)
	    {
	       if (selected_offset_enemies_2 != 0)
		  {
		     sprintf(enemyrombuf, "Points to enemies at offset: %X", (selected_offset_enemies_2 - 1));
		     sprintf(enemybuf, "Points to World %i-%i enemies", selected_world_enemies_2, selected_level_enemies_2);
		  }
	       else
		  {
		     sprintf(enemybuf, "Points to no enemies");
		     sprintf(enemybuf, "Points to unknown enemies");
		  }
	       broadcast_dialog_message(MSG_DRAW, 0);
	       refresh_dialog_flag_2_2 = FALSE;
	    }

	 if (refresh_dialog_flag_3_2)
	    {

	       sprintf(button2buf, "Change Enemies...");
	       pointer_dialog_2[7].dp2 = change_enemy_rom_offset_2;
	       pointer_dialog_2[7].dp = button2buf;
	       pointer_dialog_2[6].flags = 0;
	       pointer_dialog_2[7].flags = 0;
	       if (selected_offset_enemies_2 == 0)
		  sprintf(enemyrombuf, "Points to nothing");
	       else
		  sprintf(enemyrombuf, "Points to enemies at offset: %X", (selected_offset_enemies_2 - 1));
	       level_enemies_that_it_points_to = -1;
	       world_enemies_that_it_points_to = -1;
	       for (i = 0; i < num_levels; i++)
		  {
		     if ((level_array[i].enemy_offset == selected_offset_enemies_2) && (level_array[i].enemy_offset != 0))
			{
			   level_enemies_that_it_points_to = level_array[i].level_in_world;
			   world_enemies_that_it_points_to = level_array[i].game_world;
			   break;
			}
		  }
	       if (selected_offset_enemies_2 == 0)
		  sprintf(enemybuf, "Points to no enemies");
	       else
		  {
		     if ((world_enemies_that_it_points_to == -1) || (level_enemies_that_it_points_to == -1))
			sprintf(enemybuf, "Points to unknown enemies");
		     else
			sprintf(enemybuf, "Points to World %i-%i enemies", world_enemies_that_it_points_to, level_enemies_that_it_points_to);
		  }

	       sprintf(objectsetbuf, "Points to level with object set: %X - %s", selected_object_set_2, object_set_pointers[selected_object_set_2].type_name);
	       broadcast_dialog_message(MSG_DRAW, 0);
	       refresh_dialog_flag_3_2 = FALSE;
	    }
	 if (refresh_dialog_flag_4_2)
	    {
	       sprintf(enemyrombuf, "Type: %X-%s", (selected_offset_enemies_2 / 0x100), mushroom_houses[selected_offset_enemies_2 / 0x100]);
	       broadcast_dialog_message(MSG_DRAW, 0);
	       refresh_dialog_flag_4_2 = FALSE;
	    }
	 if (refresh_dialog_flag_5_2)
	    {
	       sprintf(levelrombuf, "Points to level at offset: %X", selected_offset_2);
	       level_that_it_points_to = -1;
	       world_that_it_points_to = -1;
	       for (i = 0; i < num_levels; i++)
		  {
		     if (level_array[i].rom_level_offset == (selected_offset_2 + 9))

			{
			   level_that_it_points_to = level_array[i].level_in_world;
			   world_that_it_points_to = level_array[i].game_world;
			   selected_level_2 = level_that_it_points_to;
			   selected_world_2 = world_that_it_points_to;
			   break;
			}
		  }
	       if ((world_that_it_points_to == -1) || (level_that_it_points_to == -1))
		  sprintf(levelbuf, "Points to unknown level");
	       else
		  sprintf(levelbuf, "Points to World %i-%i", world_that_it_points_to, level_that_it_points_to);
	       if (selected_offset_2 == 0)
		  {
		     sprintf(levelbuf, "Points to no level");
		     sprintf(levelrombuf, "Points to nothing");
		  }
	       broadcast_dialog_message(MSG_DRAW, 0);
	       refresh_dialog_flag_5_2 = FALSE;
	    }
	 if (refresh_dialog_flag_6_2)
	    {
	       sprintf(enemyrombuf, "Points to enemies at offset: %X", (selected_offset_enemies_2 - 1));
	       level_enemies_that_it_points_to = -1;
	       world_enemies_that_it_points_to = -1;
	       for (i = 0; i < num_levels; i++)
		  {
		     if ((level_array[i].enemy_offset == selected_offset_enemies_2) && (level_array[i].enemy_offset != 0))
			{
			   level_enemies_that_it_points_to = level_array[i].level_in_world;
			   world_enemies_that_it_points_to = level_array[i].game_world;
			   selected_level_enemies_2 = level_enemies_that_it_points_to;
			   selected_world_enemies_2 = world_enemies_that_it_points_to;
			   break;
			}
		  }
	       if ((world_enemies_that_it_points_to == -1) || (level_enemies_that_it_points_to == -1))
		  sprintf(enemybuf, "Points to unknown enemies");
	       else
		  sprintf(enemybuf, "Points to World %i-%i enemies", world_enemies_that_it_points_to, level_enemies_that_it_points_to);
	       if (selected_offset_enemies_2 == 0)
		  {
		     sprintf(enemybuf, "Points to no enemies");
		     sprintf(enemyrombuf, "Points to nothing");
		  }
	       broadcast_dialog_message(MSG_DRAW, 0);
	       refresh_dialog_flag_6_2 = FALSE;
	    }
      }
   shutdown_moveable(pointer_dialog_2);
   ret = shutdown_dialog(player);
   if (ret == 9)
      {
	 levelmodified = TRUE;
	 header[6] = (((header[6] / 16) * 16) + selected_object_set_2);
	 if (selected_offset_enemies_2 == 0)
	    {
	       header[2] = 0;
	       header[3] = 0;
	    }
	 else
	    {
	       if ((selected_offset_enemies_2) > 0xFFFF)
		  selected_offset_enemies_2 -= ((selected_offset_enemies_2 / 0x10000) * 0x10000);
	       selected_offset_enemies_2 -= 0x11;
	       header[2] = (selected_offset_enemies_2 % 0x100);
	       header[3] = (selected_offset_enemies_2 / 0x100);
	    }

	 if (selected_offset_2 == 0)
	    {
	       header[0] = 0;
	       header[1] = 0;
	    }
	 else
	    {
	       selected_offset_2 -= object_set_pointers[selected_object_set_2].ptr_type;
	       selected_offset_2 -= 0x10010;
	       if (selected_offset_2 > 0xFFFF)
		  selected_offset_2 -= ((selected_offset_2 / 0x10000) * 0x10000);
	       header[0] = (selected_offset_2 % 0x100);
	       header[1] = (selected_offset_2 / 0x100);
	    }
      }
   else if (ret == 11)
      {
	 if ((levelmodified == TRUE) && (options_dialog[2].flags & D_SELECTED))
	    {
	       sprintf(error_msg, "Level %i-%i has been modified.", world, level);
	       ret2 = billalert3(error_msg, "If you switch levels now, all changes", "will be lost. Save?", "Yes", "No", "Cancel", NULL, NULL, 27);
               if(ret2 == 1)
                  save_level_new();
               if(ret2 == 3)
                  return;
            }

	 load_offset_flag = TRUE;
	 old_real_object_set = real_level_object_set;
	 old_level_offset = level_offset;
	 old_level = level;
	 old_world = world;
	 old_enemy_offset = enemy_offset;
	 old_level_index_number = level_index_number;
	 old_level_object_set = level_object_set;
	 old_header_offset = header_offset;

	 level_offset = selected_offset_2;
	 enemy_offset = (selected_offset_enemies_2 - 1);
	 real_level_object_set = selected_object_set_2;
	 level_object_set = convert_object_sets(real_level_object_set);

	 if ((world_that_it_points_to != -1) && (level_that_it_points_to != -1))
	    {
	       level = level_that_it_points_to;
	       world = world_that_it_points_to;
	       level_known = TRUE;
	    }
	 else
	    {
	       level_known = FALSE;
	    }



	 if (load_level_new())
	    {
	       level_offset = old_level_offset;
	       level = old_level;
	       world = old_world;
	       enemy_offset = old_enemy_offset;
	       level_index_number = old_level_index_number;
	       real_level_object_set = old_real_object_set;
	       level_object_set = old_level_object_set;
	       header_offset = old_header_offset;
	       level_known = old_level_known;
	    }

	 load_offset_flag = FALSE;
      }
   return D_O_K;
}


int change_level_rom_offset_2()
{

   void *player;
   char error_msg[64];
   int ret;
   int ret2;
   int oldlevel = level;
   int oldworld = world;
   void *lplayer;
   int selected_level_index;

 redo_the_level_chooser_dialog_please_2:

   oldworld2 = selected_world_2;
   level_chooser_dialog_ex[4].d1 = (selected_world_2 - 1);
   level_chooser_dialog_ex[5].d1 = (selected_level_2 - 1);

   from_enemies_func_2 = FALSE;
   from_level_func_2 = TRUE;
   init_moveable(level_chooser_dialog_ex);
   player = init_dialog(level_chooser_dialog_ex, 4);
   while (update_dialog(player))
      {
	 currently_selected_level_index_2 = ((WORLD_INDEXES[level_chooser_dialog_ex[4].d1] + level_chooser_dialog_ex[5].d1));

	 if (oldworld2 != (level_chooser_dialog_ex[4].d1 + 1))
	    {
	       oldworld2 = (level_chooser_dialog_ex[4].d1 + 1);
	       if ((level_chooser_dialog_ex[4].d1 + 1) == num_worlds)
		  {
		     if (level_chooser_dialog_ex[5].d1 > ((num_levels - WORLD_INDEXES[num_worlds - 1]) - 1))
			level_chooser_dialog_ex[5].d1 = ((num_levels - WORLD_INDEXES[num_worlds - 1]) - 1);
		     if (level_chooser_dialog_ex[5].d2 > ((num_levels - WORLD_INDEXES[num_worlds - 1]) - 9))
			level_chooser_dialog_ex[5].d2 = ((num_levels - WORLD_INDEXES[num_worlds - 1]) - 9);
		  }
	       else if ((level_chooser_dialog_ex[4].d1 + 1) == 0)
		  {
		     if (level_chooser_dialog_ex[5].d1 > (WORLD_INDEXES[0] - 1))
			level_chooser_dialog_ex[5].d1 = (WORLD_INDEXES[0] - 1);
		     if (level_chooser_dialog_ex[5].d2 > 0)
			level_chooser_dialog_ex[5].d2 = 0;
		  }
	       else
		  {
		     if (level_chooser_dialog_ex[5].d1 > ((WORLD_INDEXES[level_chooser_dialog_ex[4].d1 + 1] - WORLD_INDEXES[level_chooser_dialog_ex[4].d1]) - 1))
			level_chooser_dialog_ex[5].d1 = ((WORLD_INDEXES[level_chooser_dialog_ex[4].d1 + 1] - WORLD_INDEXES[level_chooser_dialog_ex[4].d1]) - 1);
		     if (level_chooser_dialog_ex[5].d2 > ((WORLD_INDEXES[level_chooser_dialog_ex[4].d1 + 1] - WORLD_INDEXES[level_chooser_dialog_ex[4].d1]) - 9))
			level_chooser_dialog_ex[5].d2 = ((WORLD_INDEXES[level_chooser_dialog_ex[4].d1 + 1] - WORLD_INDEXES[level_chooser_dialog_ex[4].d1]) - 9);
		  }

	       SEND_MESSAGE((level_chooser_dialog_ex + 4), MSG_DRAW, 0);
	       SEND_MESSAGE((level_chooser_dialog_ex + 5), MSG_DRAW, 0);
	    }
	 oldworld2 = (level_chooser_dialog_ex[4].d1 + 1);
      }
   shutdown_moveable(level_chooser_dialog_ex);
   ret = shutdown_dialog(player);
   if (ret == 6)
      {
	 selected_world_2 = (level_chooser_dialog_ex[4].d1 + 1);
	 selected_level_2 = (level_chooser_dialog_ex[5].d1 + 1);
	 selected_level_index = ((WORLD_INDEXES[(selected_world_2 - 1)] + selected_level_2) - 1);
	 selected_offset_2 = (level_array[selected_level_index].rom_level_offset - 9);
	 selected_object_set_2 = level_array[selected_level_index].real_obj_set;
	 refresh_dialog_flag_1_2 = TRUE;
      }

   if (ret == 8)
      {
	 specify_offset_2();
	 if (!close_level_chooser_dialog_ex_flag_2)
	    goto redo_the_level_chooser_dialog_please_2;
	 close_level_chooser_dialog_ex_flag_2 = FALSE;
      }


   return D_O_K;
}


int change_enemy_rom_offset_2()
{

   void *player;
   char error_msg[64];
   int ret;
   int ret2;
   int oldlevel = level;
   int oldworld = world;
   void *lplayer;
   int selected_level_index;

 redo_the_level_chooser_dialog_please_thank_you_2:

   oldworld2 = selected_world_enemies_2;
   level_chooser_dialog_ex[4].d1 = (selected_world_enemies_2 - 1);
   level_chooser_dialog_ex[5].d1 = (selected_level_enemies_2 - 1);

   from_enemies_func_2 = TRUE;
   from_level_func_2 = FALSE;

   init_moveable(level_chooser_dialog_ex);
   player = init_dialog(level_chooser_dialog_ex, 4);
   while (update_dialog(player))
      {
	 currently_selected_level_index_2 = ((WORLD_INDEXES[level_chooser_dialog_ex[4].d1] + level_chooser_dialog_ex[5].d1));

	 if (oldworld2 != (level_chooser_dialog_ex[4].d1 + 1))
	    {
	       oldworld2 = (level_chooser_dialog_ex[4].d1 + 1);
	       if ((level_chooser_dialog_ex[4].d1 + 1) == num_worlds)
		  {
		     if (level_chooser_dialog_ex[5].d1 > ((num_levels - WORLD_INDEXES[num_worlds - 1]) - 1))
			level_chooser_dialog_ex[5].d1 = ((num_levels - WORLD_INDEXES[num_worlds - 1]) - 1);
		     if (level_chooser_dialog_ex[5].d2 > ((num_levels - WORLD_INDEXES[num_worlds - 1]) - 9))
			level_chooser_dialog_ex[5].d2 = ((num_levels - WORLD_INDEXES[num_worlds - 1]) - 9);
		  }
	       else if ((level_chooser_dialog_ex[4].d1 + 1) == 0)
		  {
		     if (level_chooser_dialog_ex[5].d1 > (WORLD_INDEXES[0] - 1))
			level_chooser_dialog_ex[5].d1 = (WORLD_INDEXES[0] - 1);
		     if (level_chooser_dialog_ex[5].d2 > 0)
			level_chooser_dialog_ex[5].d2 = 0;
		  }
	       else
		  {
		     if (level_chooser_dialog_ex[5].d1 > ((WORLD_INDEXES[level_chooser_dialog_ex[4].d1 + 1] - WORLD_INDEXES[level_chooser_dialog_ex[4].d1]) - 1))
			level_chooser_dialog_ex[5].d1 = ((WORLD_INDEXES[level_chooser_dialog_ex[4].d1 + 1] - WORLD_INDEXES[level_chooser_dialog_ex[4].d1]) - 1);
		     if (level_chooser_dialog_ex[5].d2 > ((WORLD_INDEXES[level_chooser_dialog_ex[4].d1 + 1] - WORLD_INDEXES[level_chooser_dialog_ex[4].d1]) - 9))
			level_chooser_dialog_ex[5].d2 = ((WORLD_INDEXES[level_chooser_dialog_ex[4].d1 + 1] - WORLD_INDEXES[level_chooser_dialog_ex[4].d1]) - 9);
		  }

	       SEND_MESSAGE((level_chooser_dialog_ex + 4), MSG_DRAW, 0);
	       SEND_MESSAGE((level_chooser_dialog_ex + 5), MSG_DRAW, 0);
	    }
	 oldworld2 = (level_chooser_dialog_ex[4].d1 + 1);
      }
   shutdown_moveable(level_chooser_dialog_ex);
   ret = shutdown_dialog(player);
   if (ret == 6)
      {
	 selected_world_enemies_2 = (level_chooser_dialog_ex[4].d1 + 1);
	 selected_level_enemies_2 = (level_chooser_dialog_ex[5].d1 + 1);
	 selected_level_index = ((WORLD_INDEXES[(selected_world_enemies_2 - 1)] + selected_level_enemies_2) - 1);
	 selected_offset_enemies_2 = level_array[selected_level_index].enemy_offset;
	 refresh_dialog_flag_2_2 = TRUE;
      }

   if (ret == 8)
      {
	 specify_offset_2();
	 if (!close_level_chooser_dialog_ex_flag_2)
	    goto redo_the_level_chooser_dialog_please_thank_you_2;
	 close_level_chooser_dialog_ex_flag_2 = FALSE;
      }

   return D_O_K;
}


int change_object_set_2()
{

   if (selected_object_set == 0)
      object_set_dialog_2[1].d1 = 0;
   if ((selected_object_set > 0) && (selected_object_set < 7))
      object_set_dialog_2[1].d1 = (selected_object_set_2 - 1);
   if (selected_object_set > 7)
      object_set_dialog_2[1].d1 = (selected_object_set_2 - 2);

   if (moveable_do_dialog(object_set_dialog_2, -1) == 2)
      {
	 if (object_set_dialog_2[1].d1 < 6)
	    selected_object_set_2 = (object_set_dialog_2[1].d1 + 1);
	 else
	    selected_object_set_2 = (object_set_dialog_2[1].d1 + 2);
	 refresh_dialog_flag_3_2 = TRUE;
      }
   return D_O_K;
}


int specify_offset_2()
{
   int temp;
   char *bp;

   if (from_enemies_func_2)
      {
	 if (level_array[currently_selected_level_index_2].enemy_offset != 0)
	    sprintf(specifyoffsetbuf, "%X", (level_array[currently_selected_level_index_2].enemy_offset - 1));
	 else
	    sprintf(specifyoffsetbuf, "0");
      }
   if (from_level_func_2)
      sprintf(specifyoffsetbuf, "%X", (level_array[currently_selected_level_index_2].rom_level_offset - 9));

 redo_specify_offset_dialog:

   if (moveable_do_dialog(specify_offset_dialog, -1) == 3)
      {
	 temp = strtol(specifyoffsetbuf, &bp, 16);
	 if (bp[0] != '\0')
	    {
	       billalert("Error", "Please enter a hexadecimal value between 0x0 and 0xFFFFFF", "for the offset.", "OK", NULL, NULL, NULL);
	       goto redo_specify_offset_dialog;
	    }

	 if (from_level_func_2)
	    {
	       selected_offset_2 = strtol(specifyoffsetbuf, &bp, 16);
	       refresh_dialog_flag_5_2 = TRUE;
	       close_level_chooser_dialog_ex_flag_2 = TRUE;
	    }
	 if (from_enemies_func_2)
	    {
	       selected_offset_enemies_2 = strtol(specifyoffsetbuf, &bp, 16);
	       if (selected_offset_enemies_2 != 0)
		  selected_offset_enemies_2++;
	       refresh_dialog_flag_6_2 = TRUE;
	       close_level_chooser_dialog_ex_flag_2 = TRUE;
	    }
      }

   return D_O_K;
}


int convert_object_sets(int obs)
{
   switch (obs)
      {
      case 0:
      case 1:
      case 7:
      case 15:
      default:
	 return 1;
      case 2:
	 return 4;
      case 3:
      case 14:
	 return 2;
      case 4:
	 return 3;
      case 5:
      case 11:
	 return 9;
      case 6:
      case 8:
	 return 8;
      case 9:
	 return 7;
      case 10:
	 return 5;
      case 12:
	 return 10;
      case 13:
	 return 6;
      case 16:
	 return 0;
      }
}


int new_level()
{
   char *bp;
   int temp;
   int ret;
   char error_msg[256];

   if ((levelmodified == TRUE) && (options_dialog[2].flags & D_SELECTED))
      {
	 sprintf(error_msg, "Level %i-%i has been modified.", world, level);
	 ret = billalert3("Question", error_msg, "Save changes?", "Yes", "No", "Cancel", 0, 0, 0);
	 if (ret == 1)
	    {
	       if (freeform_mode)
		  save_m3l_file();
	       else
		  save_level_new();
	    }
	 if (ret == 3)
	    return D_O_K;
      }

 redo_new_level_dialog:
   sprintf(nl_worldbuf, "%i", world);
   sprintf(nl_levelbuf, "%i", level);
   if (moveable_do_dialog(new_level_dialog, -1) == 7)
      {

	 temp = strtol(nl_worldbuf, &bp, 10);
	 if ((bp[0] != '\0') || (temp == 0))
	    {
	       billalert("Error", "Please enter an integer between 1 and 9", "for the world.", "OK", NULL, NULL, NULL);
	       goto redo_new_level_dialog;
	    }
	 temp = strtol(nl_levelbuf, &bp, 10);
	 if ((bp[0] != '\0') || (temp == 0))
	    {
	       billalert("Error", "Please enter an integer between 1 and 99", "for the level.", "OK", NULL, NULL, NULL);
	       goto redo_new_level_dialog;
	    }

	 world = atoi(nl_worldbuf);
	 level = atoi(nl_levelbuf);

	 freeform_mode = TRUE;
	 file_loaded = TRUE;
	 mapedit_flag = FALSE;
	 allstars_flag = FALSE;
	 num_levels = NUM_SMB3_LEVELS;

	 if (new_level_dialog[4].d1 == 0)
	    level_object_set = 1;
	 if (new_level_dialog[4].d1 == 1)
	    level_object_set = 4;
	 if ((new_level_dialog[4].d1 == 2) || (new_level_dialog[4].d1 == 12))
	    level_object_set = 2;
	 if (new_level_dialog[4].d1 == 3)
	    level_object_set = 3;
	 if ((new_level_dialog[4].d1 == 4) || (new_level_dialog[4].d1 == 9))
	    level_object_set = 9;
	 if ((new_level_dialog[4].d1 == 5) || (new_level_dialog[4].d1 == 6))
	    level_object_set = 8;
	 if (new_level_dialog[4].d1 == 7)
	    level_object_set = 7;
	 if (new_level_dialog[4].d1 == 8)
	    level_object_set = 5;
	 if (new_level_dialog[4].d1 == 10)
	    level_object_set = 10;
	 if (new_level_dialog[4].d1 == 11)
	    level_object_set = 6;

	 if (new_level_dialog[4].d1 < 6)
	    real_level_object_set = (new_level_dialog[4].d1 + 1);
	 else
	    real_level_object_set = (new_level_dialog[4].d1 + 2);

	 fbyte_objs = 0;
	 tbyte_objs = 0;
	 level_bytes = 0;
	 enemy_bytes = 0;
	 number_of_level_sections = 0;
	 enemy_objs = 0;

	 header[0] = 0;
	 header[1] = 0;
	 header[2] = 0;
	 header[3] = 0;

	 header[4] = 0xEA;
	 header[5] = 0x80;
	 header[6] = 0x81;

	 switch (real_level_object_set)
	    {
	    case 1:
	       header[7] = 0x01;
	       header[8] = 0x00;
	       break;
	    case 2:
	       header[7] = 0x02;
	       header[8] = 0x03;
	       break;
	    case 3:
	       header[7] = 0x13;
	       header[8] = 0x08;
	       break;
	    case 4:
	       header[7] = 0x04;
	       header[8] = 0x08;
	       break;
	    case 5:
	       header[7] = 0x05;
	       header[8] = 0x00;
	       break;
	    case 6:
	       header[7] = 0x06;
	       header[8] = 0x02;
	       break;
	    case 8:
	       header[7] = 0x08;
	       header[8] = 0x01;
	       break;
	    case 9:
	       header[7] = 0x09;
	       header[8] = 0x00;
	       break;
	    case 10:
	       header[7] = 0x0A;
	       header[8] = 0x05;
	       break;
	    case 11:
	       header[7] = 0x0B;
	       header[8] = 0x00;
	       break;
	    case 12:
	       header[7] = 0x0C;
	       header[8] = 0x08;
	       break;
	    case 13:
	       header[7] = 0x0D;
	       header[8] = 0x08;
	       break;
	    case 14:
	       header[7] = 0x03;
	       header[8] = 0x01;
	       break;
	    }
	 ff_oldobject_flag = 0;
	 ff_object_flag = 0;
	 ff_number_of_level_sections = 0;
	 clear(status_display);

      }
}




int save_level_to_rom_location()
{
   unsigned int save_rom_level_offset;
   unsigned int save_rom_enemy_offset;
   char old_rom_filename[256];
   char objectsetbuf[60];
   char levelpointerrange[60];
   char enemypointerrange[60];
   char romleveloffsetbuf[15];
   char romenemyoffsetbuf[15];
   int i;
   int j;
   int ptrmin;
   int ptrmax;
   int enemyoffset_max;
   DIALOG_PLAYER *player;

   if (file_menu[4].flags & D_DISABLED)
      return D_O_K;

   sprintf(objectsetbuf, "Object Set: %X - %s", real_level_object_set, object_set_pointers[real_level_object_set].type_name);
   ptrmin = object_set_pointers[real_level_object_set].ptr_min;
   ptrmax = (object_set_pointers[real_level_object_set].ptr_max - (10 + level_bytes));
   enemyoffset_max = (0xE00F - (enemy_bytes + 2));
   sprintf(levelpointerrange, "Level Offset Range: %X-%X", ptrmin, ptrmax);
   sprintf(enemypointerrange, "Enemy Offset Range: BFD8-%X", enemyoffset_max);
   sprintf(romleveloffsetbuf, "None yet");
   sprintf(romenemyoffsetbuf, "None yet");

   save_to_rom_dialog[1].dp = objectsetbuf;
   save_to_rom_dialog[2].dp = levelpointerrange;
   save_to_rom_dialog[3].dp = enemypointerrange;
   save_to_rom_dialog[6].dp = romleveloffsetbuf;
   save_to_rom_dialog[9].dp = romenemyoffsetbuf;

 redo_save_level_to_rom_dialog:

   init_moveable(save_to_rom_dialog);
   player = init_dialog(save_to_rom_dialog, -1);
   while (update_dialog(player))
      {
	 if ((refresh_dialog_flag_1_3) || (refresh_dialog_flag_5_3))
	    {
	       sprintf(romleveloffsetbuf, "%X       ", selected_offset_3);
	       SEND_MESSAGE((save_to_rom_dialog + 6), MSG_DRAW, 0);
	       refresh_dialog_flag_1_3 = FALSE;
	       refresh_dialog_flag_5_3 = FALSE;
	    }
	 if ((refresh_dialog_flag_3_2_1) || (refresh_dialog_flag_6_3))
	    {
	       sprintf(romenemyoffsetbuf, "%X       ", (selected_offset_enemies_3 - 1));
	       SEND_MESSAGE((save_to_rom_dialog + 9), MSG_DRAW, 0);
	       refresh_dialog_flag_3_2_1 = FALSE;
	       refresh_dialog_flag_6_3 = FALSE;
	    }
      }
   shutdown_moveable(save_to_rom_dialog);
   if (shutdown_dialog(player) == 10)
      {
	 if ((strcmp(romleveloffsetbuf, "None yet") == 0) || (strcmp(romenemyoffsetbuf, "None yet") == 0))
	    {
	       billalert("Error", "You must select an offset!", NULL, "OK", NULL, 0, 0);
	       goto redo_save_level_to_rom_dialog;
	    }
	 if ((selected_offset_3 > ptrmax) || (selected_offset_3 < ptrmin))
	    {
	       if (billalert("Warning", "The level offset you selected is outside the known valid", "offset range for this level type.  Save anyway?", "Yes", "No", 0, 0) == 2)
		  return D_O_K;
	    }
	 if (((selected_offset_enemies_3 - 1) > enemyoffset_max) || ((selected_offset_enemies_3 - 1) < 0xBFD8))
	    {
	       if (billalert("Warning", "The enemy offset you selected is outside the known valid", "offset range for enemies.  Save anyway?", "Yes", "No", 0, 0) == 2)
		  return D_O_K;
	    }

	 remove_filename(savetoromfile);
	 if (billfile_select("Save to NES ROM", savetoromfile, "nes"))
	    {
	       from_save_to_rom_func = TRUE;
	       strcpy(old_rom_filename, romfile);
	       strcpy(romfile, savetoromfile);
	       header_offset = selected_offset_3;
	       level_offset = (selected_offset_3 + 9);
	       enemy_offset = selected_offset_enemies_3;
	       save_level_new();
	       strcpy(romfile, old_rom_filename);
	       from_save_to_rom_func = FALSE;
	    }
      }
   return D_O_K;
}




void add_enemy()
{
   if (enemy_objs > (65536 / 3))
      return;

   enemy_array[0][enemy_objs] = 0x72;
   enemy_array[1][enemy_objs] = cursor_x;
   enemy_array[2][enemy_objs] = cursor_y;

   enemy_bytes += 3;
   enemy_objs++;

}



void add_3byte_object()
{
   if (tbyte_objs > (65536 / 3))
      return;
   if ((cursor_y > 27) && (!vertical_flag))
      return;
   if ((cursor_x > 15) && (vertical_flag))
      return;

   tbyte_array[0][tbyte_objs] = cursor_y;
   tbyte_array[1][tbyte_objs] = cursor_x;
   tbyte_array[2][tbyte_objs] = 0;
   tbyte_objs++;

   if (level_bytes == 0)
      the_first_object = 3;

   level_bytes += 3;
   ff_object_flag = 3;
   if (ff_oldobject_flag != ff_object_flag)
      {
	 ff_oldobject_flag = ff_object_flag;
	 ff_number_of_level_sections++;
      }
   object_ordering[ff_number_of_level_sections - 1]++;
}



void add_4byte_object()
{
   if (fbyte_objs > (65536 / 4))
      return;
   if ((cursor_y > 27) && (!vertical_flag))
      return;
   if ((cursor_x > 15) && (vertical_flag))
      return;

   fbyte_array[0][fbyte_objs] = (cursor_y + 64);
   fbyte_array[1][fbyte_objs] = cursor_x;
   fbyte_array[2][fbyte_objs] = 0xB0;
   fbyte_array[3][fbyte_objs] = 0;
   fbyte_objs++;

   if (level_bytes == 0)
      the_first_object = 4;

   level_bytes += 4;

   ff_object_flag = 4;

   if (ff_oldobject_flag != ff_object_flag)
      {
	 ff_oldobject_flag = ff_object_flag;
	 ff_number_of_level_sections++;
      }

   object_ordering[ff_number_of_level_sections - 1]++;
}


int save_m3l_file()
{
   int m3l;
   int i;
   char error_msg[256];
   int k;
   int j;
   int byte_counter = 0;
   int fbyte_obj_counter = 0;
   int tbyte_obj_counter = 0;
   unsigned char byte[1];
   struct dfree d;
   unsigned long freespace;

   if (file_menu[5].flags & D_DISABLED)
      return D_O_K;

   if (billfile_select("Save M3L Level", m3l_filename, "m3l"))
      {
	 fix_filename_path(m3l_filename, m3l_filename, 256);
	 if (m3l_filename[0] > 96)
	    getdfree((m3l_filename[0] - 96), &d);
	 else
	    getdfree((m3l_filename[0] - 64), &d);
	 freespace = (d.df_bsec * d.df_sclus * d.df_avail);
	 if ((level_bytes + enemy_bytes + 15) > freespace)
	    {
	       billalert("Error", "Not enough free disk space to save file!", NULL, "OK", NULL, 0, 0);
	       return D_O_K;
	    }

	 if (exists(m3l_filename))
	    delete_file(m3l_filename);


	 m3l = open(m3l_filename, O_CREAT | O_BINARY);
	 if (m3l < 0)
	    {
	       sprintf(error_msg, "Error saving file %s", get_filename(m3l_filename));
	       billalert("Error", error_msg, NULL, "OK", NULL, 0, 0);
	       return D_O_K;
	    }

	 if (freeform_mode)
	    number_of_level_sections = ff_number_of_level_sections;

	 for (i = 0; i < number_of_level_sections; i++)
	    {
	       if (the_first_object == 3)
		  {
		     if ((i % 2) == 0)
			{
			   for (j = 0; j < object_ordering[i]; j++)
			      {
				 for (k = 0; k < 3; k++)
				    level_table_string[k + byte_counter] = tbyte_array[k][tbyte_obj_counter];
				 tbyte_obj_counter++;
				 byte_counter += 3;
			      }
			}
		     if ((i % 2) == 1)
			{
			   for (j = 0; j < object_ordering[i]; j++)
			      {
				 for (k = 0; k < 4; k++)
				    level_table_string[k + byte_counter] = fbyte_array[k][fbyte_obj_counter];
				 fbyte_obj_counter++;
				 byte_counter += 4;
			      }
			}
		  }
	       if (the_first_object == 4)
		  {
		     if ((i % 2) == 1)
			{
			   for (j = 0; j < object_ordering[i]; j++)
			      {
				 for (k = 0; k < 3; k++)
				    level_table_string[k + byte_counter] = tbyte_array[k][tbyte_obj_counter];
				 tbyte_obj_counter++;
				 byte_counter += 3;
			      }
			}
		     if ((i % 2) == 0)
			{
			   for (j = 0; j < object_ordering[i]; j++)
			      {
				 for (k = 0; k < 4; k++)
				    level_table_string[k + byte_counter] = fbyte_array[k][fbyte_obj_counter];
				 fbyte_obj_counter++;
				 byte_counter += 4;
			      }
			}
		  }
	    }

	 if (options_dialog[12].flags & D_SELECTED)
	    {
	       for (i = 0; i < enemy_objs; i++)
		  {
		     sort[i].enemy = enemy_array[0][i];
		     sort[i].horiz = enemy_array[1][i];
		     sort[i].vert = enemy_array[2][i];
		  }

	       qsort(sort, enemy_objs, sizeof(SMB3_ENEMY), qsort_by_h_location);

	       for (i = 0; i < enemy_objs; i++)
		  {
		     enemy_array[0][i] = sort[i].enemy;
		     enemy_array[1][i] = sort[i].horiz;
		     enemy_array[2][i] = sort[i].vert;
		  }
	    }

	 for (i = 0; i < enemy_objs; i++)
	    for (j = 0; j < 3; j++)
	       enemy_string[(i * 3) + j] = enemy_array[j][i];


	 byte[0] = world;
	 lseek(m3l, 0, SEEK_SET);
	 write(m3l, byte, 1);
	 if (level_known)
	    byte[0] = level;
	 else
	    byte[0] = 1;
	 lseek(m3l, 1, SEEK_SET);
	 write(m3l, byte, 1);
	 byte[0] = real_level_object_set;
	 lseek(m3l, 2, SEEK_SET);
	 write(m3l, byte, 1);
	 lseek(m3l, 3, SEEK_SET);
	 write(m3l, header, 9);
	 lseek(m3l, 12, SEEK_SET);
	 write(m3l, level_table_string, level_bytes);
	 byte[0] = 0xFF;
	 lseek(m3l, (12 + level_bytes), SEEK_SET);
	 write(m3l, byte, 1);
	 byte[0] = 0x01;
	 lseek(m3l, (12 + level_bytes + 1), SEEK_SET);
	 write(m3l, byte, 1);
	 lseek(m3l, (12 + level_bytes + 2), SEEK_SET);
	 write(m3l, enemy_string, enemy_bytes);
	 byte[0] = 0xFF;
	 lseek(m3l, (12 + level_bytes + 2 + enemy_bytes), SEEK_SET);
	 write(m3l, byte, 1);
	 close(m3l);
	 levelmodified = FALSE;
      }

   return D_O_K;
}



void delete_enemy(int object)
{
   int i;

   for (i = object; i < enemy_objs; i++)
      {
	 enemy_array[0][i] = enemy_array[0][i + 1];
	 enemy_array[1][i] = enemy_array[1][i + 1];
	 enemy_array[2][i] = enemy_array[2][i + 1];
      }

   enemy_bytes -= 3;
   enemy_objs--;
}


void delete_4byte(int object)
{
   int i;
   int j;
   int object_counter = 0;

   if (the_first_object == 4)
      {
	 for (i = 0; i < ff_number_of_level_sections; i++)
	    {
	       if ((i % 2) == 0)
		  {
		     object_counter += object_ordering[i];
		     if (object_counter > object)
			{
			   if (object_ordering[i] == 1)
			      {
				 if (i == (ff_number_of_level_sections - 1))
				    {
				       ff_number_of_level_sections--;
				    }
				 else
				    {
				       if (i == 0)
					  {
					     for (j = 0; j < ff_number_of_level_sections; j++)
						object_ordering[j] = object_ordering[j + 1];
					     ff_number_of_level_sections--;
					     the_first_object = 3;
					  }
				       else
					  {
					     object_ordering[i - 1] += object_ordering[i + 1];
					     for (j = i; j < ff_number_of_level_sections; j++)
						object_ordering[j] = object_ordering[j + 2];
					     ff_number_of_level_sections -= 2;
					  }
				    }
			      }
			   else
			      object_ordering[i]--;
			   break;
			}
		  }
	    }
      }
   else if (the_first_object == 3)
      {
	 for (i = 0; i < ff_number_of_level_sections; i++)
	    {
	       if ((i % 2) == 1)
		  {
		     object_counter += object_ordering[i];
		     if (object_counter > object)
			{
			   if (object_ordering[i] == 1)
			      {
				 if (i == (ff_number_of_level_sections - 1))
				    {
				       ff_number_of_level_sections--;
				    }
				 else
				    {
				       if (i == 0)
					  {
					     for (j = 0; j < ff_number_of_level_sections; j++)
						object_ordering[j] = object_ordering[j + 1];
					     ff_number_of_level_sections--;
					     the_first_object = 4;
					  }
				       else
					  {
					     object_ordering[i - 1] += object_ordering[i + 1];
					     for (j = i; j < ff_number_of_level_sections; j++)
						object_ordering[j] = object_ordering[j + 2];
					     ff_number_of_level_sections -= 2;
					  }
				    }
			      }
			   else
			      object_ordering[i]--;
			   break;
			}
		  }
	    }
      }

   for (i = object; i < fbyte_objs; i++)
      {
	 fbyte_array[0][i] = fbyte_array[0][i + 1];
	 fbyte_array[1][i] = fbyte_array[1][i + 1];
	 fbyte_array[2][i] = fbyte_array[2][i + 1];
	 fbyte_array[3][i] = fbyte_array[3][i + 1];
      }

   fbyte_objs--;
   level_bytes -= 4;
}



void delete_3byte(int object)
{
   int i;
   int j;
   int object_counter = 0;

   if (the_first_object == 3)
      {
	 for (i = 0; i < ff_number_of_level_sections; i++)
	    {
	       if ((i % 2) == 0)
		  {
		     object_counter += object_ordering[i];
		     if (object_counter > object)
			{
			   if (object_ordering[i] == 1)
			      {
				 if (i == (ff_number_of_level_sections - 1))
				    {
				       ff_number_of_level_sections--;
				    }
				 else
				    {
				       if (i == 0)
					  {
					     for (j = 0; j < ff_number_of_level_sections; j++)
						object_ordering[j] = object_ordering[j + 1];
					     ff_number_of_level_sections--;
					     the_first_object = 4;
					  }
				       else
					  {
					     object_ordering[i - 1] += object_ordering[i + 1];
					     for (j = i; j < ff_number_of_level_sections; j++)
						object_ordering[j] = object_ordering[j + 2];
					     ff_number_of_level_sections -= 2;
					  }
				    }
			      }
			   else
			      object_ordering[i]--;
			   break;
			}
		  }
	    }
      }
   else if (the_first_object == 4)
      {
	 for (i = 0; i < ff_number_of_level_sections; i++)
	    {
	       if ((i % 2) == 1)
		  {
		     object_counter += object_ordering[i];
		     if (object_counter > object)
			{
			   if (object_ordering[i] == 1)
			      {
				 if (i == (ff_number_of_level_sections - 1))
				    {
				       ff_number_of_level_sections--;
				    }
				 else
				    {
				       if (i == 0)
					  {
					     for (j = 0; j < ff_number_of_level_sections; j++)
						object_ordering[j] = object_ordering[j + 1];
					     ff_number_of_level_sections--;
					     the_first_object = 3;
					  }
				       else
					  {
					     object_ordering[i - 1] += object_ordering[i + 1];
					     for (j = i; j < ff_number_of_level_sections; j++)
						object_ordering[j] = object_ordering[j + 2];
					     ff_number_of_level_sections -= 2;
					  }
				    }
			      }
			   else
			      object_ordering[i]--;
			   break;
			}
		  }
	    }
      }

   for (i = object; i < tbyte_objs; i++)
      {
	 tbyte_array[0][i] = tbyte_array[0][i + 1];
	 tbyte_array[1][i] = tbyte_array[1][i + 1];
	 tbyte_array[2][i] = tbyte_array[2][i + 1];
      }

   tbyte_objs--;
   level_bytes -= 3;
}



int load_m3l_file()
{
   int i;
   char error_msg[256];
   char old_filename[256];
   int ret;
   FILE *m3l;
   int oldworld = world;
   int oldlevel = level;
   int oldobs = real_level_object_set;
   int oldlobs = level_object_set;
   int file_error = 0;
   int old_level_offset = level_offset;
   int old_header_offset = header_offset;
   int old_enemy_offset = enemy_offset;
   int old_allstars_flag = allstars_flag;

   if (file_menu[6].flags & D_DISABLED)
      return D_O_K;

   if ((levelmodified == TRUE) && (options_dialog[2].flags & D_SELECTED))
      {
	 sprintf(error_msg, "Level %i-%i has been modified.", world, level);
	 ret = billalert3("Question", error_msg, "Save changes?", "Yes", "No", "Cancel", 0, 0, 0);
	 if (ret == 1)
	    {
	       if (freeform_mode)
		  save_m3l_file();
	       else
		  save_level_new();
	    }
	 if (ret == 3)
	    return D_O_K;
      }

   remove_filename(m3l_filename);

   if (billfile_select("Load M3L File", m3l_filename, "m3l"))
      {
	 m3l = fopen(m3l_filename, "rb");
	 if (!m3l)
	    {
	       sprintf(error_msg, "Error reading file %s!", get_filename(m3l_filename));
	       billalert("Error", error_msg, NULL, "OK", NULL, 0, 0);
	       return D_O_K;
	    }

	 if ((world = getc(m3l)) == EOF)
	    {
	       sprintf(error_msg, "Error reading file %s!", get_filename(m3l_filename));
	       billalert("Error", error_msg, "This file may not be a valid M3L file.", "OK", NULL, 0, 0);
	       world = oldworld;
	       return D_O_K;
	    }
	 if ((level = getc(m3l)) == EOF)
	    {
	       sprintf(error_msg, "Error reading file %s!", get_filename(m3l_filename));
	       billalert("Error", error_msg, "This file may not be a valid M3L file.", "OK", NULL, 0, 0);
	       world = oldworld;
	       level = oldlevel;
	       return D_O_K;
	    }
	 if ((real_level_object_set = getc(m3l)) == EOF)
	    {
	       sprintf(error_msg, "Error reading file %s!", get_filename(m3l_filename));
	       billalert("Error", error_msg, "This file may not be a valid M3L file.", "OK", NULL, 0, 0);
	       level = oldlevel;
	       world = oldworld;
	       real_level_object_set = oldobs;
	       return D_O_K;
	    }
	 header_offset = 3;
	 level_offset = 12;

	 fclose(m3l);

	 strcpy(old_filename, romfile);
	 strcpy(romfile, m3l_filename);

	 enemy_offset = get_m3l_enemy_offset(m3l_filename);
	 level_object_set = convert_object_sets(real_level_object_set);
	 allstars_flag = FALSE;

	 if (read_objects(level_object_set) > 0)
	    {
	       sprintf(error_msg, "Error reading file %s!", get_filename(m3l_filename));
	       billalert("Error", error_msg, "This file may not be a valid M3L file.", "OK", NULL, 0, 0);
	       level = oldlevel;
	       world = oldworld;
	       real_level_object_set = oldobs;
	       level_object_set = oldlobs;
	       level_offset = old_level_offset;
	       header_offset = old_header_offset;
	       enemy_offset = old_enemy_offset;
	       strcpy(romfile, old_filename);
	       allstars_flag = old_allstars_flag;
	       return D_O_K;
	    }

	 ff_number_of_level_sections = number_of_level_sections;
	 if (((the_first_object == 3) && ((ff_number_of_level_sections % 2) == 1)) || ((the_first_object == 4) && ((ff_number_of_level_sections % 2) == 0)))
	    ff_oldobject_flag = 3;
	 if (((the_first_object == 3) && ((ff_number_of_level_sections % 2) == 0)) || ((the_first_object == 4) && ((ff_number_of_level_sections % 2) == 1)))
	    ff_oldobject_flag = 4;
	 freeform_mode = TRUE;
	 file_loaded = TRUE;
	 levelmodified = FALSE;
	 mapedit_flag = FALSE;
	 num_levels = NUM_SMB3_LEVELS;
      }

   clear(status_display);
   return D_O_K;
}



int get_m3l_enemy_offset(char *filename)
{
   FILE *m3l;
   int i;
   unsigned char byte;

   m3l = fopen(filename, "rb");

   if (!m3l)
      return -1;

   for (i = (file_size(filename) - 2); i > 0; i--)
      {
	 fseek(m3l, i, SEEK_SET);
	 byte = getc(m3l);
	 if (byte == 0xFF)
	    break;
      }

   fclose(m3l);

   if ((file_size(filename) - (i + 2)) <= 3)
      return 0;

   return (i + 2);
}




int change_level_rom_offset_3()
{
   void *player;
   char error_msg[64];
   int ret;
   int ret2;
   int oldlevel = level;
   int oldworld = world;
   void *lplayer;
   int selected_level_index;

 redo_the_level_chooser_dialog_please_3:

   oldworld2 = selected_world_3;
   level_chooser_dialog_ex[4].d1 = (selected_world_3 - 1);
   level_chooser_dialog_ex[5].d1 = (selected_level_3 - 1);

   from_enemies_func_3 = FALSE;
   from_level_func_3 = TRUE;


   init_moveable(level_chooser_dialog_ex);
   player = init_dialog(level_chooser_dialog_ex, 4);
   while (update_dialog(player))
      {
	 currently_selected_level_index_3 = ((WORLD_INDEXES[level_chooser_dialog_ex[4].d1] + level_chooser_dialog_ex[5].d1));

	 if (oldworld2 != (level_chooser_dialog_ex[4].d1 + 1))
	    {
	       oldworld2 = (level_chooser_dialog_ex[4].d1 + 1);
	       if ((level_chooser_dialog_ex[4].d1 + 1) == num_worlds)
		  {
		     if (level_chooser_dialog_ex[5].d1 > ((num_levels - WORLD_INDEXES[num_worlds - 1]) - 1))
			level_chooser_dialog_ex[5].d1 = ((num_levels - WORLD_INDEXES[num_worlds - 1]) - 1);
		     if (level_chooser_dialog_ex[5].d2 > ((num_levels - WORLD_INDEXES[num_worlds - 1]) - 9))
			level_chooser_dialog_ex[5].d2 = ((num_levels - WORLD_INDEXES[num_worlds - 1]) - 9);
		  }
	       else if ((level_chooser_dialog_ex[4].d1 + 1) == 0)
		  {
		     if (level_chooser_dialog_ex[5].d1 > (WORLD_INDEXES[0] - 1))
			level_chooser_dialog_ex[5].d1 = (WORLD_INDEXES[0] - 1);
		     if (level_chooser_dialog_ex[5].d2 > 0)
			level_chooser_dialog_ex[5].d2 = 0;
		  }
	       else
		  {
		     if (level_chooser_dialog_ex[5].d1 > ((WORLD_INDEXES[level_chooser_dialog_ex[4].d1 + 1] - WORLD_INDEXES[level_chooser_dialog_ex[4].d1]) - 1))
			level_chooser_dialog_ex[5].d1 = ((WORLD_INDEXES[level_chooser_dialog_ex[4].d1 + 1] - WORLD_INDEXES[level_chooser_dialog_ex[4].d1]) - 1);
		     if (level_chooser_dialog_ex[5].d2 > ((WORLD_INDEXES[level_chooser_dialog_ex[4].d1 + 1] - WORLD_INDEXES[level_chooser_dialog_ex[4].d1]) - 9))
			level_chooser_dialog_ex[5].d2 = ((WORLD_INDEXES[level_chooser_dialog_ex[4].d1 + 1] - WORLD_INDEXES[level_chooser_dialog_ex[4].d1]) - 9);
		  }

	       SEND_MESSAGE((level_chooser_dialog_ex + 4), MSG_DRAW, 0);
	       SEND_MESSAGE((level_chooser_dialog_ex + 5), MSG_DRAW, 0);
	    }
	 oldworld2 = (level_chooser_dialog_ex[4].d1 + 1);
      }
   shutdown_moveable(level_chooser_dialog_ex);
   ret = shutdown_dialog(player);
   if (ret == 6)
      {
	 selected_world_3 = (level_chooser_dialog_ex[4].d1 + 1);
	 selected_level_3 = (level_chooser_dialog_ex[5].d1 + 1);
	 selected_level_index = ((WORLD_INDEXES[(selected_world_3 - 1)] + selected_level_3) - 1);
	 selected_offset_3 = (level_array[selected_level_index].rom_level_offset - 9);
	 selected_object_set_3 = level_array[selected_level_index].real_obj_set;
	 refresh_dialog_flag_1_3 = TRUE;
      }

   if (ret == 8)
      {
	 specify_offset_3();
	 if (!close_level_chooser_dialog_ex_flag_3)
	    goto redo_the_level_chooser_dialog_please_3;
	 close_level_chooser_dialog_ex_flag_3 = FALSE;
      }
}


int change_enemy_rom_offset_3()
{
   void *player;
   char error_msg[64];
   int ret;
   int ret2;
   int oldlevel = level;
   int oldworld = world;
   void *lplayer;
   int selected_level_index;

 redo_the_level_chooser_dialog_please_thank_you_3:

   oldworld2 = selected_world_enemies_3;
   level_chooser_dialog_ex[4].d1 = (selected_world_enemies_3 - 1);
   level_chooser_dialog_ex[5].d1 = (selected_level_enemies_3 - 1);

   from_enemies_func_3 = TRUE;
   from_level_func_3 = FALSE;

   init_moveable(level_chooser_dialog_ex);
   player = init_dialog(level_chooser_dialog_ex, 4);
   while (update_dialog(player))
      {
	 currently_selected_level_index_3 = ((WORLD_INDEXES[level_chooser_dialog_ex[4].d1] + level_chooser_dialog_ex[5].d1));

	 if (oldworld2 != (level_chooser_dialog_ex[4].d1 + 1))
	    {
	       oldworld2 = (level_chooser_dialog_ex[4].d1 + 1);
	       if ((level_chooser_dialog_ex[4].d1 + 1) == num_worlds)
		  {
		     if (level_chooser_dialog_ex[5].d1 > ((num_levels - WORLD_INDEXES[num_worlds - 1]) - 1))
			level_chooser_dialog_ex[5].d1 = ((num_levels - WORLD_INDEXES[num_worlds - 1]) - 1);
		     if (level_chooser_dialog_ex[5].d2 > ((num_levels - WORLD_INDEXES[num_worlds - 1]) - 9))
			level_chooser_dialog_ex[5].d2 = ((num_levels - WORLD_INDEXES[num_worlds - 1]) - 9);
		  }
	       else if ((level_chooser_dialog_ex[4].d1 + 1) == 0)
		  {
		     if (level_chooser_dialog_ex[5].d1 > (WORLD_INDEXES[0] - 1))
			level_chooser_dialog_ex[5].d1 = (WORLD_INDEXES[0] - 1);
		     if (level_chooser_dialog_ex[5].d2 > 0)
			level_chooser_dialog_ex[5].d2 = 0;
		  }
	       else
		  {
		     if (level_chooser_dialog_ex[5].d1 > ((WORLD_INDEXES[level_chooser_dialog_ex[4].d1 + 1] - WORLD_INDEXES[level_chooser_dialog_ex[4].d1]) - 1))
			level_chooser_dialog_ex[5].d1 = ((WORLD_INDEXES[level_chooser_dialog_ex[4].d1 + 1] - WORLD_INDEXES[level_chooser_dialog_ex[4].d1]) - 1);
		     if (level_chooser_dialog_ex[5].d2 > ((WORLD_INDEXES[level_chooser_dialog_ex[4].d1 + 1] - WORLD_INDEXES[level_chooser_dialog_ex[4].d1]) - 9))
			level_chooser_dialog_ex[5].d2 = ((WORLD_INDEXES[level_chooser_dialog_ex[4].d1 + 1] - WORLD_INDEXES[level_chooser_dialog_ex[4].d1]) - 9);
		  }

	       SEND_MESSAGE((level_chooser_dialog_ex + 4), MSG_DRAW, 0);
	       SEND_MESSAGE((level_chooser_dialog_ex + 5), MSG_DRAW, 0);
	    }
	 oldworld2 = (level_chooser_dialog_ex[4].d1 + 1);
      }
   shutdown_moveable(level_chooser_dialog_ex);
   ret = shutdown_dialog(player);
   if (ret == 6)
      {
	 selected_world_enemies_3 = (level_chooser_dialog_ex[4].d1 + 1);
	 selected_level_enemies_3 = (level_chooser_dialog_ex[5].d1 + 1);
	 selected_level_index = ((WORLD_INDEXES[(selected_world_enemies_3 - 1)] + selected_level_enemies_3) - 1);
	 selected_offset_enemies_3 = level_array[selected_level_index].enemy_offset;
	 refresh_dialog_flag_3_2_1 = TRUE;
      }

   if (ret == 8)
      {
	 specify_offset_3();
	 if (!close_level_chooser_dialog_ex_flag_3)
	    goto redo_the_level_chooser_dialog_please_thank_you_3;
	 close_level_chooser_dialog_ex_flag_3 = FALSE;
      }
}



int specify_offset_3()
{
   int temp;
   char *bp;

   if (from_enemies_func_3)
      {
	 if (level_array[currently_selected_level_index_3].enemy_offset != 0)
	    sprintf(specifyoffsetbuf, "%X", (level_array[currently_selected_level_index_3].enemy_offset - 1));
	 else
	    sprintf(specifyoffsetbuf, "0");
      }
   if (from_level_func_3)
      sprintf(specifyoffsetbuf, "%X", (level_array[currently_selected_level_index_3].rom_level_offset - 9));

 redo_specify_offset_dialog:

   if (moveable_do_dialog(specify_offset_dialog, -1) == 3)
      {
	 temp = strtol(specifyoffsetbuf, &bp, 16);
	 if (bp[0] != '\0')
	    {
	       billalert("Error", "Please enter a hexadecimal value between 0x0 and 0xFFFFFF", "for the offset.", "OK", NULL, NULL, NULL);
	       goto redo_specify_offset_dialog;
	    }

	 if (from_level_func_3)
	    {
	       selected_offset_3 = strtol(specifyoffsetbuf, &bp, 16);
	       refresh_dialog_flag_5_3 = TRUE;
	       close_level_chooser_dialog_ex_flag_3 = TRUE;
	    }
	 if (from_enemies_func_3)
	    {
	       selected_offset_enemies_3 = strtol(specifyoffsetbuf, &bp, 16);
	       if (selected_offset_enemies_3 != 0)
		  selected_offset_enemies_3++;
	       refresh_dialog_flag_6_3 = TRUE;
	       close_level_chooser_dialog_ex_flag_3 = TRUE;
	    }
      }
}
